#include "defines.h"
#include "../include/abilities.h"
#include "../include/items.h"
#include "../include/base_stats.h"

// Maximum value for a female Pokémon is 254 (MON_FEMALE) which is 100% female.
// 255 (MON_GENDERLESS) is reserved for genderless Pokémon.
#define PERCENT_FEMALE(percent) min(254, ((percent * 255) / 100))

const struct BaseStats gBaseStats[] = 
{
	[SPECIES_NONE] = {0},

	[SPECIES_BULBASAUR] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 49,
		.baseDefense 	= 49,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 45,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 64,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CHLOROPHYLL,
		.noFlip = TRUE,
	},

	[SPECIES_IVYSAUR] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 62,
		.baseDefense 	= 63,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 60,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 141,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CHLOROPHYLL,
		.noFlip = TRUE,
	},

	[SPECIES_VENUSAUR] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 82,
		.baseDefense 	= 83,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 80,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CHLOROPHYLL,
		.noFlip = TRUE,
	},

	[SPECIES_CHARMANDER] =
	{
		.baseHP 		= 39,
		.baseAttack 	= 52,
		.baseDefense 	= 43,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOLARPOWER,
		.noFlip = TRUE,
	},

	[SPECIES_CHARMELEON] =
	{
		.baseHP 		= 58,
		.baseAttack 	= 64,
		.baseDefense 	= 58,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 80,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 142,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOLARPOWER,
		.noFlip = TRUE,
	},

	[SPECIES_CHARIZARD] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 84,
		.baseDefense 	= 78,
		.baseSpAttack 	= 109,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOLARPOWER,
		.noFlip = TRUE,
	},

	[SPECIES_SQUIRTLE] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 48,
		.baseDefense 	= 65,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 64,
		.baseSpeed 		= 43,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 66,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RAINDISH,
		.noFlip = TRUE,
	},

	[SPECIES_WARTORTLE] =
	{
		.baseHP 		= 59,
		.baseAttack 	= 63,
		.baseDefense 	= 80,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 58,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 143,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RAINDISH,
		.noFlip = TRUE,
	},

	[SPECIES_BLASTOISE] =
	{
		.baseHP 		= 79,
		.baseAttack 	= 83,
		.baseDefense 	= 100,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 78,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RAINDISH,
		.noFlip = TRUE,
	},

	[SPECIES_CATERPIE] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 30,
		.baseDefense 	= 35,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 20,
		.baseSpeed 		= 45,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 255,
		.expYield = 53,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_RUNAWAY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RUNAWAY,
		.noFlip = TRUE,
	},

	[SPECIES_METAPOD] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 20,
		.baseDefense 	= 55,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 30,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 120,
		.expYield = 72,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_SHEDSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEDSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_BUTTERFREE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 45,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 70,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 160,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SILVER_POWDER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_COMPOUNDEYES,
		.ability2 = ABILITY_TINTEDLENS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TINTEDLENS,
		.noFlip = TRUE,
	},

	[SPECIES_WEEDLE] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 35,
		.baseDefense 	= 30,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 20,
		.baseSpeed 		= 50,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 255,
		.expYield = 52,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_RUNAWAY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RUNAWAY,
		.noFlip = TRUE,
	},

	[SPECIES_KAKUNA] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 25,
		.baseDefense 	= 50,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 35,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 120,
		.expYield = 71,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_SHEDSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEDSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_BEEDRILL] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 90,
		.baseDefense 	= 40,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 75,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 159,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNIPER,
		.noFlip = TRUE,
	},

	[SPECIES_PIDGEY] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 40,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 56,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 55,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_TANGLEDFEET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BIGPECKS,
		.noFlip = TRUE,
	},

	[SPECIES_PIDGEOTTO] =
	{
		.baseHP 		= 63,
		.baseAttack 	= 60,
		.baseDefense 	= 55,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 71,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 120,
		.expYield = 113,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_TANGLEDFEET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BIGPECKS,
		.noFlip = TRUE,
	},

	[SPECIES_PIDGEOT] =
	{
		.baseHP 		= 83,
		.baseAttack 	= 80,
		.baseDefense 	= 75,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 101,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_TANGLEDFEET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BIGPECKS,
		.noFlip = TRUE,
	},

	[SPECIES_RATTATA] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 56,
		.baseDefense 	= 35,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 72,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 57,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHILAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_GUTS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HUSTLE,
		.noFlip = TRUE,
	},

	[SPECIES_RATICATE] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 81,
		.baseDefense 	= 60,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 97,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 127,
		.expYield = 116,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHILAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_GUTS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HUSTLE,
		.noFlip = TRUE,
	},

	[SPECIES_SPEAROW] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 60,
		.baseDefense 	= 30,
		.baseSpAttack 	= 31,
		.baseSpDefense 	= 31,
		.baseSpeed 		= 70,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 58,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHARP_BEAK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNIPER,
		.noFlip = TRUE,
	},

	[SPECIES_FEAROW] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 90,
		.baseDefense 	= 65,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 61,
		.baseSpeed 		= 100,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 90,
		.expYield = 162,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHARP_BEAK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNIPER,
		.noFlip = TRUE,
	},

	[SPECIES_EKANS] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 60,
		.baseDefense 	= 44,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 54,
		.baseSpeed 		= 55,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 255,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_SHEDSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_ARBOK] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 95,
		.baseDefense 	= 69,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 79,
		.baseSpeed 		= 80,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 90,
		.expYield = 147,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_SHEDSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_PIKACHU] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},

	[SPECIES_RAICHU] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 90,
		.baseDefense 	= 55,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 110,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 75,
		.expYield = 122,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ORAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},

	[SPECIES_SANDSHREW] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 75,
		.baseDefense 	= 85,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 40,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 255,
		.expYield = 93,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_GRIP_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_SANDRUSH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDRUSH,
		.noFlip = TRUE,
	},

	[SPECIES_SANDSLASH] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 100,
		.baseDefense 	= 110,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 65,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 90,
		.expYield = 163,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_GRIP_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_SANDRUSH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDRUSH,
		.noFlip = TRUE,
	},

	[SPECIES_NIDORAN_F] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 47,
		.baseDefense 	= 52,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 41,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 235,
		.expYield = 59,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_HUSTLE,
		.safariZoneFleeRate = 50,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_NIDORINA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 62,
		.baseDefense 	= 67,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 56,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 120,
		.expYield = 117,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_HUSTLE,
		.safariZoneFleeRate = 75,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_NIDOQUEEN] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 92,
		.baseDefense 	= 87,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 76,
		.type1 = TYPE_POISON,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 194,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_NIDORAN_M] =
	{
		.baseHP 		= 46,
		.baseAttack 	= 57,
		.baseDefense 	= 40,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 50,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 235,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_HUSTLE,
		.safariZoneFleeRate = 50,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_NIDORINO] =
	{
		.baseHP 		= 61,
		.baseAttack 	= 72,
		.baseDefense 	= 57,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 65,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 120,
		.expYield = 118,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_HUSTLE,
		.safariZoneFleeRate = 75,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_NIDOKING] =
	{
		.baseHP 		= 81,
		.baseAttack 	= 102,
		.baseDefense 	= 77,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 85,
		.type1 = TYPE_POISON,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 195,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_CLEFAIRY] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 45,
		.baseDefense 	= 48,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 35,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 150,
		.expYield = 68,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LEPPA_BERRY,
		.item2 = ITEM_MOON_STONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 10,
		.friendship = 140,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_CLEFABLE] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 70,
		.baseDefense 	= 73,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 60,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 25,
		.expYield = 129,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LEPPA_BERRY,
		.item2 = ITEM_MOON_STONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 10,
		.friendship = 140,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNAWARE,
		.noFlip = TRUE,
	},

	[SPECIES_VULPIX] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 41,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 190,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_RAWST_BERRY,
		.item2 = ITEM_CHARCOAL,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_DROUGHT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DROUGHT,
		.noFlip = TRUE,
	},

	[SPECIES_NINETALES] =
	{
		.baseHP 		= 73,
		.baseAttack 	= 76,
		.baseDefense 	= 75,
		.baseSpAttack 	= 81,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 75,
		.expYield = 178,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 1,
		.item1 = ITEM_RAWST_BERRY,
		.item2 = ITEM_CHARCOAL,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_DROUGHT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DROUGHT,
		.noFlip = TRUE,
	},

	[SPECIES_JIGGLYPUFF] =
	{
		.baseHP 		= 115,
		.baseAttack 	= 45,
		.baseDefense 	= 20,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 20,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FAIRY,
		.catchRate = 170,
		.expYield = 76,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_MOON_STONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_COMPETITIVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_WIGGLYTUFF] =
	{
		.baseHP 		= 140,
		.baseAttack 	= 70,
		.baseDefense 	= 45,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 45,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FAIRY,
		.catchRate = 50,
		.expYield = 109,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_MOON_STONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_COMPETITIVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},

	[SPECIES_ZUBAT] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 35,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 55,
		.type1 = TYPE_POISON,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 54,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_GOLBAT] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 70,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 90,
		.type1 = TYPE_POISON,
		.type2 = TYPE_FLYING,
		.catchRate = 90,
		.expYield = 171,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_ODDISH] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 50,
		.baseDefense 	= 55,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 255,
		.expYield = 78,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ABSORB_BULB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_RUNAWAY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RUNAWAY,
		.noFlip = TRUE,
	},

	[SPECIES_GLOOM] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 65,
		.baseDefense 	= 70,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 40,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 120,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ABSORB_BULB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_STENCH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STENCH,
		.noFlip = TRUE,
	},

	[SPECIES_VILEPLUME] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 85,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 50,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 184,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ABSORB_BULB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_EFFECTSPORE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_EFFECTSPORE,
		.noFlip = TRUE,
	},

	[SPECIES_PARAS] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 70,
		.baseDefense 	= 55,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 25,
		.type1 = TYPE_BUG,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 70,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_TINY_MUSHROOM,
		.item2 = ITEM_BIG_MUSHROOM,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_EFFECTSPORE,
		.ability2 = ABILITY_DRYSKIN,
		.safariZoneFleeRate = 50,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_PARASECT] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 95,
		.baseDefense 	= 80,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 30,
		.type1 = TYPE_BUG,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_TINY_MUSHROOM,
		.item2 = ITEM_BIG_MUSHROOM,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_EFFECTSPORE,
		.ability2 = ABILITY_DRYSKIN,
		.safariZoneFleeRate = 75,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_VENONAT] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 55,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 45,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 190,
		.expYield = 75,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_COMPOUNDEYES,
		.ability2 = ABILITY_TINTEDLENS,
		.safariZoneFleeRate = 50,
		.hiddenAbility = ABILITY_RUNAWAY,
		.noFlip = TRUE,
	},

	[SPECIES_VENOMOTH] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 65,
		.baseDefense 	= 60,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 90,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 75,
		.expYield = 138,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHED_SHELL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_TINTEDLENS,
		.safariZoneFleeRate = 75,
		.hiddenAbility = ABILITY_WONDERSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_DIGLETT] =
	{
		.baseHP 		= 10,
		.baseAttack 	= 55,
		.baseDefense 	= 25,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 95,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 255,
		.expYield = 81,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SOFT_SAND,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_ARENATRAP,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_DUGTRIO] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 100,
		.baseDefense 	= 50,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 120,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 50,
		.expYield = 153,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SOFT_SAND,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_ARENATRAP,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_MEOWTH] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 35,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 90,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 69,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_QUICK_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_PERSIAN] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 70,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 115,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 90,
		.expYield = 148,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_QUICK_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_LIMBER,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_PSYDUCK] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 52,
		.baseDefense 	= 48,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 55,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 80,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_DAMP,
		.ability2 = ABILITY_CLOUDNINE,
		.safariZoneFleeRate = 50,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},

	[SPECIES_GOLDUCK] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 82,
		.baseDefense 	= 78,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 85,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 75,
		.expYield = 174,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_DAMP,
		.ability2 = ABILITY_CLOUDNINE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},

	[SPECIES_MANKEY] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 80,
		.baseDefense 	= 35,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 70,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 190,
		.expYield = 74,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PAYAPA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_VITALSPIRIT,
		.ability2 = ABILITY_ANGERPOINT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_PRIMEAPE] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 105,
		.baseDefense 	= 60,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 95,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 75,
		.expYield = 149,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PAYAPA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_VITALSPIRIT,
		.ability2 = ABILITY_ANGERPOINT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_GROWLITHE] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 70,
		.baseDefense 	= 45,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 60,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 190,
		.expYield = 91,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_RAWST_BERRY,
		.item2 = ITEM_RAWST_BERRY,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_FLASHFIRE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_JUSTIFIED,
		.noFlip = TRUE,
	},

	[SPECIES_ARCANINE] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 110,
		.baseDefense 	= 80,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 95,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 75,
		.expYield = 213,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_RAWST_BERRY,
		.item2 = ITEM_RAWST_BERRY,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_FLASHFIRE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_JUSTIFIED,
		.noFlip = TRUE,
	},

	[SPECIES_POLIWAG] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 50,
		.baseDefense 	= 40,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 90,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 255,
		.expYield = 77,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_SWIFTSWIM,
		.safariZoneFleeRate = 50,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_POLIWHIRL] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 120,
		.expYield = 131,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_KINGS_ROCK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_SWIFTSWIM,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_POLIWRATH] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_KINGS_ROCK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_SWIFTSWIM,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_ABRA] =
	{
		.baseHP 		= 25,
		.baseAttack 	= 20,
		.baseDefense 	= 15,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 90,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 200,
		.expYield = 75,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_TWISTED_SPOON,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_KADABRA] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 35,
		.baseDefense 	= 30,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 105,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 100,
		.expYield = 145,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_TWISTED_SPOON,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_ALAKAZAM] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 50,
		.baseDefense 	= 45,
		.baseSpAttack 	= 135,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 120,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 50,
		.expYield = 186,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_TWISTED_SPOON,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_MACHOP] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 80,
		.baseDefense 	= 50,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 35,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 180,
		.expYield = 75,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_FOCUS_BAND,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_NOGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STEADFAST,
		.noFlip = TRUE,
	},

	[SPECIES_MACHOKE] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 45,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 90,
		.expYield = 146,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_FOCUS_BAND,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_NOGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STEADFAST,
		.noFlip = TRUE,
	},

	[SPECIES_MACHAMP] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 130,
		.baseDefense 	= 80,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 55,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 193,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_FOCUS_BAND,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_NOGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STEADFAST,
		.noFlip = TRUE,
	},

	[SPECIES_BELLSPROUT] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 75,
		.baseDefense 	= 35,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 40,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 255,
		.expYield = 84,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},

	[SPECIES_WEEPINBELL] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 90,
		.baseDefense 	= 50,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 55,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 120,
		.expYield = 151,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},

	[SPECIES_VICTREEBEL] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 105,
		.baseDefense 	= 65,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 70,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 191,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},

	[SPECIES_TENTACOOL] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 40,
		.baseDefense 	= 35,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_POISON,
		.catchRate = 190,
		.expYield = 105,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_LIQUIDOOZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RAINDISH,
		.noFlip = TRUE,
	},

	[SPECIES_TENTACRUEL] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 70,
		.baseDefense 	= 65,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 100,
		.type1 = TYPE_WATER,
		.type2 = TYPE_POISON,
		.catchRate = 60,
		.expYield = 205,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_LIQUIDOOZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RAINDISH,
		.noFlip = TRUE,
	},

	[SPECIES_GEODUDE] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 80,
		.baseDefense 	= 100,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 20,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_GROUND,
		.catchRate = 255,
		.expYield = 73,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_EVERSTONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_GRAVELER] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 95,
		.baseDefense 	= 115,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 35,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_GROUND,
		.catchRate = 120,
		.expYield = 134,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_EVERSTONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_GOLEM] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 120,
		.baseDefense 	= 130,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 45,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_EVERSTONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_PONYTA] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 85,
		.baseDefense 	= 55,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 90,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 190,
		.expYield = 152,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHUCA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_FLASHFIRE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLAMEBODY,
		.noFlip = TRUE,
	},

	[SPECIES_RAPIDASH] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 105,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 60,
		.expYield = 192,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHUCA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_FLASHFIRE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLAMEBODY,
		.noFlip = TRUE,
	},

	[SPECIES_SLOWPOKE] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 15,
		.type1 = TYPE_WATER,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 190,
		.expYield = 99,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LAGGING_TAIL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_OBLIVIOUS,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 50,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_SLOWBRO] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 75,
		.baseDefense 	= 110,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 30,
		.type1 = TYPE_WATER,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 75,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_KINGS_ROCK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_OBLIVIOUS,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_MAGNEMITE] =
	{
		.baseHP 		= 25,
		.baseAttack 	= 35,
		.baseDefense 	= 70,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 45,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_STEEL,
		.catchRate = 190,
		.expYield = 89,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_MAGNETPULL,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_MAGNETON] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 60,
		.baseDefense 	= 95,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 70,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_STEEL,
		.catchRate = 60,
		.expYield = 161,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_MAGNETPULL,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_FARFETCHD] =
	{
		.baseHP 		= 52,
		.baseAttack 	= 90,
		.baseDefense 	= 55,
		.baseSpAttack 	= 58,
		.baseSpDefense 	= 62,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 94,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LEEK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_INNERFOCUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_DODUO] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 85,
		.baseDefense 	= 45,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 75,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 190,
		.expYield = 96,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHARP_BEAK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_EARLYBIRD,
		.safariZoneFleeRate = 50,
		.hiddenAbility = ABILITY_TANGLEDFEET,
		.noFlip = TRUE,
	},

	[SPECIES_DODRIO] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 110,
		.baseDefense 	= 70,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 110,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 158,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHARP_BEAK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_EARLYBIRD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TANGLEDFEET,
		.noFlip = TRUE,
	},

	[SPECIES_SEEL] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 45,
		.baseDefense 	= 55,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 45,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 100,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ASPEAR_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_HYDRATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ICEBODY,
		.noFlip = TRUE,
	},

	[SPECIES_DEWGONG] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 70,
		.baseDefense 	= 80,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ICE,
		.catchRate = 75,
		.expYield = 176,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ASPEAR_BERRY,
		.item2 = ITEM_NEVER_MELT_ICE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_HYDRATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ICEBODY,
		.noFlip = TRUE,
	},

	[SPECIES_GRIMER] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 80,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 25,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 190,
		.expYield = 90,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BLACK_SLUDGE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_STENCH,
		.ability2 = ABILITY_STICKYHOLD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONTOUCH,
		.noFlip = TRUE,
	},

	[SPECIES_MUK] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 105,
		.baseDefense 	= 75,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 50,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 75,
		.expYield = 157,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_BLACK_SLUDGE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_STENCH,
		.ability2 = ABILITY_STICKYHOLD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONTOUCH,
		.noFlip = TRUE,
	},

	[SPECIES_SHELLDER] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 65,
		.baseDefense 	= 100,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 40,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 97,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PEARL,
		.item2 = ITEM_BIG_PEARL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SHELLARMOR,
		.ability2 = ABILITY_SKILLLINK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_CLOYSTER] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 95,
		.baseDefense 	= 180,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ICE,
		.catchRate = 60,
		.expYield = 203,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PEARL,
		.item2 = ITEM_BIG_PEARL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SHELLARMOR,
		.ability2 = ABILITY_SKILLLINK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_GASTLY] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 35,
		.baseDefense 	= 30,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 80,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_POISON,
		.catchRate = 190,
		.expYield = 95,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_HAUNTER] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 50,
		.baseDefense 	= 45,
		.baseSpAttack 	= 115,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 95,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_POISON,
		.catchRate = 90,
		.expYield = 126,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GENGAR] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 65,
		.baseDefense 	= 60,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 110,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 190,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_CURSEDBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ONIX] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 45,
		.baseDefense 	= 160,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 70,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 108,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_DROWZEE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 48,
		.baseDefense 	= 45,
		.baseSpAttack 	= 43,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 42,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 190,
		.expYield = 102,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_INSOMNIA,
		.ability2 = ABILITY_FOREWARN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_HYPNO] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 73,
		.baseDefense 	= 70,
		.baseSpAttack 	= 73,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 67,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 75,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_INSOMNIA,
		.ability2 = ABILITY_FOREWARN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_KRABBY] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 105,
		.baseDefense 	= 90,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 50,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 225,
		.expYield = 115,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHELLARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_KINGLER] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 130,
		.baseDefense 	= 115,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 75,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 206,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHELLARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_VOLTORB] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 30,
		.baseDefense 	= 50,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 100,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 103,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SOUNDPROOF,
		.ability2 = ABILITY_STATIC,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AFTERMATH,
		.noFlip = TRUE,
	},

	[SPECIES_ELECTRODE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 50,
		.baseDefense 	= 70,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 150,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 60,
		.expYield = 150,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SOUNDPROOF,
		.ability2 = ABILITY_STATIC,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AFTERMATH,
		.noFlip = TRUE,
	},

	[SPECIES_EXEGGCUTE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 40,
		.baseDefense 	= 80,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 40,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 90,
		.expYield = 98,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PSYCHIC_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_HARVEST,
		.safariZoneFleeRate = 75,
		.hiddenAbility = ABILITY_HARVEST,
		.noFlip = TRUE,
	},

	[SPECIES_EXEGGUTOR] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 85,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 55,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 212,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_HARVEST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HARVEST,
		.noFlip = TRUE,
	},

	[SPECIES_CUBONE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 50,
		.baseDefense 	= 95,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 35,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 190,
		.expYield = 87,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_THICK_CLUB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BATTLEARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_MAROWAK] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 80,
		.baseDefense 	= 110,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 45,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 75,
		.expYield = 124,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_THICK_CLUB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BATTLEARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_HITMONLEE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 120,
		.baseDefense 	= 53,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 87,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 139,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_UNBURDEN,
		.ability2 = ABILITY_RECKLESS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIMBER,
		.noFlip = TRUE,
	},

	[SPECIES_HITMONCHAN] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 105,
		.baseDefense 	= 79,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 76,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 140,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_IRONFIST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_LICKITUNG] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 55,
		.baseDefense 	= 75,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 30,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 127,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LAGGING_TAIL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_CLOUDNINE,
		.ability2 = ABILITY_OBLIVIOUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_KOFFING] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 65,
		.baseDefense 	= 95,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 35,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 190,
		.expYield = 114,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SMOKE_BALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NEUTRALIZINGGAS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_WEEZING] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 90,
		.baseDefense 	= 120,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 60,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 60,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SMOKE_BALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NEUTRALIZINGGAS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_RHYHORN] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 85,
		.baseDefense 	= 95,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 25,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_ROCK,
		.catchRate = 120,
		.expYield = 135,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_ROCKHEAD,
		.safariZoneFleeRate = 75,
		.hiddenAbility = ABILITY_RECKLESS,
		.noFlip = TRUE,
	},

	[SPECIES_RHYDON] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 130,
		.baseDefense 	= 120,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 40,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_ROCK,
		.catchRate = 60,
		.expYield = 204,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_ROCKHEAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RECKLESS,
		.noFlip = TRUE,
	},

	[SPECIES_CHANSEY] =
	{
		.baseHP 		= 250,
		.baseAttack 	= 5,
		.baseDefense 	= 5,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 50,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 30,
		.expYield = 255,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LUCKY_PUNCH,
		.item2 = ITEM_LUCKY_EGG,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 40,
		.friendship = 140,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_SERENEGRACE,
		.safariZoneFleeRate = 125,
		.hiddenAbility = ABILITY_HEALER,
		.noFlip = TRUE,
	},

	[SPECIES_TANGELA] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 55,
		.baseDefense 	= 115,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 60,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LEAFGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_KANGASKHAN] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 95,
		.baseDefense 	= 80,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 90,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 175,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_EARLYBIRD,
		.ability2 = ABILITY_SCRAPPY,
		.safariZoneFleeRate = 125,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_HORSEA] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 40,
		.baseDefense 	= 70,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 225,
		.expYield = 83,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_SEADRA] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 65,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 85,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 75,
		.expYield = 155,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_GOLDEEN] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 67,
		.baseDefense 	= 60,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 63,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 225,
		.expYield = 111,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MYSTIC_WATER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 50,
		.hiddenAbility = ABILITY_WATERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_SEAKING] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 92,
		.baseDefense 	= 65,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 68,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MYSTIC_WATER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 75,
		.hiddenAbility = ABILITY_WATERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_STARYU] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 45,
		.baseDefense 	= 55,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 85,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 225,
		.expYield = 106,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_STARDUST,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_ANALYTIC,
		.ability2 = ABILITY_NATURALCURE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ILLUMINATE,
		.noFlip = TRUE,
	},

	[SPECIES_STARMIE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 75,
		.baseDefense 	= 85,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 115,
		.type1 = TYPE_WATER,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 60,
		.expYield = 207,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_STARDUST,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_ANALYTIC,
		.ability2 = ABILITY_NATURALCURE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ILLUMINATE,
		.noFlip = TRUE,
	},

	[SPECIES_MR_MIME] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 65,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 90,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 136,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LEPPA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SOUNDPROOF,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FILTER,
		.noFlip = TRUE,
	},

	[SPECIES_SCYTHER] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 110,
		.baseDefense 	= 80,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 105,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 187,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 125,
		.hiddenAbility = ABILITY_STEADFAST,
		.noFlip = TRUE,
	},

	[SPECIES_JYNX] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 50,
		.baseDefense 	= 35,
		.baseSpAttack 	= 115,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_ICE,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 137,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ASPEAR_BERRY,
		.item2 = ITEM_ASPEAR_BERRY,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_DRYSKIN,
		.ability2 = ABILITY_FOREWARN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_ELECTABUZZ] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 83,
		.baseDefense 	= 57,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 105,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 156,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ELECTIRIZER,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VITALSPIRIT,
		.noFlip = TRUE,
	},

	[SPECIES_MAGMAR] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 95,
		.baseDefense 	= 57,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 93,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 167,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MAGMARIZER,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_FLAMEBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VITALSPIRIT,
		.noFlip = TRUE,
	},

	[SPECIES_PINSIR] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 125,
		.baseDefense 	= 100,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 85,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 45,
		.expYield = 200,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_MOXIE,
		.ability2 = ABILITY_MOLDBREAKER,
		.safariZoneFleeRate = 125,
		.hiddenAbility = ABILITY_HYPERCUTTER,
		.noFlip = TRUE,
	},

	[SPECIES_TAUROS] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 100,
		.baseDefense 	= 95,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 110,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 211,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 125,
		.hiddenAbility = ABILITY_ANGERPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_MAGIKARP] =
	{
		.baseHP 		= 20,
		.baseAttack 	= 10,
		.baseDefense 	= 55,
		.baseSpAttack 	= 15,
		.baseSpDefense 	= 20,
		.baseSpeed 		= 80,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 255,
		.expYield = 20,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 5,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_RATTLED,
		.safariZoneFleeRate = 25,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_GYARADOS] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 125,
		.baseDefense 	= 79,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 81,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 154,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 5,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_MOXIE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOXIE,
		.noFlip = TRUE,
	},

	[SPECIES_LAPRAS] =
	{
		.baseHP 		= 130,
		.baseAttack 	= 85,
		.baseDefense 	= 80,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 219,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_MYSTIC_WATER,
		.item2 = ITEM_MYSTIC_WATER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYDRATION,
		.noFlip = TRUE,
	},

	[SPECIES_DITTO] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 48,
		.baseDefense 	= 48,
		.baseSpAttack 	= 48,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 35,
		.expYield = 61,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_QUICK_POWDER,
		.item2 = ITEM_METAL_POWDER,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_DITTO,
		.eggGroup2 = EGG_GROUP_DITTO,
		.ability1 = ABILITY_LIMBER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_IMPOSTER,
		.noFlip = TRUE,
	},

	[SPECIES_EEVEE] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 55,
		.baseDefense 	= 50,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 55,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 92,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_ADAPTABILITY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANTICIPATION,
		.noFlip = TRUE,
	},

	[SPECIES_VAPOREON] =
	{
		.baseHP 		= 130,
		.baseAttack 	= 65,
		.baseDefense 	= 60,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 65,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 196,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYDRATION,
		.noFlip = TRUE,
	},

	[SPECIES_JOLTEON] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 65,
		.baseDefense 	= 60,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 130,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 197,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_VOLTABSORB,
		.ability2 = ABILITY_VOLTABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_QUICKFEET,
		.noFlip = TRUE,
	},

	[SPECIES_FLAREON] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 130,
		.baseDefense 	= 60,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 198,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_FLASHFIRE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GUTS,
		.noFlip = TRUE,
	},

	[SPECIES_PORYGON] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 70,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 40,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_TRACE,
		.ability2 = ABILITY_DOWNLOAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_OMANYTE] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 40,
		.baseDefense 	= 100,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 35,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_OMASTAR] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 60,
		.baseDefense 	= 125,
		.baseSpAttack 	= 115,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 55,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_KABUTO] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 80,
		.baseDefense 	= 90,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 55,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_BATTLEARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_KABUTOPS] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 115,
		.baseDefense 	= 105,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 80,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_BATTLEARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_AERODACTYL] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 105,
		.baseDefense 	= 65,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 130,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 202,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_UNNERVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRESSURE,
		.noFlip = TRUE,
	},

	[SPECIES_SNORLAX] =
	{
		.baseHP 		= 160,
		.baseAttack 	= 110,
		.baseDefense 	= 65,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 30,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 25,
		.expYield = 213,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LEFTOVERS,
		.item2 = ITEM_LEFTOVERS,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_IMMUNITY,
		.ability2 = ABILITY_THICKFAT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},

	[SPECIES_ARTICUNO] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 85,
		.baseDefense 	= 100,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 125,
		.baseSpeed 		= 85,
		.type1 = TYPE_ICE,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SNOWCLOAK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRESSURE,
		.noFlip = TRUE,
	},

	[SPECIES_ZAPDOS] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 90,
		.baseDefense 	= 85,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 100,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 216,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRESSURE,
		.noFlip = TRUE,
	},

	[SPECIES_MOLTRES] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 100,
		.baseDefense 	= 90,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 90,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 217,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_FLAMEBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRESSURE,
		.noFlip = TRUE,
	},

	[SPECIES_DRATINI] =
	{
		.baseHP 		= 41,
		.baseAttack 	= 64,
		.baseDefense 	= 45,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 50,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_MARVELSCALE,
		.safariZoneFleeRate = 100,
		.hiddenAbility = ABILITY_MARVELSCALE,
		.noFlip = TRUE,
	},

	[SPECIES_DRAGONAIR] =
	{
		.baseHP 		= 61,
		.baseAttack 	= 84,
		.baseDefense 	= 65,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 70,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_MARVELSCALE,
		.safariZoneFleeRate = 125,
		.hiddenAbility = ABILITY_MARVELSCALE,
		.noFlip = TRUE,
	},

	[SPECIES_DRAGONITE] =
	{
		.baseHP 		= 91,
		.baseAttack 	= 134,
		.baseDefense 	= 95,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 80,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_MULTISCALE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MULTISCALE,
		.noFlip = TRUE,
	},

	[SPECIES_MEWTWO] =
	{
		.baseHP 		= 106,
		.baseAttack 	= 110,
		.baseDefense 	= 90,
		.baseSpAttack 	= 154,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 130,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_MEW] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 215,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LUM_BERRY,
		.item2 = ITEM_LUM_BERRY,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CHIKORITA] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 49,
		.baseDefense 	= 65,
		.baseSpAttack 	= 49,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 45,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 64,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LEAFGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_BAYLEEF] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 62,
		.baseDefense 	= 80,
		.baseSpAttack 	= 63,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 60,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 141,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LEAFGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_MEGANIUM] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 82,
		.baseDefense 	= 100,
		.baseSpAttack 	= 83,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 80,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LEAFGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_CYNDAQUIL] =
	{
		.baseHP 		= 39,
		.baseAttack 	= 52,
		.baseDefense 	= 43,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLASHFIRE,
		.noFlip = TRUE,
	},

	[SPECIES_QUILAVA] =
	{
		.baseHP 		= 58,
		.baseAttack 	= 64,
		.baseDefense 	= 58,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 80,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 142,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLASHFIRE,
		.noFlip = TRUE,
	},

	[SPECIES_TYPHLOSION] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 84,
		.baseDefense 	= 78,
		.baseSpAttack 	= 109,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLASHFIRE,
		.noFlip = TRUE,
	},

	[SPECIES_TOTODILE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 64,
		.baseSpAttack 	= 44,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 43,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 66,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_CROCONAW] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 80,
		.baseDefense 	= 80,
		.baseSpAttack 	= 59,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 58,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 143,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_FERALIGATR] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 105,
		.baseDefense 	= 100,
		.baseSpAttack 	= 79,
		.baseSpDefense 	= 83,
		.baseSpeed 		= 78,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_SENTRET] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 46,
		.baseDefense 	= 34,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 20,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 57,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ORAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_KEENEYE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},

	[SPECIES_FURRET] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 76,
		.baseDefense 	= 64,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 90,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 90,
		.expYield = 116,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_SITRUS_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_KEENEYE,
		.safariZoneFleeRate = 90,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},

	[SPECIES_HOOTHOOT] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 30,
		.baseDefense 	= 30,
		.baseSpAttack 	= 36,
		.baseSpDefense 	= 56,
		.baseSpeed 		= 50,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 58,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_INSOMNIA,
		.ability2 = ABILITY_KEENEYE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TINTEDLENS,
		.noFlip = TRUE,
	},

	[SPECIES_NOCTOWL] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 50,
		.baseDefense 	= 50,
		.baseSpAttack 	= 86,
		.baseSpDefense 	= 96,
		.baseSpeed 		= 70,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 90,
		.expYield = 162,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_INSOMNIA,
		.ability2 = ABILITY_KEENEYE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TINTEDLENS,
		.noFlip = TRUE,
	},

	[SPECIES_LEDYBA] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 20,
		.baseDefense 	= 30,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 55,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 54,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_EARLYBIRD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_LEDIAN] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 35,
		.baseDefense 	= 50,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 85,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 90,
		.expYield = 134,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_EARLYBIRD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_IRONFIST,
		.noFlip = TRUE,
	},

	[SPECIES_SPINARAK] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 60,
		.baseDefense 	= 40,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 30,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 255,
		.expYield = 54,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_INSOMNIA,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNIPER,
		.noFlip = TRUE,
	},

	[SPECIES_ARIADOS] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 90,
		.baseDefense 	= 70,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 40,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 90,
		.expYield = 134,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_INSOMNIA,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNIPER,
		.noFlip = TRUE,
	},

	[SPECIES_CROBAT] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 90,
		.baseDefense 	= 80,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 130,
		.type1 = TYPE_POISON,
		.type2 = TYPE_FLYING,
		.catchRate = 90,
		.expYield = 204,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_CHINCHOU] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 38,
		.baseDefense 	= 38,
		.baseSpAttack 	= 56,
		.baseSpDefense 	= 56,
		.baseSpeed 		= 67,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 90,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DEEP_SEA_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_VOLTABSORB,
		.ability2 = ABILITY_ILLUMINATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERABSORB,
		.noFlip = TRUE,
	},

	[SPECIES_LANTURN] =
	{
		.baseHP 		= 125,
		.baseAttack 	= 58,
		.baseDefense 	= 58,
		.baseSpAttack 	= 76,
		.baseSpDefense 	= 76,
		.baseSpeed 		= 67,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 75,
		.expYield = 156,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DEEP_SEA_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_VOLTABSORB,
		.ability2 = ABILITY_ILLUMINATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERABSORB,
		.noFlip = TRUE,
	},

	[SPECIES_PICHU] =
	{
		.baseHP 		= 20,
		.baseAttack 	= 40,
		.baseDefense 	= 15,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 60,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 42,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ORAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},

	[SPECIES_CLEFFA] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 25,
		.baseDefense 	= 28,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 15,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 150,
		.expYield = 37,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LEPPA_BERRY,
		.item2 = ITEM_MOON_STONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 10,
		.friendship = 140,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_IGGLYBUFF] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 30,
		.baseDefense 	= 15,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 20,
		.baseSpeed 		= 15,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FAIRY,
		.catchRate = 170,
		.expYield = 39,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_COMPETITIVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_TOGEPI] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 20,
		.baseDefense 	= 65,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 20,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 190,
		.expYield = 74,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SUPERLUCK,
		.ability2 = ABILITY_SERENEGRACE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HUSTLE,
		.noFlip = TRUE,
	},

	[SPECIES_TOGETIC] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 40,
		.baseDefense 	= 85,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 40,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FLYING,
		.catchRate = 75,
		.expYield = 114,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_SUPERLUCK,
		.ability2 = ABILITY_SERENEGRACE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HUSTLE,
		.noFlip = TRUE,
	},

	[SPECIES_NATU] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 50,
		.baseDefense 	= 45,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 70,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FLYING,
		.catchRate = 190,
		.expYield = 73,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_MAGICBOUNCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_EARLYBIRD,
		.noFlip = TRUE,
	},

	[SPECIES_XATU] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 75,
		.baseDefense 	= 70,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 95,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FLYING,
		.catchRate = 75,
		.expYield = 171,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_MAGICBOUNCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_EARLYBIRD,
		.noFlip = TRUE,
	},

	[SPECIES_MAREEP] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 40,
		.baseDefense 	= 40,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 35,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 235,
		.expYield = 59,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PLUS,
		.noFlip = TRUE,
	},

	[SPECIES_FLAAFFY] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 55,
		.baseDefense 	= 55,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 45,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 120,
		.expYield = 117,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PLUS,
		.noFlip = TRUE,
	},

	[SPECIES_AMPHAROS] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 75,
		.baseDefense 	= 85,
		.baseSpAttack 	= 115,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 55,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 194,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PLUS,
		.noFlip = TRUE,
	},

	[SPECIES_BELLOSSOM] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 95,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 50,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 184,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ABSORB_BULB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEALER,
		.noFlip = TRUE,
	},

	[SPECIES_MARILL] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 20,
		.baseDefense 	= 50,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 40,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FAIRY,
		.catchRate = 190,
		.expYield = 58,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_HUGEPOWER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SAPSIPPER,
		.noFlip = TRUE,
	},

	[SPECIES_AZUMARILL] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 50,
		.baseDefense 	= 80,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 50,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FAIRY,
		.catchRate = 75,
		.expYield = 153,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_HUGEPOWER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SAPSIPPER,
		.noFlip = TRUE,
	},

	[SPECIES_SUDOWOODO] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 100,
		.baseDefense 	= 115,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 30,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 65,
		.expYield = 135,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_ROCKHEAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_POLITOED] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 75,
		.baseDefense 	= 75,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_KINGS_ROCK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_DRIZZLE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_HOPPIP] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 35,
		.baseDefense 	= 40,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 50,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 74,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_LEAFGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_SKIPLOOM] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 45,
		.baseDefense 	= 50,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 80,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FLYING,
		.catchRate = 120,
		.expYield = 136,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_LEAFGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_JUMPLUFF] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 55,
		.baseDefense 	= 70,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 110,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 176,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_LEAFGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_AIPOM] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 70,
		.baseDefense 	= 55,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 85,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 94,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SKILLLINK,
		.ability2 = ABILITY_RUNAWAY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKUP,
		.noFlip = TRUE,
	},

	[SPECIES_SUNKERN] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 30,
		.baseDefense 	= 30,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 235,
		.expYield = 52,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_COBA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SOLARPOWER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_EARLYBIRD,
		.noFlip = TRUE,
	},

	[SPECIES_SUNFLORA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 75,
		.baseDefense 	= 55,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 120,
		.expYield = 146,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SOLARPOWER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_EARLYBIRD,
		.noFlip = TRUE,
	},

	[SPECIES_YANMA] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 65,
		.baseDefense 	= 45,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 95,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 75,
		.expYield = 147,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_WIDE_LENS,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SPEEDBOOST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},

	[SPECIES_WOOPER] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 45,
		.baseDefense 	= 45,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 15,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 255,
		.expYield = 52,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_UNAWARE,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_QUAGSIRE] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 85,
		.baseDefense 	= 85,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 35,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 90,
		.expYield = 137,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_UNAWARE,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_ESPEON] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 65,
		.baseDefense 	= 60,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 110,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 197,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_MAGICBOUNCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MAGICBOUNCE,
		.noFlip = TRUE,
	},

	[SPECIES_UMBREON] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 65,
		.baseDefense 	= 110,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 65,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 197,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_SYNCHRONIZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_MURKROW] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 85,
		.baseDefense 	= 42,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 42,
		.baseSpeed 		= 91,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 107,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_SUPERLUCK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_SLOWKING] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 75,
		.baseDefense 	= 80,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 30,
		.type1 = TYPE_WATER,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 70,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_KINGS_ROCK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_OBLIVIOUS,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_MISDREAVUS] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 60,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 85,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 147,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_WOBBUFFET] =
	{
		.baseHP 		= 190,
		.baseAttack 	= 33,
		.baseDefense 	= 58,
		.baseSpAttack 	= 33,
		.baseSpDefense 	= 58,
		.baseSpeed 		= 33,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SHADOWTAG,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_GIRAFARIG] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 80,
		.baseDefense 	= 65,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 85,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 60,
		.expYield = 149,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PERSIM_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_EARLYBIRD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SAPSIPPER,
		.noFlip = TRUE,
	},

	[SPECIES_PINECO] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 90,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 15,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 190,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_FORRETRESS] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 90,
		.baseDefense 	= 140,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 40,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 75,
		.expYield = 118,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_DUNSPARCE] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 70,
		.baseDefense 	= 70,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 45,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 190,
		.expYield = 125,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SERENEGRACE,
		.ability2 = ABILITY_RUNAWAY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_GLIGAR] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 75,
		.baseDefense 	= 105,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 85,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_FLYING,
		.catchRate = 60,
		.expYield = 108,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_SANDVEIL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_IMMUNITY,
		.noFlip = TRUE,
	},

	[SPECIES_STEELIX] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 85,
		.baseDefense 	= 200,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 30,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_GROUND,
		.catchRate = 25,
		.expYield = 196,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_SNUBBULL] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 80,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 30,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 190,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_RUNAWAY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_GRANBULL] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 120,
		.baseDefense 	= 75,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 45,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 75,
		.expYield = 178,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_QUICKFEET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_QWILFISH] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 95,
		.baseDefense 	= 85,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 85,
		.type1 = TYPE_WATER,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 100,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_SWIFTSWIM,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INTIMIDATE,
		.noFlip = TRUE,
	},

	[SPECIES_SCIZOR] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 130,
		.baseDefense 	= 100,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 65,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 25,
		.expYield = 200,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_SHUCKLE] =
	{
		.baseHP 		= 20,
		.baseAttack 	= 10,
		.baseDefense 	= 230,
		.baseSpAttack 	= 10,
		.baseSpDefense 	= 230,
		.baseSpeed 		= 5,
		.type1 = TYPE_BUG,
		.type2 = TYPE_ROCK,
		.catchRate = 190,
		.expYield = 80,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_BERRY_JUICE,
		.item2 = ITEM_BERRY_JUICE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CONTRARY,
		.noFlip = TRUE,
	},

	[SPECIES_HERACROSS] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 125,
		.baseDefense 	= 75,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 85,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 200,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_MOXIE,
		.ability2 = ABILITY_GUTS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWARM,
		.noFlip = TRUE,
	},

	[SPECIES_SNEASEL] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 95,
		.baseDefense 	= 55,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 115,
		.type1 = TYPE_DARK,
		.type2 = TYPE_ICE,
		.catchRate = 200,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_GRIP_CLAW,
		.item2 = ITEM_QUICK_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_PICKPOCKET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_TEDDIURSA] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 80,
		.baseDefense 	= 50,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 40,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 120,
		.expYield = 124,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_SITRUS_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_QUICKFEET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HONEYGATHER,
		.noFlip = TRUE,
	},

	[SPECIES_URSARING] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 130,
		.baseDefense 	= 75,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 55,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 60,
		.expYield = 189,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_SITRUS_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_QUICKFEET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_SLUGMA] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 40,
		.baseDefense 	= 40,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 20,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 190,
		.expYield = 78,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_MAGMAARMOR,
		.ability2 = ABILITY_FLAMEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_MAGCARGO] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 50,
		.baseDefense 	= 120,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 30,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_ROCK,
		.catchRate = 75,
		.expYield = 154,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_MAGMAARMOR,
		.ability2 = ABILITY_FLAMEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_SWINUB] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 50,
		.baseDefense 	= 40,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 50,
		.type1 = TYPE_ICE,
		.type2 = TYPE_GROUND,
		.catchRate = 225,
		.expYield = 78,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ASPEAR_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_SNOWCLOAK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_PILOSWINE] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 80,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 50,
		.type1 = TYPE_ICE,
		.type2 = TYPE_GROUND,
		.catchRate = 75,
		.expYield = 160,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ASPEAR_BERRY,
		.item2 = ITEM_NEVER_MELT_ICE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_SNOWCLOAK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_CORSOLA] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 55,
		.baseDefense 	= 95,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 35,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ROCK,
		.catchRate = 60,
		.expYield = 113,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LUMINOUS_MOSS,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_HUSTLE,
		.ability2 = ABILITY_NATURALCURE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_REGENERATOR,
		.noFlip = TRUE,
	},

	[SPECIES_REMORAID] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 65,
		.baseDefense 	= 35,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 65,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 78,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_HUSTLE,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOODY,
		.noFlip = TRUE,
	},

	[SPECIES_OCTILLERY] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 105,
		.baseDefense 	= 75,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 45,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 75,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SUCTIONCUPS,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOODY,
		.noFlip = TRUE,
	},

	[SPECIES_DELIBIRD] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 55,
		.baseDefense 	= 45,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 75,
		.type1 = TYPE_ICE,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 183,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_VITALSPIRIT,
		.ability2 = ABILITY_HUSTLE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_MANTINE] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 40,
		.baseDefense 	= 70,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 140,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FLYING,
		.catchRate = 25,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_SKARMORY] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 80,
		.baseDefense 	= 140,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 70,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_FLYING,
		.catchRate = 25,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_HOUNDOUR] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 60,
		.baseDefense 	= 30,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 65,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FIRE,
		.catchRate = 120,
		.expYield = 114,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_EARLYBIRD,
		.ability2 = ABILITY_FLASHFIRE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_HOUNDOOM] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 90,
		.baseDefense 	= 50,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 95,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 204,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_EARLYBIRD,
		.ability2 = ABILITY_FLASHFIRE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_KINGDRA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 85,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 207,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_PHANPY] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 60,
		.baseDefense 	= 60,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 40,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 120,
		.expYield = 124,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PASSHO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_SANDVEIL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_DONPHAN] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 50,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 60,
		.expYield = 189,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PASSHO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_SANDVEIL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_PORYGON2] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 80,
		.baseDefense 	= 90,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 180,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_UP_GRADE,
		.item2 = ITEM_UP_GRADE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_TRACE,
		.ability2 = ABILITY_DOWNLOAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_STANTLER] =
	{
		.baseHP 		= 73,
		.baseAttack 	= 95,
		.baseDefense 	= 62,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 85,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SAPSIPPER,
		.noFlip = TRUE,
	},

	[SPECIES_SMEARGLE] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 20,
		.baseDefense 	= 35,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 75,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 106,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_OWNTEMPO,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOODY,
		.noFlip = TRUE,
	},

	[SPECIES_TYROGUE] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 35,
		.baseDefense 	= 35,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 35,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 75,
		.expYield = 91,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_STEADFAST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VITALSPIRIT,
		.noFlip = TRUE,
	},

	[SPECIES_HITMONTOP] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 70,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 138,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STEADFAST,
		.noFlip = TRUE,
	},

	[SPECIES_SMOOCHUM] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 30,
		.baseDefense 	= 15,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 65,
		.type1 = TYPE_ICE,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 87,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ASPEAR_BERRY,
		.item2 = ITEM_ASPEAR_BERRY,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_HYDRATION,
		.ability2 = ABILITY_FOREWARN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_ELEKID] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 63,
		.baseDefense 	= 37,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 95,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 106,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ELECTIRIZER,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VITALSPIRIT,
		.noFlip = TRUE,
	},

	[SPECIES_MAGBY] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 75,
		.baseDefense 	= 37,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 83,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 117,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MAGMARIZER,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_FLAMEBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VITALSPIRIT,
		.noFlip = TRUE,
	},

	[SPECIES_MILTANK] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 80,
		.baseDefense 	= 105,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 100,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 200,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_MOOMOO_MILK,
		.item2 = ITEM_MOOMOO_MILK,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_SCRAPPY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SAPSIPPER,
		.noFlip = TRUE,
	},

	[SPECIES_BLISSEY] =
	{
		.baseHP 		= 255,
		.baseAttack 	= 10,
		.baseDefense 	= 10,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 135,
		.baseSpeed 		= 55,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 30,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LUCKY_EGG,
		.item2 = ITEM_LUCKY_EGG,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 40,
		.friendship = 140,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_SERENEGRACE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEALER,
		.noFlip = TRUE,
	},

	[SPECIES_RAIKOU] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 85,
		.baseDefense 	= 75,
		.baseSpAttack 	= 115,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 115,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 3,
		.expYield = 216,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_ENTEI] =
	{
		.baseHP 		= 115,
		.baseAttack 	= 115,
		.baseDefense 	= 85,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 3,
		.expYield = 217,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_SUICUNE] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 75,
		.baseDefense 	= 115,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 85,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_LARVITAR] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 64,
		.baseDefense 	= 50,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 41,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_PUPITAR] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 84,
		.baseDefense 	= 70,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 51,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TYRANITAR] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 134,
		.baseDefense 	= 110,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 61,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_SANDSTREAM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_LUGIA] =
	{
		.baseHP 		= 106,
		.baseAttack 	= 90,
		.baseDefense 	= 130,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 154,
		.baseSpeed 		= 110,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MULTISCALE,
		.noFlip = TRUE,
	},

	[SPECIES_HO_OH] =
	{
		.baseHP 		= 106,
		.baseAttack 	= 130,
		.baseDefense 	= 90,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 154,
		.baseSpeed 		= 90,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_SACRED_ASH,
		.item2 = ITEM_SACRED_ASH,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_REGENERATOR,
		.noFlip = TRUE,
	},

	[SPECIES_CELEBI] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 215,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LUM_BERRY,
		.item2 = ITEM_LUM_BERRY,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TREECKO] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 50,
		.baseDefense 	= 35,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 70,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNBURDEN,
		.noFlip = TRUE,
	},

	[SPECIES_GROVYLE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 70,
		.baseDefense 	= 45,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 95,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 141,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNBURDEN,
		.noFlip = TRUE,
	},

	[SPECIES_SCEPTILE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 100,
		.baseDefense 	= 65,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 120,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNBURDEN,
		.noFlip = TRUE,
	},

	[SPECIES_TORCHIC] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 60,
		.baseDefense 	= 40,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 45,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_SPEEDBOOST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SPEEDBOOST,
		.noFlip = TRUE,
	},

	[SPECIES_COMBUSKEN] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 85,
		.baseDefense 	= 60,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 55,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 142,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_SPEEDBOOST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SPEEDBOOST,
		.noFlip = TRUE,
	},

	[SPECIES_BLAZIKEN] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 120,
		.baseDefense 	= 70,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 80,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_SPEEDBOOST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SPEEDBOOST,
		.noFlip = TRUE,
	},

	[SPECIES_MUDKIP] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 70,
		.baseDefense 	= 50,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 40,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_DAMP,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_MARSHTOMP] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 85,
		.baseDefense 	= 70,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 50,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 143,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_DAMP,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_SWAMPERT] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 110,
		.baseDefense 	= 90,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_DAMP,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_POOCHYENA] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 35,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 35,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 255,
		.expYield = 55,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PECHA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_RATTLED,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_QUICKFEET,
		.noFlip = TRUE,
	},

	[SPECIES_MIGHTYENA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 90,
		.baseDefense 	= 70,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 70,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 127,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PECHA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_MOXIE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_QUICKFEET,
		.noFlip = TRUE,
	},

	[SPECIES_ZIGZAGOON] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 30,
		.baseDefense 	= 41,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 41,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_POTION,
		.item2 = ITEM_REVIVE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_QUICKFEET,
		.noFlip = TRUE,
	},

	[SPECIES_LINOONE] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 70,
		.baseDefense 	= 61,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 61,
		.baseSpeed 		= 100,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 90,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_POTION,
		.item2 = ITEM_MAX_REVIVE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_QUICKFEET,
		.noFlip = TRUE,
	},

	[SPECIES_WURMPLE] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 45,
		.baseDefense 	= 35,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 20,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 255,
		.expYield = 54,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_BRIGHT_POWDER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RUNAWAY,
		.noFlip = TRUE,
	},

	[SPECIES_SILCOON] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 35,
		.baseDefense 	= 55,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 15,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 120,
		.expYield = 72,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEDSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_BEAUTIFLY] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 70,
		.baseDefense 	= 50,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 65,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 161,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHED_SHELL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_CASCOON] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 35,
		.baseDefense 	= 55,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 15,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 120,
		.expYield = 72,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEDSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_DUSTOX] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 50,
		.baseDefense 	= 70,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 65,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 161,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHED_SHELL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_COMPOUNDEYES,
		.noFlip = TRUE,
	},

	[SPECIES_LOTAD] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 30,
		.baseDefense 	= 30,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 30,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GRASS,
		.catchRate = 255,
		.expYield = 74,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MENTAL_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_RAINDISH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_LOMBRE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 50,
		.baseDefense 	= 50,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 50,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GRASS,
		.catchRate = 120,
		.expYield = 141,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MENTAL_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_RAINDISH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_LUDICOLO] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 70,
		.baseDefense 	= 70,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 181,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MENTAL_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_RAINDISH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_SEEDOT] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 40,
		.baseDefense 	= 50,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 255,
		.expYield = 74,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POWER_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_EARLYBIRD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKPOCKET,
		.noFlip = TRUE,
	},

	[SPECIES_NUZLEAF] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 70,
		.baseDefense 	= 40,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 60,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DARK,
		.catchRate = 120,
		.expYield = 141,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POWER_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_EARLYBIRD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKPOCKET,
		.noFlip = TRUE,
	},

	[SPECIES_SHIFTRY] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 80,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 181,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POWER_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_EARLYBIRD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKPOCKET,
		.noFlip = TRUE,
	},

	[SPECIES_NINCADA] =
	{
		.baseHP 		= 31,
		.baseAttack 	= 45,
		.baseDefense 	= 90,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 40,
		.type1 = TYPE_BUG,
		.type2 = TYPE_GROUND,
		.catchRate = 255,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SOFT_SAND,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_COMPOUNDEYES,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RUNAWAY,
		.noFlip = TRUE,
	},

	[SPECIES_NINJASK] =
	{
		.baseHP 		= 61,
		.baseAttack 	= 90,
		.baseDefense 	= 45,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 160,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 120,
		.expYield = 155,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SPEEDBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_SHEDINJA] =
	{
		.baseHP 		= 1,
		.baseAttack 	= 90,
		.baseDefense 	= 45,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 40,
		.type1 = TYPE_BUG,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 95,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_WONDERGUARD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TAILLOW] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 55,
		.baseDefense 	= 30,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 85,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 200,
		.expYield = 59,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHARTI_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_SCRAPPY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SCRAPPY,
		.noFlip = TRUE,
	},

	[SPECIES_SWELLOW] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 85,
		.baseDefense 	= 60,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 125,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 162,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHARTI_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_SCRAPPY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SCRAPPY,
		.noFlip = TRUE,
	},

	[SPECIES_SHROOMISH] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 40,
		.baseDefense 	= 60,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 35,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 255,
		.expYield = 65,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_TINY_MUSHROOM,
		.item2 = ITEM_KEBIA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_QUICKFEET,
		.ability2 = ABILITY_POISONHEAL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_EFFECTSPORE,
		.noFlip = TRUE,
	},

	[SPECIES_BRELOOM] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 130,
		.baseDefense 	= 80,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 70,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FIGHTING,
		.catchRate = 90,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_TINY_MUSHROOM,
		.item2 = ITEM_KEBIA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_TECHNICIAN,
		.ability2 = ABILITY_POISONHEAL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_EFFECTSPORE,
		.noFlip = TRUE,
	},

	[SPECIES_SPINDA] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 60,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 85,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHESTO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_OWNTEMPO,
		.ability2 = ABILITY_TANGLEDFEET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CONTRARY,
		.noFlip = TRUE,
	},

	[SPECIES_WINGULL] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 30,
		.baseDefense 	= 30,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 85,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FLYING,
		.catchRate = 190,
		.expYield = 64,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_PRETTY_WING,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_RAINDISH,
		.ability2 = ABILITY_HYDRATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_PELIPPER] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 50,
		.baseDefense 	= 100,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 65,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PRETTY_WING,
		.item2 = ITEM_LUCKY_EGG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_RAINDISH,
		.ability2 = ABILITY_DRIZZLE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_SURSKIT] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 30,
		.baseDefense 	= 32,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 52,
		.baseSpeed 		= 65,
		.type1 = TYPE_BUG,
		.type2 = TYPE_WATER,
		.catchRate = 200,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HONEY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RAINDISH,
		.noFlip = TRUE,
	},

	[SPECIES_MASQUERAIN] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 60,
		.baseDefense 	= 62,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 82,
		.baseSpeed 		= 80,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 75,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SILVER_POWDER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_WAILMER] =
	{
		.baseHP 		= 130,
		.baseAttack 	= 70,
		.baseDefense 	= 35,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 125,
		.expYield = 137,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_WATERVEIL,
		.ability2 = ABILITY_OBLIVIOUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRESSURE,
		.noFlip = TRUE,
	},

	[SPECIES_WAILORD] =
	{
		.baseHP 		= 170,
		.baseAttack 	= 90,
		.baseDefense 	= 45,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 206,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_WATERVEIL,
		.ability2 = ABILITY_OBLIVIOUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRESSURE,
		.noFlip = TRUE,
	},

	[SPECIES_SKITTY] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 45,
		.baseDefense 	= 45,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 50,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_LEPPA_BERRY,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_NORMALIZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WONDERSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_DELCATTY] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 90,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 60,
		.expYield = 138,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_LEPPA_BERRY,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_NORMALIZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WONDERSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_KECLEON] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 90,
		.baseDefense 	= 70,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 40,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 200,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PERSIM_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_COLORCHANGE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PROTEAN,
		.noFlip = TRUE,
	},

	[SPECIES_BALTOY] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 40,
		.baseDefense 	= 55,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 55,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 255,
		.expYield = 58,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LIGHT_CLAY,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CLAYDOL] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 70,
		.baseDefense 	= 105,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 75,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 90,
		.expYield = 189,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LIGHT_CLAY,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_NOSEPASS] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 45,
		.baseDefense 	= 135,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 30,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 255,
		.expYield = 108,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MAGNET,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_MAGNETPULL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_TORKOAL] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 85,
		.baseDefense 	= 140,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 20,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 90,
		.expYield = 161,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHARCOAL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_WHITESMOKE,
		.ability2 = ABILITY_DROUGHT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHELLARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_SABLEYE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 75,
		.baseDefense 	= 75,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 50,
		.type1 = TYPE_DARK,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 98,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_WIDE_LENS,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_STALL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRANKSTER,
		.noFlip = TRUE,
	},

	[SPECIES_BARBOACH] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 48,
		.baseDefense 	= 43,
		.baseSpAttack 	= 46,
		.baseSpDefense 	= 41,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 190,
		.expYield = 92,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_OBLIVIOUS,
		.ability2 = ABILITY_ANTICIPATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYDRATION,
		.noFlip = TRUE,
	},

	[SPECIES_WHISCASH] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 78,
		.baseDefense 	= 73,
		.baseSpAttack 	= 76,
		.baseSpDefense 	= 71,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 75,
		.expYield = 158,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_OBLIVIOUS,
		.ability2 = ABILITY_ANTICIPATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYDRATION,
		.noFlip = TRUE,
	},

	[SPECIES_LUVDISC] =
	{
		.baseHP 		= 43,
		.baseAttack 	= 30,
		.baseDefense 	= 55,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 97,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 225,
		.expYield = 110,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_HEART_SCALE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYDRATION,
		.noFlip = TRUE,
	},

	[SPECIES_CORPHISH] =
	{
		.baseHP 		= 43,
		.baseAttack 	= 80,
		.baseDefense 	= 65,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 35,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 205,
		.expYield = 111,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ADAPTABILITY,
		.noFlip = TRUE,
	},

	[SPECIES_CRAWDAUNT] =
	{
		.baseHP 		= 63,
		.baseAttack 	= 120,
		.baseDefense 	= 85,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 55,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DARK,
		.catchRate = 155,
		.expYield = 161,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ADAPTABILITY,
		.noFlip = TRUE,
	},

	[SPECIES_FEEBAS] =
	{
		.baseHP 		= 20,
		.baseAttack 	= 15,
		.baseDefense 	= 20,
		.baseSpAttack 	= 10,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 80,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 255,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_ADAPTABILITY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_MILOTIC] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 60,
		.baseDefense 	= 79,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 125,
		.baseSpeed 		= 81,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 154,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_MARVELSCALE,
		.ability2 = ABILITY_CUTECHARM,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_COMPETITIVE,
		.noFlip = TRUE,
	},

	[SPECIES_CARVANHA] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 90,
		.baseDefense 	= 20,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 20,
		.baseSpeed 		= 65,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DARK,
		.catchRate = 225,
		.expYield = 88,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DEEP_SEA_TOOTH,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_ROUGHSKIN,
		.ability2 = ABILITY_SPEEDBOOST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SPEEDBOOST,
		.noFlip = TRUE,
	},

	[SPECIES_SHARPEDO] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 120,
		.baseDefense 	= 40,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 95,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DARK,
		.catchRate = 60,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DEEP_SEA_TOOTH,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_ROUGHSKIN,
		.ability2 = ABILITY_SPEEDBOOST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SPEEDBOOST,
		.noFlip = TRUE,
	},

	[SPECIES_TRAPINCH] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 100,
		.baseDefense 	= 45,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 10,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 255,
		.expYield = 73,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SOFT_SAND,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_ARENATRAP,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_VIBRAVA] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 70,
		.baseDefense 	= 50,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 70,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_DRAGON,
		.catchRate = 120,
		.expYield = 126,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_LEVITATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FLYGON] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 100,
		.baseDefense 	= 80,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 100,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 197,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_LEVITATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MAKUHITA] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 60,
		.baseDefense 	= 30,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 25,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 180,
		.expYield = 87,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BLACK_BELT,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_GUTS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_HARIYAMA] =
	{
		.baseHP 		= 144,
		.baseAttack 	= 120,
		.baseDefense 	= 60,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 50,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 200,
		.expYield = 184,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_KINGS_ROCK,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_GUTS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_ELECTRIKE] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 40,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 65,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 120,
		.expYield = 104,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},

	[SPECIES_MANECTRIC] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 75,
		.baseDefense 	= 60,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 105,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},

	[SPECIES_NUMEL] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 40,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 35,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_GROUND,
		.catchRate = 255,
		.expYield = 88,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_RAWST_BERRY,
		.item2 = ITEM_RAWST_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_OBLIVIOUS,
		.ability2 = ABILITY_SIMPLE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_CAMERUPT] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 40,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_GROUND,
		.catchRate = 150,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_RAWST_BERRY,
		.item2 = ITEM_RAWST_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_MAGMAARMOR,
		.ability2 = ABILITY_SOLIDROCK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANGERPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_SPHEAL] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 40,
		.baseDefense 	= 50,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 25,
		.type1 = TYPE_ICE,
		.type2 = TYPE_WATER,
		.catchRate = 255,
		.expYield = 75,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_ICEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_SEALEO] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 60,
		.baseDefense 	= 70,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 45,
		.type1 = TYPE_ICE,
		.type2 = TYPE_WATER,
		.catchRate = 120,
		.expYield = 128,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_ICEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_WALREIN] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 80,
		.baseDefense 	= 90,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 65,
		.type1 = TYPE_ICE,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 192,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_ICEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_CACNEA] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 85,
		.baseDefense 	= 40,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 35,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 97,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STICKY_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERABSORB,
		.noFlip = TRUE,
	},

	[SPECIES_CACTURNE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 115,
		.baseDefense 	= 60,
		.baseSpAttack 	= 115,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 55,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DARK,
		.catchRate = 60,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STICKY_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERABSORB,
		.noFlip = TRUE,
	},

	[SPECIES_SNORUNT] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 50,
		.baseDefense 	= 50,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 50,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 255,
		.expYield = 74,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SNOWBALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_ICEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOODY,
		.noFlip = TRUE,
	},

	[SPECIES_GLALIE] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 80,
		.baseDefense 	= 80,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 80,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 75,
		.expYield = 187,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NEVER_MELT_ICE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_ICEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOODY,
		.noFlip = TRUE,
	},

	[SPECIES_LUNATONE] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 55,
		.baseDefense 	= 65,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 70,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 150,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_STARDUST,
		.item2 = ITEM_MOON_STONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SOLROCK] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 95,
		.baseDefense 	= 85,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 70,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 150,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_STARDUST,
		.item2 = ITEM_SUN_STONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_AZURILL] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 20,
		.baseDefense 	= 40,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 20,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FAIRY,
		.catchRate = 150,
		.expYield = 33,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_HUGEPOWER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SAPSIPPER,
		.noFlip = TRUE,
	},

	[SPECIES_SPOINK] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 25,
		.baseDefense 	= 35,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 60,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 255,
		.expYield = 89,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PERSIM_BERRY,
		.item2 = ITEM_TANGA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_OWNTEMPO,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},

	[SPECIES_GRUMPIG] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 45,
		.baseDefense 	= 65,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 80,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 60,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PERSIM_BERRY,
		.item2 = ITEM_TANGA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_OWNTEMPO,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},

	[SPECIES_PLUSLE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 50,
		.baseDefense 	= 40,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 95,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 200,
		.expYield = 120,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CELL_BATTERY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_PLUS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},

	[SPECIES_MINUN] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 40,
		.baseDefense 	= 50,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 95,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 200,
		.expYield = 120,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CELL_BATTERY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_MINUS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VOLTABSORB,
		.noFlip = TRUE,
	},

	[SPECIES_MAWILE] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 50,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 98,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_IRON_BALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_SHEERFORCE,
		.ability2 = ABILITY_INTIMIDATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYPERCUTTER,
		.noFlip = TRUE,
	},

	[SPECIES_MEDITITE] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 40,
		.baseDefense 	= 55,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 60,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 180,
		.expYield = 91,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_HUGEPOWER, //ABILITY_PUREPOWER
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 90,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_MEDICHAM] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 80,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 90,
		.expYield = 153,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_HUGEPOWER, //ABILITY_PUREPOWER
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 60,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_SWABLU] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 40,
		.baseDefense 	= 60,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 50,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 74,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_CLOUDNINE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CLOUDNINE,
		.noFlip = TRUE,
	},

	[SPECIES_ALTARIA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 70,
		.baseDefense 	= 90,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 80,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 188,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_CLOUDNINE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CLOUDNINE,
		.noFlip = TRUE,
	},

	[SPECIES_WYNAUT] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 23,
		.baseDefense 	= 48,
		.baseSpAttack 	= 23,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 23,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 125,
		.expYield = 44,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SHADOWTAG,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_DUSKULL] =
	{
		.baseHP 		= 20,
		.baseAttack 	= 40,
		.baseDefense 	= 90,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 25,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 190,
		.expYield = 97,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},

	[SPECIES_DUSCLOPS] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 70,
		.baseDefense 	= 130,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 25,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 90,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},

	[SPECIES_ROSELIA] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 60,
		.baseDefense 	= 45,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 65,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 150,
		.expYield = 152,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_LEAFGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_SLAKOTH] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 60,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 30,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 83,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TRUANT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_VIGOROTH] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 80,
		.baseDefense 	= 80,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 90,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 120,
		.expYield = 126,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_VITALSPIRIT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SLAKING] =
	{
		.baseHP 		= 150,
		.baseAttack 	= 160,
		.baseDefense 	= 100,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 100,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TRUANT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GULPIN] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 43,
		.baseDefense 	= 53,
		.baseSpAttack 	= 43,
		.baseSpDefense 	= 53,
		.baseSpeed 		= 40,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 225,
		.expYield = 75,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_SITRUS_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LIQUIDOOZE,
		.ability2 = ABILITY_STICKYHOLD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},

	[SPECIES_SWALOT] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 73,
		.baseDefense 	= 83,
		.baseSpAttack 	= 73,
		.baseSpDefense 	= 83,
		.baseSpeed 		= 55,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 75,
		.expYield = 168,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_SITRUS_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LIQUIDOOZE,
		.ability2 = ABILITY_STICKYHOLD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},

	[SPECIES_TROPIUS] =
	{
		.baseHP 		= 99,
		.baseAttack 	= 68,
		.baseDefense 	= 83,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 87,
		.baseSpeed 		= 51,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FLYING,
		.catchRate = 200,
		.expYield = 169,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_HARVEST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOLARPOWER,
		.noFlip = TRUE,
	},

	[SPECIES_WHISMUR] =
	{
		.baseHP 		= 64,
		.baseAttack 	= 51,
		.baseDefense 	= 23,
		.baseSpAttack 	= 51,
		.baseSpDefense 	= 23,
		.baseSpeed 		= 28,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 190,
		.expYield = 68,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHESTO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SOUNDPROOF,
		.ability2 = ABILITY_RATTLED,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_LOUDRED] =
	{
		.baseHP 		= 84,
		.baseAttack 	= 71,
		.baseDefense 	= 43,
		.baseSpAttack 	= 71,
		.baseSpDefense 	= 43,
		.baseSpeed 		= 48,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 120,
		.expYield = 126,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHESTO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SOUNDPROOF,
		.ability2 = ABILITY_SCRAPPY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SCRAPPY,
		.noFlip = TRUE,
	},

	[SPECIES_EXPLOUD] =
	{
		.baseHP 		= 104,
		.baseAttack 	= 91,
		.baseDefense 	= 63,
		.baseSpAttack 	= 91,
		.baseSpDefense 	= 73,
		.baseSpeed 		= 68,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 184,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHESTO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SOUNDPROOF,
		.ability2 = ABILITY_SCRAPPY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SCRAPPY,
		.noFlip = TRUE,
	},

	[SPECIES_CLAMPERL] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 64,
		.baseDefense 	= 85,
		.baseSpAttack 	= 74,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 32,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 255,
		.expYield = 142,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PEARL,
		.item2 = ITEM_BIG_PEARL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_SHELLARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_HUNTAIL] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 104,
		.baseDefense 	= 105,
		.baseSpAttack 	= 94,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 52,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 178,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DEEP_SEA_TOOTH,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_GOREBYSS] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 84,
		.baseDefense 	= 105,
		.baseSpAttack 	= 114,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 52,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 178,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DEEP_SEA_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYDRATION,
		.noFlip = TRUE,
	},

	[SPECIES_ABSOL] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 130,
		.baseDefense 	= 60,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 75,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 30,
		.expYield = 174,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LIFE_ORB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_JUSTIFIED,
		.ability2 = ABILITY_SUPERLUCK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRESSURE,
		.noFlip = TRUE,
	},

	[SPECIES_SHUPPET] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 75,
		.baseDefense 	= 35,
		.baseSpAttack 	= 63,
		.baseSpDefense 	= 33,
		.baseSpeed 		= 45,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 225,
		.expYield = 97,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_CURSEDBODY,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_BANETTE] =
	{
		.baseHP 		= 64,
		.baseAttack 	= 115,
		.baseDefense 	= 65,
		.baseSpAttack 	= 83,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 65,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_CURSEDBODY,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_SEVIPER] =
	{
		.baseHP 		= 73,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 65,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 90,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHED_SHELL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_ZANGOOSE] =
	{
		.baseHP 		= 73,
		.baseAttack 	= 115,
		.baseDefense 	= 60,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 90,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 90,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_QUICK_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_IMMUNITY,
		.ability2 = ABILITY_TOXICBOOST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TOXICBOOST,
		.noFlip = TRUE,
	},

	[SPECIES_RELICANTH] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 90,
		.baseDefense 	= 130,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 55,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ROCK,
		.catchRate = 25,
		.expYield = 198,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DEEP_SEA_SCALE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_ROCKHEAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STURDY,
		.noFlip = TRUE,
	},

	[SPECIES_ARON] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 70,
		.baseDefense 	= 100,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 30,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_ROCK,
		.catchRate = 180,
		.expYield = 96,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 35,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_ROCKHEAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEAVYMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_LAIRON] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 90,
		.baseDefense 	= 140,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 40,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_ROCK,
		.catchRate = 90,
		.expYield = 152,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 35,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_ROCKHEAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEAVYMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_AGGRON] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 110,
		.baseDefense 	= 180,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 50,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_ROCK,
		.catchRate = 45,
		.expYield = 205,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 35,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_ROCKHEAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEAVYMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_CASTFORM] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 70,
		.baseDefense 	= 70,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 70,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 145,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_MYSTIC_WATER,
		.item2 = ITEM_MYSTIC_WATER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_FORECAST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_VOLBEAT] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 73,
		.baseDefense 	= 75,
		.baseSpAttack 	= 47,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 85,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 150,
		.expYield = 146,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BRIGHT_POWDER,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_ILLUMINATE,
		.ability2 = ABILITY_SWARM,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRANKSTER,
		.noFlip = TRUE,
	},

	[SPECIES_ILLUMISE] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 47,
		.baseDefense 	= 75,
		.baseSpAttack 	= 73,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 85,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 150,
		.expYield = 146,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BRIGHT_POWDER,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_OBLIVIOUS,
		.ability2 = ABILITY_TINTEDLENS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRANKSTER,
		.noFlip = TRUE,
	},

	[SPECIES_LILEEP] =
	{
		.baseHP 		= 66,
		.baseAttack 	= 41,
		.baseDefense 	= 77,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 87,
		.baseSpeed 		= 23,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BIG_ROOT,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SUCTIONCUPS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STORMDRAIN,
		.noFlip = TRUE,
	},

	[SPECIES_CRADILY] =
	{
		.baseHP 		= 86,
		.baseAttack 	= 81,
		.baseDefense 	= 97,
		.baseSpAttack 	= 81,
		.baseSpDefense 	= 107,
		.baseSpeed 		= 43,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BIG_ROOT,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SUCTIONCUPS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STORMDRAIN,
		.noFlip = TRUE,
	},

	[SPECIES_ANORITH] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 95,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 75,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_BUG,
		.catchRate = 45,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_BATTLEARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},

	[SPECIES_ARMALDO] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 125,
		.baseDefense 	= 100,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 45,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_BUG,
		.catchRate = 45,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_BATTLEARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},

	[SPECIES_RALTS] =
	{
		.baseHP 		= 28,
		.baseAttack 	= 25,
		.baseDefense 	= 25,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 40,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 235,
		.expYield = 70,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_TRACE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_KIRLIA] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 35,
		.baseDefense 	= 35,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 50,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 120,
		.expYield = 140,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_TRACE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_GARDEVOIR] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 80,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SYNCHRONIZE,
		.ability2 = ABILITY_TRACE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_BAGON] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 75,
		.baseDefense 	= 60,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 50,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 89,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_FANG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_SHELGON] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 95,
		.baseDefense 	= 100,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 50,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_FANG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_OVERCOAT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_SALAMENCE] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 135,
		.baseDefense 	= 80,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 100,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_FANG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_MOXIE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOXIE,
		.noFlip = TRUE,
	},

	[SPECIES_BELDUM] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 55,
		.baseDefense 	= 80,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 30,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 103,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_METANG] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 75,
		.baseDefense 	= 100,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 50,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 153,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_METAGROSS] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 135,
		.baseDefense 	= 130,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 70,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_REGIROCK] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 100,
		.baseDefense 	= 200,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 50,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 3,
		.expYield = 217,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STURDY,
		.noFlip = TRUE,
	},

	[SPECIES_REGICE] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 50,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 200,
		.baseSpeed 		= 50,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 3,
		.expYield = 216,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ICEBODY,
		.noFlip = TRUE,
	},

	[SPECIES_REGISTEEL] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 75,
		.baseDefense 	= 150,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 150,
		.baseSpeed 		= 50,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_KYOGRE] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 90,
		.baseSpAttack 	= 150,
		.baseSpDefense 	= 140,
		.baseSpeed 		= 90,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 3,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DRIZZLE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GROUDON] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 150,
		.baseDefense 	= 140,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 90,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 3,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DROUGHT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_RAYQUAZA] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 150,
		.baseDefense 	= 90,
		.baseSpAttack 	= 150,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 95,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_AIRLOCK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LATIAS] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 80,
		.baseDefense 	= 90,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 110,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 211,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LATIOS] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 90,
		.baseDefense 	= 80,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 110,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 211,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_JIRACHI] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_STAR_PIECE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SERENEGRACE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_DEOXYS] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 150,
		.baseDefense 	= 50,
		.baseSpAttack 	= 150,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 150,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CHIMECHO] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 50,
		.baseDefense 	= 80,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 65,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 147,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CLEANSE_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_EGG] =
	{
		.baseHP 		= 0,
		.baseAttack 	= 0,
		.baseDefense 	= 0,
		.baseSpAttack 	= 0,
		.baseSpDefense 	= 0,
		.baseSpeed 		= 0,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 0,
		.expYield = 0,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 0,
		.friendship = 0,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_NONE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_B] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_C] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_D] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_E] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_F] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_G] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_H] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_I] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_J] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_K] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_L] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_M] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_N] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_O] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_P] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_Q] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_R] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_S] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_T] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_U] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_V] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_W] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_X] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_Y] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_Z] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_EXCLAMATION] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNOWN_QUESTION] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 72,
		.baseDefense 	= 48,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 48,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TURTWIG] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 68,
		.baseDefense 	= 64,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 31,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 64,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHELLARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_GROTLE] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 89,
		.baseDefense 	= 85,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 36,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 141,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHELLARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_TORTERRA] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 109,
		.baseDefense 	= 105,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 56,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHELLARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_CHIMCHAR] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 58,
		.baseDefense 	= 44,
		.baseSpAttack 	= 58,
		.baseSpDefense 	= 44,
		.baseSpeed 		= 61,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_IRONFIST,
		.noFlip = TRUE,
	},

	[SPECIES_MONFERNO] =
	{
		.baseHP 		= 64,
		.baseAttack 	= 78,
		.baseDefense 	= 52,
		.baseSpAttack 	= 78,
		.baseSpDefense 	= 52,
		.baseSpeed 		= 81,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 142,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_IRONFIST,
		.noFlip = TRUE,
	},

	[SPECIES_INFERNAPE] =
	{
		.baseHP 		= 76,
		.baseAttack 	= 104,
		.baseDefense 	= 71,
		.baseSpAttack 	= 104,
		.baseSpDefense 	= 71,
		.baseSpeed 		= 108,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_IRONFIST,
		.noFlip = TRUE,
	},

	[SPECIES_PIPLUP] =
	{
		.baseHP 		= 53,
		.baseAttack 	= 51,
		.baseDefense 	= 53,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 56,
		.baseSpeed 		= 40,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 66,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_PRINPLUP] =
	{
		.baseHP 		= 64,
		.baseAttack 	= 66,
		.baseDefense 	= 68,
		.baseSpAttack 	= 81,
		.baseSpDefense 	= 76,
		.baseSpeed 		= 50,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 143,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_EMPOLEON] =
	{
		.baseHP 		= 84,
		.baseAttack 	= 86,
		.baseDefense 	= 88,
		.baseSpAttack 	= 111,
		.baseSpDefense 	= 101,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_STARLY] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 55,
		.baseDefense 	= 30,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 56,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_YACHE_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_RECKLESS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RECKLESS,
		.noFlip = TRUE,
	},

	[SPECIES_STARAVIA] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 75,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 80,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 120,
		.expYield = 113,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_YACHE_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_RECKLESS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RECKLESS,
		.noFlip = TRUE,
	},

	[SPECIES_STARAPTOR] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 120,
		.baseDefense 	= 70,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 100,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_YACHE_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_RECKLESS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RECKLESS,
		.noFlip = TRUE,
	},

	[SPECIES_BIDOOF] =
	{
		.baseHP 		= 59,
		.baseAttack 	= 45,
		.baseDefense 	= 40,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 31,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 58,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SIMPLE,
		.ability2 = ABILITY_UNAWARE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOODY,
		.noFlip = TRUE,
	},

	[SPECIES_BIBAREL] =
	{
		.baseHP 		= 79,
		.baseAttack 	= 85,
		.baseDefense 	= 60,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 71,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_WATER,
		.catchRate = 127,
		.expYield = 116,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_SITRUS_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SIMPLE,
		.ability2 = ABILITY_UNAWARE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOODY,
		.noFlip = TRUE,
	},

	[SPECIES_KRICKETOT] =
	{
		.baseHP 		= 37,
		.baseAttack 	= 25,
		.baseDefense 	= 41,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 41,
		.baseSpeed 		= 25,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 255,
		.expYield = 54,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METRONOME,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RUNAWAY,
		.noFlip = TRUE,
	},

	[SPECIES_KRICKETUNE] =
	{
		.baseHP 		= 77,
		.baseAttack 	= 85,
		.baseDefense 	= 51,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 51,
		.baseSpeed 		= 65,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 45,
		.expYield = 159,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METRONOME,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TECHNICIAN,
		.noFlip = TRUE,
	},

	[SPECIES_SHINX] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 65,
		.baseDefense 	= 34,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 34,
		.baseSpeed 		= 45,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 235,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_INTIMIDATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_LUXIO] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 85,
		.baseDefense 	= 49,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 49,
		.baseSpeed 		= 60,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 120,
		.expYield = 117,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 100,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_INTIMIDATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_LUXRAY] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 120,
		.baseDefense 	= 79,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 79,
		.baseSpeed 		= 70,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 194,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_INTIMIDATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_BUDEW] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 30,
		.baseDefense 	= 35,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 55,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 255,
		.expYield = 68,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_LEAFGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_ROSERADE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 70,
		.baseDefense 	= 65,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 90,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 75,
		.expYield = 204,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_CRANIDOS] =
	{
		.baseHP 		= 67,
		.baseAttack 	= 125,
		.baseDefense 	= 40,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 58,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 45,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_MOLDBREAKER,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_RAMPARDOS] =
	{
		.baseHP 		= 97,
		.baseAttack 	= 165,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 58,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 45,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_MOLDBREAKER,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_SHIELDON] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 42,
		.baseDefense 	= 118,
		.baseSpAttack 	= 42,
		.baseSpDefense 	= 88,
		.baseSpeed 		= 30,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOUNDPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_BASTIODON] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 52,
		.baseDefense 	= 168,
		.baseSpAttack 	= 47,
		.baseSpDefense 	= 138,
		.baseSpeed 		= 30,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOUNDPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_BURMY] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 29,
		.baseDefense 	= 45,
		.baseSpAttack 	= 29,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 36,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 120,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_WORMADAM] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 59,
		.baseDefense 	= 85,
		.baseSpAttack 	= 79,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 36,
		.type1 = TYPE_BUG,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 159,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SILVER_POWDER,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_ANTICIPATION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_MOTHIM] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 94,
		.baseDefense 	= 50,
		.baseSpAttack 	= 94,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 66,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 159,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SILVER_POWDER,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TINTEDLENS,
		.noFlip = TRUE,
	},

	[SPECIES_COMBEE] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 30,
		.baseDefense 	= 42,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 42,
		.baseSpeed 		= 70,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 120,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_HONEY,
		.item2 = ITEM_HONEY,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_HONEYGATHER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HUSTLE,
		.noFlip = TRUE,
	},

	[SPECIES_VESPIQUEN] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 80,
		.baseDefense 	= 102,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 102,
		.baseSpeed 		= 40,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 188,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_PACHIRISU] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 45,
		.baseDefense 	= 70,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 95,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 200,
		.expYield = 120,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 100,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_PICKUP,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VOLTABSORB,
		.noFlip = TRUE,
	},

	[SPECIES_BUIZEL] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 65,
		.baseDefense 	= 35,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 85,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 75,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_WACAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_FLOATZEL] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 105,
		.baseDefense 	= 55,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 115,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 75,
		.expYield = 178,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_WACAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_CHERUBI] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 35,
		.baseDefense 	= 45,
		.baseSpAttack 	= 62,
		.baseSpDefense 	= 53,
		.baseSpeed 		= 35,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 68,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MIRACLE_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CHERRIM] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 60,
		.baseDefense 	= 70,
		.baseSpAttack 	= 87,
		.baseSpDefense 	= 78,
		.baseSpeed 		= 85,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 133,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MIRACLE_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_FLOWERGIFT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SHELLOS] =
	{
		.baseHP 		= 76,
		.baseAttack 	= 48,
		.baseDefense 	= 48,
		.baseSpAttack 	= 57,
		.baseSpDefense 	= 62,
		.baseSpeed 		= 34,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 73,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_STICKYHOLD,
		.ability2 = ABILITY_STORMDRAIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_GASTRODON] =
	{
		.baseHP 		= 111,
		.baseAttack 	= 83,
		.baseDefense 	= 68,
		.baseSpAttack 	= 92,
		.baseSpDefense 	= 82,
		.baseSpeed 		= 39,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 75,
		.expYield = 176,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_STICKYHOLD,
		.ability2 = ABILITY_STORMDRAIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_AMBIPOM] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 100,
		.baseDefense 	= 66,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 66,
		.baseSpeed 		= 115,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 186,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 100,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TECHNICIAN,
		.ability2 = ABILITY_SKILLLINK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKUP,
		.noFlip = TRUE,
	},

	[SPECIES_DRIFLOON] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 50,
		.baseDefense 	= 34,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 44,
		.baseSpeed 		= 70,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_FLYING,
		.catchRate = 125,
		.expYield = 127,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_AFTERMATH,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLAREBOOST,
		.noFlip = TRUE,
	},

	[SPECIES_DRIFBLIM] =
	{
		.baseHP 		= 150,
		.baseAttack 	= 80,
		.baseDefense 	= 44,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 54,
		.baseSpeed 		= 80,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_FLYING,
		.catchRate = 60,
		.expYield = 204,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_AIR_BALLOON,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_FLUCTUATING,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_AFTERMATH,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLAREBOOST,
		.noFlip = TRUE,
	},

	[SPECIES_BUNEARY] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 66,
		.baseDefense 	= 44,
		.baseSpAttack 	= 44,
		.baseSpDefense 	= 56,
		.baseSpeed 		= 85,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 190,
		.expYield = 84,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_CHOPLE_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 0,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_KLUTZ,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIMBER,
		.noFlip = TRUE,
	},

	[SPECIES_LOPUNNY] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 76,
		.baseDefense 	= 84,
		.baseSpAttack 	= 54,
		.baseSpDefense 	= 96,
		.baseSpeed 		= 105,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 60,
		.expYield = 178,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_CHOPLE_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 140,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_KLUTZ,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIMBER,
		.noFlip = TRUE,
	},

	[SPECIES_MISMAGIUS] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 60,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 105,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 187,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_HONCHKROW] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 125,
		.baseDefense 	= 52,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 52,
		.baseSpeed 		= 71,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 187,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_MOXIE,
		.ability2 = ABILITY_SUPERLUCK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_GLAMEOW] =
	{
		.baseHP 		= 49,
		.baseAttack 	= 55,
		.baseDefense 	= 42,
		.baseSpAttack 	= 42,
		.baseSpDefense 	= 37,
		.baseSpeed 		= 85,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 190,
		.expYield = 71,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHERI_BERRY,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_LIMBER,
		.ability2 = ABILITY_OWNTEMPO,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_PURUGLY] =
	{
		.baseHP 		= 71,
		.baseAttack 	= 82,
		.baseDefense 	= 64,
		.baseSpAttack 	= 64,
		.baseSpDefense 	= 59,
		.baseSpeed 		= 112,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 75,
		.expYield = 183,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHERI_BERRY,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_OWNTEMPO,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_CHINGLING] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 30,
		.baseDefense 	= 50,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 45,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 120,
		.expYield = 74,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CLEANSE_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_STUNKY] =
	{
		.baseHP 		= 63,
		.baseAttack 	= 63,
		.baseDefense 	= 47,
		.baseSpAttack 	= 41,
		.baseSpDefense 	= 41,
		.baseSpeed 		= 74,
		.type1 = TYPE_POISON,
		.type2 = TYPE_DARK,
		.catchRate = 225,
		.expYield = 79,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PECHA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STENCH,
		.ability2 = ABILITY_AFTERMATH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_SKUNTANK] =
	{
		.baseHP 		= 103,
		.baseAttack 	= 93,
		.baseDefense 	= 67,
		.baseSpAttack 	= 71,
		.baseSpDefense 	= 61,
		.baseSpeed 		= 84,
		.type1 = TYPE_POISON,
		.type2 = TYPE_DARK,
		.catchRate = 60,
		.expYield = 209,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PECHA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STENCH,
		.ability2 = ABILITY_AFTERMATH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_BRONZOR] =
	{
		.baseHP 		= 57,
		.baseAttack 	= 24,
		.baseDefense 	= 86,
		.baseSpAttack 	= 24,
		.baseSpDefense 	= 86,
		.baseSpeed 		= 23,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 255,
		.expYield = 72,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_HEATPROOF,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEAVYMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_BRONZONG] =
	{
		.baseHP 		= 67,
		.baseAttack 	= 89,
		.baseDefense 	= 116,
		.baseSpAttack 	= 79,
		.baseSpDefense 	= 116,
		.baseSpeed 		= 33,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 90,
		.expYield = 188,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_HEATPROOF,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEAVYMETAL,
		.noFlip = TRUE,
	},

	[SPECIES_BONSLY] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 80,
		.baseDefense 	= 95,
		.baseSpAttack 	= 10,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 10,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 255,
		.expYield = 68,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_ROCKHEAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_MIME_JR] =
	{
		.baseHP 		= 20,
		.baseAttack 	= 25,
		.baseDefense 	= 45,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 60,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 145,
		.expYield = 78,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LEPPA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SOUNDPROOF,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FILTER,
		.noFlip = TRUE,
	},

	[SPECIES_HAPPINY] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 5,
		.baseDefense 	= 5,
		.baseSpAttack 	= 15,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 30,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 130,
		.expYield = 255,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_OVAL_STONE,
		.item2 = ITEM_LUCKY_EGG,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 40,
		.friendship = 140,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_SERENEGRACE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_CHATOT] =
	{
		.baseHP 		= 76,
		.baseAttack 	= 65,
		.baseDefense 	= 45,
		.baseSpAttack 	= 92,
		.baseSpDefense 	= 42,
		.baseSpeed 		= 91,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 107,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METRONOME,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_TANGLEDFEET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BIGPECKS,
		.noFlip = TRUE,
	},

	[SPECIES_SPIRITOMB] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 92,
		.baseDefense 	= 108,
		.baseSpAttack 	= 92,
		.baseSpDefense 	= 108,
		.baseSpeed 		= 35,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_DARK,
		.catchRate = 100,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_SMOKE_BALL,
		.item2 = ITEM_SMOKE_BALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_GIBLE] =
	{
		.baseHP 		= 58,
		.baseAttack 	= 70,
		.baseDefense 	= 45,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 42,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HABAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_ROUGHSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ROUGHSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_GABITE] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 90,
		.baseDefense 	= 65,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 82,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HABAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_ROUGHSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ROUGHSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_GARCHOMP] =
	{
		.baseHP 		= 108,
		.baseAttack 	= 130,
		.baseDefense 	= 95,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 102,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HABAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_ROUGHSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ROUGHSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_MUNCHLAX] =
	{
		.baseHP 		= 135,
		.baseAttack 	= 85,
		.baseDefense 	= 40,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 5,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 50,
		.expYield = 94,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LEFTOVERS,
		.item2 = ITEM_LEFTOVERS,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_THICKFAT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},

	[SPECIES_RIOLU] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 70,
		.baseDefense 	= 40,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 60,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 75,
		.expYield = 72,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_STEADFAST,
		.ability2 = ABILITY_PRANKSTER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_LUCARIO] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 110,
		.baseDefense 	= 70,
		.baseSpAttack 	= 115,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 90,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 204,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_STEADFAST,
		.ability2 = ABILITY_JUSTIFIED,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_HIPPOPOTAS] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 72,
		.baseDefense 	= 78,
		.baseSpAttack 	= 38,
		.baseSpDefense 	= 42,
		.baseSpeed 		= 32,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 140,
		.expYield = 95,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDSTREAM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_HIPPOWDON] =
	{
		.baseHP 		= 108,
		.baseAttack 	= 112,
		.baseDefense 	= 118,
		.baseSpAttack 	= 68,
		.baseSpDefense 	= 72,
		.baseSpeed 		= 47,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 60,
		.expYield = 188,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDSTREAM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_SKORUPI] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 50,
		.baseDefense 	= 90,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 65,
		.type1 = TYPE_POISON,
		.type2 = TYPE_BUG,
		.catchRate = 120,
		.expYield = 114,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_BATTLEARMOR,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_DRAPION] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 90,
		.baseDefense 	= 110,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 95,
		.type1 = TYPE_POISON,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 204,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_BATTLEARMOR,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_CROAGUNK] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 61,
		.baseDefense 	= 40,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 50,
		.type1 = TYPE_POISON,
		.type2 = TYPE_FIGHTING,
		.catchRate = 140,
		.expYield = 83,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BLACK_SLUDGE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 100,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_ANTICIPATION,
		.ability2 = ABILITY_DRYSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONTOUCH,
		.noFlip = TRUE,
	},

	[SPECIES_TOXICROAK] =
	{
		.baseHP 		= 83,
		.baseAttack 	= 106,
		.baseDefense 	= 65,
		.baseSpAttack 	= 86,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 85,
		.type1 = TYPE_POISON,
		.type2 = TYPE_FIGHTING,
		.catchRate = 75,
		.expYield = 181,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BLACK_SLUDGE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_ANTICIPATION,
		.ability2 = ABILITY_DRYSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONTOUCH,
		.noFlip = TRUE,
	},

	[SPECIES_CARNIVINE] =
	{
		.baseHP 		= 74,
		.baseAttack 	= 100,
		.baseDefense 	= 72,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 72,
		.baseSpeed 		= 46,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 200,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FINNEON] =
	{
		.baseHP 		= 49,
		.baseAttack 	= 49,
		.baseDefense 	= 56,
		.baseSpAttack 	= 49,
		.baseSpDefense 	= 61,
		.baseSpeed 		= 66,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 90,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_RINDO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_STORMDRAIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_LUMINEON] =
	{
		.baseHP 		= 69,
		.baseAttack 	= 69,
		.baseDefense 	= 76,
		.baseSpAttack 	= 69,
		.baseSpDefense 	= 86,
		.baseSpeed 		= 91,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 75,
		.expYield = 156,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_RINDO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_STORMDRAIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_MANTYKE] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 20,
		.baseDefense 	= 50,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 50,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FLYING,
		.catchRate = 25,
		.expYield = 108,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_SNOVER] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 62,
		.baseDefense 	= 50,
		.baseSpAttack 	= 62,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 40,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_ICE,
		.catchRate = 120,
		.expYield = 131,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NEVER_MELT_ICE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_SNOWWARNING,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOUNDPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_ABOMASNOW] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 92,
		.baseDefense 	= 75,
		.baseSpAttack 	= 92,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 60,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_ICE,
		.catchRate = 60,
		.expYield = 214,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NEVER_MELT_ICE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_SNOWWARNING,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOUNDPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_WEAVILE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 120,
		.baseDefense 	= 65,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 125,
		.type1 = TYPE_DARK,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_GRIP_CLAW,
		.item2 = ITEM_QUICK_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_PICKPOCKET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKPOCKET,
		.noFlip = TRUE,
	},

	[SPECIES_MAGNEZONE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 70,
		.baseDefense 	= 115,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 60,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_STEEL,
		.catchRate = 30,
		.expYield = 211,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_MAGNETPULL,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_LICKILICKY] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 85,
		.baseDefense 	= 95,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 50,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 30,
		.expYield = 193,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LAGGING_TAIL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_CLOUDNINE,
		.ability2 = ABILITY_OBLIVIOUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_RHYPERIOR] =
	{
		.baseHP 		= 115,
		.baseAttack 	= 140,
		.baseDefense 	= 130,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 40,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_ROCK,
		.catchRate = 30,
		.expYield = 217,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_SOLIDROCK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RECKLESS,
		.noFlip = TRUE,
	},

	[SPECIES_TANGROWTH] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 125,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 50,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 30,
		.expYield = 211,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LEAFGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_ELECTIVIRE] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 123,
		.baseDefense 	= 67,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 95,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 30,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ELECTIRIZER,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_MOTORDRIVE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VITALSPIRIT,
		.noFlip = TRUE,
	},

	[SPECIES_MAGMORTAR] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 95,
		.baseDefense 	= 67,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 83,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 30,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MAGMARIZER,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_FLAMEBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VITALSPIRIT,
		.noFlip = TRUE,
	},

	[SPECIES_TOGEKISS] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 50,
		.baseDefense 	= 95,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 80,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_SUPERLUCK,
		.ability2 = ABILITY_SERENEGRACE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HUSTLE,
		.noFlip = TRUE,
	},

	[SPECIES_YANMEGA] =
	{
		.baseHP 		= 86,
		.baseAttack 	= 76,
		.baseDefense 	= 86,
		.baseSpAttack 	= 116,
		.baseSpDefense 	= 56,
		.baseSpeed 		= 95,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 198,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_WIDE_LENS,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SPEEDBOOST,
		.ability2 = ABILITY_TINTEDLENS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},

	[SPECIES_LEAFEON] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 110,
		.baseDefense 	= 130,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 95,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 196,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_LEAFGUARD,
		.ability2 = ABILITY_CHLOROPHYLL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CHLOROPHYLL,
		.noFlip = TRUE,
	},

	[SPECIES_GLACEON] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 110,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 65,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 196,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SNOWCLOAK,
		.ability2 = ABILITY_ICEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ICEBODY,
		.noFlip = TRUE,
	},

	[SPECIES_GLISCOR] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 95,
		.baseDefense 	= 125,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 95,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 192,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_POISONHEAL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_MAMOSWINE] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 130,
		.baseDefense 	= 80,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 80,
		.type1 = TYPE_ICE,
		.type2 = TYPE_GROUND,
		.catchRate = 50,
		.expYield = 207,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_SNOWCLOAK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_PORYGON_Z] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 80,
		.baseDefense 	= 70,
		.baseSpAttack 	= 135,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 90,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 30,
		.expYield = 185,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_ADAPTABILITY,
		.ability2 = ABILITY_DOWNLOAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_GALLADE] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 125,
		.baseDefense 	= 65,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 80,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_STEADFAST,
		.ability2 = ABILITY_JUSTIFIED,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_JUSTIFIED,
		.noFlip = TRUE,
	},

	[SPECIES_PROBOPASS] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 55,
		.baseDefense 	= 145,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 150,
		.baseSpeed 		= 40,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_STEEL,
		.catchRate = 60,
		.expYield = 198,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MAGNET,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_MAGNETPULL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_DUSKNOIR] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 100,
		.baseDefense 	= 135,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 135,
		.baseSpeed 		= 45,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},

	[SPECIES_FROSLASS] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 80,
		.baseDefense 	= 70,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 110,
		.type1 = TYPE_ICE,
		.type2 = TYPE_GHOST,
		.catchRate = 75,
		.expYield = 187,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BABIRI_BERRY,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SNOWCLOAK,
		.ability2 = ABILITY_CURSEDBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CURSEDBODY,
		.noFlip = TRUE,
	},

	[SPECIES_ROTOM] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 50,
		.baseDefense 	= 77,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 77,
		.baseSpeed 		= 91,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UXIE] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 75,
		.baseDefense 	= 130,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 95,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 140,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MESPRIT] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 105,
		.baseDefense 	= 105,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 80,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 140,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_AZELF] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 125,
		.baseDefense 	= 70,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 115,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 140,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_DIALGA] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 150,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 90,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_DRAGON,
		.catchRate = 30,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_PALKIA] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 120,
		.baseDefense 	= 100,
		.baseSpAttack 	= 150,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 100,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DRAGON,
		.catchRate = 30,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_HEATRAN] =
	{
		.baseHP 		= 91,
		.baseAttack 	= 90,
		.baseDefense 	= 106,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 106,
		.baseSpeed 		= 77,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 100,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLAMEBODY,
		.noFlip = TRUE,
	},

	[SPECIES_REGIGIGAS] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 160,
		.baseDefense 	= 110,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 100,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SLOWSTART,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GIRATINA] =
	{
		.baseHP 		= 150,
		.baseAttack 	= 100,
		.baseDefense 	= 120,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 90,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_DRAGON,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_CRESSELIA] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 70,
		.baseDefense 	= 120,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 85,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_PHIONE] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 80,
		.baseDefense 	= 80,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 80,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 30,
		.expYield = 165,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HYDRATION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MANAPHY] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HYDRATION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_DARKRAI] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 90,
		.baseDefense 	= 90,
		.baseSpAttack 	= 135,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 125,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BADDREAMS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SHAYMIN] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 215,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LUM_BERRY,
		.item2 = ITEM_LUM_BERRY,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_VICTINI] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FIRE,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_VICTORYSTAR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SNIVY] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 45,
		.baseDefense 	= 55,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 63,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CONTRARY,
		.noFlip = TRUE,
	},

	[SPECIES_SERVINE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 83,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 145,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CONTRARY,
		.noFlip = TRUE,
	},

	[SPECIES_SERPERIOR] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 75,
		.baseDefense 	= 95,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 113,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CONTRARY,
		.noFlip = TRUE,
	},

	[SPECIES_TEPIG] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 63,
		.baseDefense 	= 45,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 45,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 62,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_THICKFAT,
		.noFlip = TRUE,
	},

	[SPECIES_PIGNITE] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 93,
		.baseDefense 	= 55,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 55,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 146,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_THICKFAT,
		.noFlip = TRUE,
	},

	[SPECIES_EMBOAR] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 123,
		.baseDefense 	= 65,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RECKLESS,
		.noFlip = TRUE,
	},

	[SPECIES_OSHAWOTT] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 55,
		.baseDefense 	= 45,
		.baseSpAttack 	= 63,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 45,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHELLARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_DEWOTT] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 75,
		.baseDefense 	= 60,
		.baseSpAttack 	= 83,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 145,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHELLARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_SAMUROTT] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 100,
		.baseDefense 	= 85,
		.baseSpAttack 	= 108,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHELLARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_PATRAT] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 55,
		.baseDefense 	= 39,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 39,
		.baseSpeed 		= 42,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 57,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_KEENEYE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_WATCHOG] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 85,
		.baseDefense 	= 69,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 69,
		.baseSpeed 		= 77,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 116,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_ILLUMINATE,
		.ability2 = ABILITY_KEENEYE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_LILLIPUP] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 60,
		.baseDefense 	= 45,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 55,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_PICKUP,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_VITALSPIRIT,
		.noFlip = TRUE,
	},

	[SPECIES_HERDIER] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 80,
		.baseDefense 	= 65,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 120,
		.expYield = 118,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SCRAPPY,
		.ability2 = ABILITY_SANDRUSH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INTIMIDATE,
		.noFlip = TRUE,
	},

	[SPECIES_STOUTLAND] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 110,
		.baseDefense 	= 90,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 80,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 195,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SCRAPPY,
		.ability2 = ABILITY_SANDRUSH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INTIMIDATE,
		.noFlip = TRUE,
	},

	[SPECIES_PURRLOIN] =
	{
		.baseHP 		= 41,
		.baseAttack 	= 50,
		.baseDefense 	= 37,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 37,
		.baseSpeed 		= 66,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 255,
		.expYield = 69,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIMBER,
		.noFlip = TRUE,
	},

	[SPECIES_LIEPARD] =
	{
		.baseHP 		= 64,
		.baseAttack 	= 88,
		.baseDefense 	= 50,
		.baseSpAttack 	= 88,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 106,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 90,
		.expYield = 148,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIMBER,
		.noFlip = TRUE,
	},

	[SPECIES_PANSAGE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 53,
		.baseDefense 	= 48,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 64,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_OCCA_BERRY,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERGROW,
		.noFlip = TRUE,
	},

	[SPECIES_SIMISAGE] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 98,
		.baseDefense 	= 63,
		.baseSpAttack 	= 98,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 101,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_OCCA_BERRY,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERGROW,
		.noFlip = TRUE,
	},

	[SPECIES_PANSEAR] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 53,
		.baseDefense 	= 48,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 64,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 190,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_PASSHO_BERRY,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BLAZE,
		.noFlip = TRUE,
	},

	[SPECIES_SIMISEAR] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 98,
		.baseDefense 	= 63,
		.baseSpAttack 	= 98,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 101,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 75,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_PASSHO_BERRY,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BLAZE,
		.noFlip = TRUE,
	},

	[SPECIES_PANPOUR] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 53,
		.baseDefense 	= 48,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 64,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_RINDO_BERRY,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TORRENT,
		.noFlip = TRUE,
	},

	[SPECIES_SIMIPOUR] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 98,
		.baseDefense 	= 63,
		.baseSpAttack 	= 98,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 101,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 75,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_RINDO_BERRY,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TORRENT,
		.noFlip = TRUE,
	},

	[SPECIES_MUNNA] =
	{
		.baseHP 		= 76,
		.baseAttack 	= 25,
		.baseDefense 	= 45,
		.baseSpAttack 	= 67,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 24,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 190,
		.expYield = 92,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FOREWARN,
		.ability2 = ABILITY_SYNCHRONIZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_MUSHARNA] =
	{
		.baseHP 		= 116,
		.baseAttack 	= 55,
		.baseDefense 	= 85,
		.baseSpAttack 	= 107,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 29,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 75,
		.expYield = 158,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FOREWARN,
		.ability2 = ABILITY_SYNCHRONIZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_PIDOVE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 55,
		.baseDefense 	= 50,
		.baseSpAttack 	= 36,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 43,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 56,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_BIGPECKS,
		.ability2 = ABILITY_SUPERLUCK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_TRANQUILL] =
	{
		.baseHP 		= 62,
		.baseAttack 	= 77,
		.baseDefense 	= 62,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 42,
		.baseSpeed 		= 65,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 120,
		.expYield = 113,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_BIGPECKS,
		.ability2 = ABILITY_SUPERLUCK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_UNFEZANT] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 115,
		.baseDefense 	= 80,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 93,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_BIGPECKS,
		.ability2 = ABILITY_SUPERLUCK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_BLITZLE] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 60,
		.baseDefense 	= 32,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 32,
		.baseSpeed 		= 76,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 99,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_CHERI_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_MOTORDRIVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SAPSIPPER,
		.noFlip = TRUE,
	},

	[SPECIES_ZEBSTRIKA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 100,
		.baseDefense 	= 63,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 116,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 75,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_CHERI_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_MOTORDRIVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SAPSIPPER,
		.noFlip = TRUE,
	},

	[SPECIES_ROGGENROLA] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 75,
		.baseDefense 	= 85,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 15,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 255,
		.expYield = 73,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_EVERSTONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_WEAKARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_BOLDORE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 105,
		.baseDefense 	= 105,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 20,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 120,
		.expYield = 134,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_EVERSTONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_WEAKARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_GIGALITH] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 135,
		.baseDefense 	= 130,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 25,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_EVERSTONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_SANDSTREAM,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_WOOBAT] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 45,
		.baseDefense 	= 43,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 43,
		.baseSpeed 		= 72,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FLYING,
		.catchRate = 190,
		.expYield = 87,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_UNAWARE,
		.ability2 = ABILITY_KLUTZ,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SIMPLE,
		.noFlip = TRUE,
	},

	[SPECIES_SWOOBAT] =
	{
		.baseHP 		= 67,
		.baseAttack 	= 57,
		.baseDefense 	= 55,
		.baseSpAttack 	= 77,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 114,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 124,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_UNAWARE,
		.ability2 = ABILITY_KLUTZ,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SIMPLE,
		.noFlip = TRUE,
	},

	[SPECIES_DRILBUR] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 85,
		.baseDefense 	= 40,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 68,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 120,
		.expYield = 71,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDRUSH,
		.ability2 = ABILITY_MOLDBREAKER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_EXCADRILL] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 135,
		.baseDefense 	= 60,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 88,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_STEEL,
		.catchRate = 60,
		.expYield = 159,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDRUSH,
		.ability2 = ABILITY_MOLDBREAKER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_AUDINO] =
	{
		.baseHP 		= 103,
		.baseAttack 	= 60,
		.baseDefense 	= 86,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 86,
		.baseSpeed 		= 50,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 240,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_SITRUS_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HEALER,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KLUTZ,
		.noFlip = TRUE,
	},

	[SPECIES_TIMBURR] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 55,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 35,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 180,
		.expYield = 75,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50, //70 in SwSh but most likely a bug
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_IRONFIST,
		.noFlip = TRUE,
	},

	[SPECIES_GURDURR] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 105,
		.baseDefense 	= 85,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 40,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 90,
		.expYield = 146,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_IRONFIST,
		.noFlip = TRUE,
	},

	[SPECIES_CONKELDURR] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 140,
		.baseDefense 	= 95,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 45,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 193,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_IRONFIST,
		.noFlip = TRUE,
	},

	[SPECIES_TYMPOLE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 50,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 64,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 255,
		.expYield = 77,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYDRATION,
		.noFlip = TRUE,
	},

	[SPECIES_PALPITOAD] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 65,
		.baseDefense 	= 55,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 69,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 120,
		.expYield = 131,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYDRATION,
		.noFlip = TRUE,
	},

	[SPECIES_SEISMITOAD] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 95,
		.baseDefense 	= 75,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 74,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONTOUCH,
		.noFlip = TRUE,
	},

	[SPECIES_THROH] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 100,
		.baseDefense 	= 85,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 45,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 170,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_EXPERT_BELT,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_INNERFOCUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOLDBREAKER,
		.noFlip = TRUE,
	},

	[SPECIES_SAWK] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 125,
		.baseDefense 	= 75,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 85,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_EXPERT_BELT,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_INNERFOCUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOLDBREAKER,
		.noFlip = TRUE,
	},

	[SPECIES_SEWADDLE] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 53,
		.baseDefense 	= 70,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 42,
		.type1 = TYPE_BUG,
		.type2 = TYPE_GRASS,
		.catchRate = 255,
		.expYield = 75,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MENTAL_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_CHLOROPHYLL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_SWADLOON] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 63,
		.baseDefense 	= 90,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 42,
		.type1 = TYPE_BUG,
		.type2 = TYPE_GRASS,
		.catchRate = 120,
		.expYield = 133,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MENTAL_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_LEAFGUARD,
		.ability2 = ABILITY_CHLOROPHYLL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_LEAVANNY] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 103,
		.baseDefense 	= 80,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 92,
		.type1 = TYPE_BUG,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 186,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MENTAL_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_CHLOROPHYLL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_VENIPEDE] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 45,
		.baseDefense 	= 59,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 39,
		.baseSpeed 		= 57,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 255,
		.expYield = 68,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SPEEDBOOST,
		.ability2 = ABILITY_SWARM,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_WHIRLIPEDE] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 55,
		.baseDefense 	= 99,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 79,
		.baseSpeed 		= 47,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 120,
		.expYield = 126,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SPEEDBOOST,
		.ability2 = ABILITY_SWARM,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_SCOLIPEDE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 89,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 69,
		.baseSpeed 		= 112,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 184,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_PECHA_BERRY,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SPEEDBOOST,
		.ability2 = ABILITY_SWARM,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POISONPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_COTTONEE] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 27,
		.baseDefense 	= 60,
		.baseSpAttack 	= 37,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 66,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FAIRY,
		.catchRate = 190,
		.expYield = 55,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ABSORB_BULB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CHLOROPHYLL,
		.noFlip = TRUE,
	},

	[SPECIES_WHIMSICOTT] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 67,
		.baseDefense 	= 85,
		.baseSpAttack 	= 77,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 116,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FAIRY,
		.catchRate = 75,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ABSORB_BULB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CHLOROPHYLL,
		.noFlip = TRUE,
	},

	[SPECIES_PETILIL] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 35,
		.baseDefense 	= 50,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 55,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ABSORB_BULB,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_OWNTEMPO,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LEAFGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_LILLIGANT] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 90,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ABSORB_BULB,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_OWNTEMPO,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LEAFGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_BASCULIN_RED] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 92,
		.baseDefense 	= 65,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 98,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 25,
		.expYield = 136,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DEEP_SEA_TOOTH,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_RECKLESS,
		.ability2 = ABILITY_ADAPTABILITY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOLDBREAKER,
		.noFlip = TRUE,
	},

	[SPECIES_SANDILE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 72,
		.baseDefense 	= 35,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 65,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_DARK,
		.catchRate = 180,
		.expYield = 58,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BLACK_GLASSES,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_MOXIE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANGERPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_KROKOROK] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 82,
		.baseDefense 	= 45,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 74,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_DARK,
		.catchRate = 90,
		.expYield = 123,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BLACK_GLASSES,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_MOXIE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANGERPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_KROOKODILE] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 117,
		.baseDefense 	= 80,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 92,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 229,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_BLACK_GLASSES,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_MOXIE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANGERPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_DARUMAKA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 90,
		.baseDefense 	= 45,
		.baseSpAttack 	= 15,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 50,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 120,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_RAWST_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_HUSTLE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_DARMANITAN] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 140,
		.baseDefense 	= 55,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 95,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 60,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_RAWST_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SHEERFORCE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ZENMODE,
		.noFlip = TRUE,
	},

	[SPECIES_MARACTUS] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 86,
		.baseDefense 	= 67,
		.baseSpAttack 	= 106,
		.baseSpDefense 	= 67,
		.baseSpeed 		= 60,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 255,
		.expYield = 161,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MIRACLE_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_CHLOROPHYLL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STORMDRAIN,
		.noFlip = TRUE,
	},

	[SPECIES_DWEBBLE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 85,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 55,
		.type1 = TYPE_BUG,
		.type2 = TYPE_ROCK,
		.catchRate = 190,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_CRUSTLE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 105,
		.baseDefense 	= 125,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 45,
		.type1 = TYPE_BUG,
		.type2 = TYPE_ROCK,
		.catchRate = 75,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_SCRAGGY] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 75,
		.baseDefense 	= 70,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 48,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FIGHTING,
		.catchRate = 180,
		.expYield = 70,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHED_SHELL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_MOXIE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INTIMIDATE,
		.noFlip = TRUE,
	},

	[SPECIES_SCRAFTY] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 90,
		.baseDefense 	= 115,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 58,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FIGHTING,
		.catchRate = 90,
		.expYield = 171,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHED_SHELL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_MOXIE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INTIMIDATE,
		.noFlip = TRUE,
	},

	[SPECIES_SIGILYPH] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 58,
		.baseDefense 	= 80,
		.baseSpAttack 	= 103,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 97,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_TINTEDLENS,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WONDERSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_YAMASK] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 30,
		.baseDefense 	= 85,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 30,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 190,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_MUMMY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_COFAGRIGUS] =
	{
		.baseHP 		= 58,
		.baseAttack 	= 50,
		.baseDefense 	= 145,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 30,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 90,
		.expYield = 169,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_MUMMY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TIRTOUGA] =
	{
		.baseHP 		= 54,
		.baseAttack 	= 78,
		.baseDefense 	= 103,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 22,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ROCK,
		.catchRate = 45,
		.expYield = 71,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SOLIDROCK,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},

	[SPECIES_CARRACOSTA] =
	{
		.baseHP 		= 74,
		.baseAttack 	= 108,
		.baseDefense 	= 133,
		.baseSpAttack 	= 83,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 32,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ROCK,
		.catchRate = 45,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_SOLIDROCK,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},

	[SPECIES_ARCHEN] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 112,
		.baseDefense 	= 45,
		.baseSpAttack 	= 74,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 70,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 71,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_DEFEATIST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCHEOPS] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 140,
		.baseDefense 	= 65,
		.baseSpAttack 	= 112,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 110,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_DEFEATIST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TRUBBISH] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 50,
		.baseDefense 	= 62,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 62,
		.baseSpeed 		= 65,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 190,
		.expYield = 66,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_BLACK_SLUDGE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STENCH,
		.ability2 = ABILITY_STICKYHOLD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AFTERMATH,
		.noFlip = TRUE,
	},

	[SPECIES_GARBODOR] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 95,
		.baseDefense 	= 82,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 82,
		.baseSpeed 		= 75,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 60,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_BLACK_SLUDGE,
		.item2 = ITEM_NUGGET,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STENCH,
		.ability2 = ABILITY_WEAKARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AFTERMATH,
		.noFlip = TRUE,
	},

	[SPECIES_ZORUA] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 65,
		.baseDefense 	= 40,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 65,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 75,
		.expYield = 66,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_ILLUSION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ZOROARK] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 105,
		.baseDefense 	= 60,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 105,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_ILLUSION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MINCCINO] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 50,
		.baseDefense 	= 40,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 75,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_CHESTO_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SKILLLINK,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CUTECHARM,
		.noFlip = TRUE,
	},

	[SPECIES_CINCCINO] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 95,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 115,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 60,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_CHESTO_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SKILLLINK,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CUTECHARM,
		.noFlip = TRUE,
	},

	[SPECIES_GOTHITA] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 30,
		.baseDefense 	= 50,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 45,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 200,
		.expYield = 58,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PERSIM_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_FRISK,
		.ability2 = ABILITY_SHADOWTAG,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_COMPETITIVE,
		.noFlip = TRUE,
	},

	[SPECIES_GOTHORITA] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 45,
		.baseDefense 	= 70,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 55,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 100,
		.expYield = 137,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PERSIM_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_FRISK,
		.ability2 = ABILITY_SHADOWTAG,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_COMPETITIVE,
		.noFlip = TRUE,
	},

	[SPECIES_GOTHITELLE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 55,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 65,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 50,
		.expYield = 221,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PERSIM_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_FRISK,
		.ability2 = ABILITY_SHADOWTAG,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_COMPETITIVE,
		.noFlip = TRUE,
	},

	[SPECIES_SOLOSIS] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 30,
		.baseDefense 	= 40,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 20,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 200,
		.expYield = 58,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PERSIM_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_REGENERATOR,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_DUOSION] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 40,
		.baseDefense 	= 50,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 30,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 100,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PERSIM_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_REGENERATOR,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_REUNICLUS] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 65,
		.baseDefense 	= 75,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 30,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 50,
		.expYield = 221,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_PERSIM_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_REGENERATOR,
		.ability2 = ABILITY_MAGICGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_DUCKLETT] =
	{
		.baseHP 		= 62,
		.baseAttack 	= 44,
		.baseDefense 	= 50,
		.baseSpAttack 	= 44,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 55,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FLYING,
		.catchRate = 190,
		.expYield = 61,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_HYDRATION,
		.ability2 = ABILITY_BIGPECKS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_SWANNA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 87,
		.baseDefense 	= 63,
		.baseSpAttack 	= 87,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 98,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_HYDRATION,
		.ability2 = ABILITY_BIGPECKS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_VANILLITE] =
	{
		.baseHP 		= 36,
		.baseAttack 	= 50,
		.baseDefense 	= 50,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 44,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 255,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NEVER_MELT_ICE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_ICEBODY,
		.ability2 = ABILITY_SNOWCLOAK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_VANILLISH] =
	{
		.baseHP 		= 51,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 59,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 120,
		.expYield = 138,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NEVER_MELT_ICE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_ICEBODY,
		.ability2 = ABILITY_SNOWCLOAK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_VANILLUXE] =
	{
		.baseHP 		= 71,
		.baseAttack 	= 95,
		.baseDefense 	= 85,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 79,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 241,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NEVER_MELT_ICE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_ICEBODY,
		.ability2 = ABILITY_SNOWWARNING,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_DEERLING] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 75,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SERENEGRACE,
		.noFlip = TRUE,
	},

	[SPECIES_SAWSBUCK] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 95,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SERENEGRACE,
		.noFlip = TRUE,
	},

	[SPECIES_EMOLGA] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 75,
		.baseDefense 	= 60,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 103,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_FLYING,
		.catchRate = 200,
		.expYield = 150,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_CHERI_BERRY,
		.item2 = ITEM_CHERI_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOTORDRIVE,
		.noFlip = TRUE,
	},

	[SPECIES_KARRABLAST] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 75,
		.baseDefense 	= 45,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 60,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 200,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_SHEDSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NOGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_ESCAVALIER] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 135,
		.baseDefense 	= 105,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 20,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 75,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_FOONGUS] =
	{
		.baseHP 		= 69,
		.baseAttack 	= 55,
		.baseDefense 	= 45,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 15,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 190,
		.expYield = 59,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_TINY_MUSHROOM,
		.item2 = ITEM_BIG_MUSHROOM,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_EFFECTSPORE,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_REGENERATOR,
		.noFlip = TRUE,
	},

	[SPECIES_AMOONGUSS] =
	{
		.baseHP 		= 114,
		.baseAttack 	= 85,
		.baseDefense 	= 70,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 75,
		.expYield = 162,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_TINY_MUSHROOM,
		.item2 = ITEM_BIG_MUSHROOM,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_EFFECTSPORE,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_REGENERATOR,
		.noFlip = TRUE,
	},

	[SPECIES_FRILLISH] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 40,
		.baseDefense 	= 50,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 40,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GHOST,
		.catchRate = 190,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_CURSEDBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_JELLICENT] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 60,
		.baseDefense 	= 70,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GHOST,
		.catchRate = 60,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_CURSEDBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_ALOMOMOLA] =
	{
		.baseHP 		= 165,
		.baseAttack 	= 75,
		.baseDefense 	= 80,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 65,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 75,
		.expYield = 165,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_HEALER,
		.ability2 = ABILITY_HYDRATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_REGENERATOR,
		.noFlip = TRUE,
	},

	[SPECIES_JOLTIK] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 47,
		.baseDefense 	= 50,
		.baseSpAttack 	= 57,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 65,
		.type1 = TYPE_BUG,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 64,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_COMPOUNDEYES,
		.ability2 = ABILITY_UNNERVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWARM,
		.noFlip = TRUE,
	},

	[SPECIES_GALVANTULA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 77,
		.baseDefense 	= 60,
		.baseSpAttack 	= 97,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 108,
		.type1 = TYPE_BUG,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 75,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_COMPOUNDEYES,
		.ability2 = ABILITY_UNNERVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWARM,
		.noFlip = TRUE,
	},

	[SPECIES_FERROSEED] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 50,
		.baseDefense 	= 91,
		.baseSpAttack 	= 24,
		.baseSpDefense 	= 86,
		.baseSpeed 		= 10,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_STEEL,
		.catchRate = 255,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STICKY_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_IRONBARBS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FERROTHORN] =
	{
		.baseHP 		= 74,
		.baseAttack 	= 94,
		.baseDefense 	= 131,
		.baseSpAttack 	= 54,
		.baseSpDefense 	= 116,
		.baseSpeed 		= 20,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_STEEL,
		.catchRate = 90,
		.expYield = 171,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STICKY_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_IRONBARBS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANTICIPATION,
		.noFlip = TRUE,
	},

	[SPECIES_KLINK] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 55,
		.baseDefense 	= 70,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 30,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 130,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_MINUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PLUS,
		.noFlip = TRUE,
	},

	[SPECIES_KLANG] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 80,
		.baseDefense 	= 95,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 50,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 60,
		.expYield = 154,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_MINUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PLUS,
		.noFlip = TRUE,
	},

	[SPECIES_KLINKLANG] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 115,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 90,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 30,
		.expYield = 234,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_MINUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PLUS,
		.noFlip = TRUE,
	},

	[SPECIES_TYNAMO] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 60,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 55,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_EELEKTRIK] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 85,
		.baseDefense 	= 70,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 40,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 60,
		.expYield = 142,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_EELEKTROSS] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 115,
		.baseDefense 	= 80,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 50,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 30,
		.expYield = 232,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ELGYEM] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 55,
		.baseDefense 	= 55,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 30,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 255,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_TELEPATHY,
		.ability2 = ABILITY_SYNCHRONIZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_BEHEEYEM] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 75,
		.baseDefense 	= 75,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 40,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 90,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_TELEPATHY,
		.ability2 = ABILITY_SYNCHRONIZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANALYTIC,
		.noFlip = TRUE,
	},

	[SPECIES_LITWICK] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 30,
		.baseDefense 	= 55,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 20,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_FIRE,
		.catchRate = 190,
		.expYield = 55,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_FLAMEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHADOWTAG,
		.noFlip = TRUE,
	},

	[SPECIES_LAMPENT] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 40,
		.baseDefense 	= 60,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 55,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_FIRE,
		.catchRate = 90,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_FLAMEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHADOWTAG,
		.noFlip = TRUE,
	},

	[SPECIES_CHANDELURE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 55,
		.baseDefense 	= 90,
		.baseSpAttack 	= 145,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 80,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 234,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_FLAMEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_AXEW] =
	{
		.baseHP 		= 46,
		.baseAttack 	= 87,
		.baseDefense 	= 60,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 57,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 75,
		.expYield = 64,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_RIVALRY,
		.ability2 = ABILITY_MOLDBREAKER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_FRAXURE] =
	{
		.baseHP 		= 66,
		.baseAttack 	= 117,
		.baseDefense 	= 70,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 67,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 60,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_RIVALRY,
		.ability2 = ABILITY_MOLDBREAKER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_HAXORUS] =
	{
		.baseHP 		= 76,
		.baseAttack 	= 147,
		.baseDefense 	= 90,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 97,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_RIVALRY,
		.ability2 = ABILITY_MOLDBREAKER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_CUBCHOO] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 70,
		.baseDefense 	= 40,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 40,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 120,
		.expYield = 61,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ASPEAR_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SNOWCLOAK,
		.ability2 = ABILITY_SLUSHRUSH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_BEARTIC] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 130,
		.baseDefense 	= 80,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 50,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 60,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_ASPEAR_BERRY,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SNOWCLOAK,
		.ability2 = ABILITY_SLUSHRUSH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},

	[SPECIES_CRYOGONAL] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 50,
		.baseDefense 	= 50,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 135,
		.baseSpeed 		= 105,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 25,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NEVER_MELT_ICE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SHELMET] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 40,
		.baseDefense 	= 85,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 25,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 200,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_HYDRATION,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_ACCELGOR] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 70,
		.baseDefense 	= 40,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 145,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 75,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_HYDRATION,
		.ability2 = ABILITY_STICKYHOLD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNBURDEN,
		.noFlip = TRUE,
	},

	[SPECIES_STUNFISK] =
	{
		.baseHP 		= 109,
		.baseAttack 	= 66,
		.baseDefense 	= 84,
		.baseSpAttack 	= 81,
		.baseSpDefense 	= 99,
		.baseSpeed 		= 32,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 75,
		.expYield = 165,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SOFT_SAND,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 70,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_LIMBER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_MIENFOO] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 85,
		.baseDefense 	= 50,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 180,
		.expYield = 70,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_RECKLESS,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_MIENSHAO] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 125,
		.baseDefense 	= 60,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 105,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_RECKLESS,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_DRUDDIGON] =
	{
		.baseHP 		= 77,
		.baseAttack 	= 120,
		.baseDefense 	= 90,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 48,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DRAGON_FANG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_ROUGHSKIN,
		.ability2 = ABILITY_MOLDBREAKER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_GOLETT] =
	{
		.baseHP 		= 59,
		.baseAttack 	= 74,
		.baseDefense 	= 50,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 35,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GHOST,
		.catchRate = 190,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LIGHT_CLAY,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_IRONFIST,
		.ability2 = ABILITY_NOGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KLUTZ,
		.noFlip = TRUE,
	},

	[SPECIES_GOLURK] =
	{
		.baseHP 		= 89,
		.baseAttack 	= 124,
		.baseDefense 	= 80,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 55,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GHOST,
		.catchRate = 90,
		.expYield = 169,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LIGHT_CLAY,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_IRONFIST,
		.ability2 = ABILITY_NOGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KLUTZ,
		.noFlip = TRUE,
	},

	[SPECIES_PAWNIARD] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 85,
		.baseDefense 	= 70,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 60,
		.type1 = TYPE_DARK,
		.type2 = TYPE_STEEL,
		.catchRate = 120,
		.expYield = 68,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_DEFIANT,
		.ability2 = ABILITY_INNERFOCUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRESSURE,
		.noFlip = TRUE,
	},

	[SPECIES_BISHARP] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 125,
		.baseDefense 	= 100,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 70,
		.type1 = TYPE_DARK,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_DEFIANT,
		.ability2 = ABILITY_INNERFOCUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRESSURE,
		.noFlip = TRUE,
	},

	[SPECIES_BOUFFALANT] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 110,
		.baseDefense 	= 95,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 55,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RECKLESS,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOUNDPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_RUFFLET] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 83,
		.baseDefense 	= 50,
		.baseSpAttack 	= 37,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 190,
		.expYield = 70,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HUSTLE,
		.noFlip = TRUE,
	},

	[SPECIES_BRAVIARY] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 123,
		.baseDefense 	= 75,
		.baseSpAttack 	= 57,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 80,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 60,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_VULLABY] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 55,
		.baseDefense 	= 75,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 60,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FLYING,
		.catchRate = 190,
		.expYield = 74,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_BIGPECKS,
		.ability2 = ABILITY_OVERCOAT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_MANDIBUZZ] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 65,
		.baseDefense 	= 105,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 80,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FLYING,
		.catchRate = 60,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_BIGPECKS,
		.ability2 = ABILITY_OVERCOAT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WEAKARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_HEATMOR] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 97,
		.baseDefense 	= 66,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 66,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 90,
		.expYield = 169,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_FLAME_ORB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_FLASHFIRE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WHITESMOKE,
		.noFlip = TRUE,
	},

	[SPECIES_DURANT] =
	{
		.baseHP 		= 58,
		.baseAttack 	= 109,
		.baseDefense 	= 112,
		.baseSpAttack 	= 48,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 109,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 90,
		.expYield = 169,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_HUSTLE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TRUANT,
		.noFlip = TRUE,
	},

	[SPECIES_DEINO] =
	{
		.baseHP 		= 52,
		.baseAttack 	= 65,
		.baseDefense 	= 50,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 38,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_HUSTLE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ZWEILOUS] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 85,
		.baseDefense 	= 70,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 58,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 147,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_HUSTLE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_HYDREIGON] =
	{
		.baseHP 		= 92,
		.baseAttack 	= 105,
		.baseDefense 	= 90,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 98,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LARVESTA] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 85,
		.baseDefense 	= 55,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 60,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 72,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_FLAMEBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWARM,
		.noFlip = TRUE,
	},

	[SPECIES_VOLCARONA] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 60,
		.baseDefense 	= 65,
		.baseSpAttack 	= 135,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 100,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FIRE,
		.catchRate = 15,
		.expYield = 248,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_SILVER_POWDER,
		.item2 = ITEM_SILVER_POWDER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_FLAMEBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWARM,
		.noFlip = TRUE,
	},

	[SPECIES_COBALION] =
	{
		.baseHP 		= 91,
		.baseAttack 	= 90,
		.baseDefense 	= 129,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 72,
		.baseSpeed 		= 108,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_JUSTIFIED,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TERRAKION] =
	{
		.baseHP 		= 91,
		.baseAttack 	= 129,
		.baseDefense 	= 90,
		.baseSpAttack 	= 72,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 108,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_JUSTIFIED,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_VIRIZION] =
	{
		.baseHP 		= 91,
		.baseAttack 	= 90,
		.baseDefense 	= 72,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 129,
		.baseSpeed 		= 108,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_JUSTIFIED,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TORNADUS] =
	{
		.baseHP 		= 79,
		.baseAttack 	= 115,
		.baseDefense 	= 70,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 111,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_THUNDURUS] =
	{
		.baseHP 		= 79,
		.baseAttack 	= 115,
		.baseDefense 	= 70,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 111,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_RESHIRAM] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 120,
		.baseDefense 	= 100,
		.baseSpAttack 	= 150,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 90,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_TURBOBLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ZEKROM] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 150,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 90,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_TERAVOLT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LANDORUS] =
	{
		.baseHP 		= 89,
		.baseAttack 	= 125,
		.baseDefense 	= 90,
		.baseSpAttack 	= 115,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 101,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SANDFORCE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_KYUREM] =
	{
		.baseHP 		= 125,
		.baseAttack 	= 130,
		.baseDefense 	= 90,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 95,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_ICE,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_KELDEO] =
	{
		.baseHP 		= 91,
		.baseAttack 	= 72,
		.baseDefense 	= 90,
		.baseSpAttack 	= 129,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 108,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_JUSTIFIED,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MELOETTA] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 77,
		.baseDefense 	= 77,
		.baseSpAttack 	= 128,
		.baseSpDefense 	= 128,
		.baseSpeed 		= 90,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 1,
		.item1 = ITEM_STAR_PIECE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SERENEGRACE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GENESECT] =
	{
		.baseHP 		= 71,
		.baseAttack 	= 120,
		.baseDefense 	= 95,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 99,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DOWNLOAD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_UNFEZANT_F] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 115,
		.baseDefense 	= 80,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 93,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_BIGPECKS,
		.ability2 = ABILITY_SUPERLUCK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RIVALRY,
		.noFlip = TRUE,
	},

	[SPECIES_FRILLISH_F] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 40,
		.baseDefense 	= 50,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 40,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GHOST,
		.catchRate = 190,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_CURSEDBODY,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_JELLICENT_F] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 60,
		.baseDefense 	= 70,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GHOST,
		.catchRate = 60,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_CURSEDBODY,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DAMP,
		.noFlip = TRUE,
	},

	[SPECIES_BURMY_SANDY] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 29,
		.baseDefense 	= 45,
		.baseSpAttack 	= 29,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 36,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 120,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_BURMY_TRASH] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 29,
		.baseDefense 	= 45,
		.baseSpAttack 	= 29,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 36,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 120,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_WORMADAM_SANDY] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 79,
		.baseDefense 	= 105,
		.baseSpAttack 	= 59,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 36,
		.type1 = TYPE_BUG,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 148,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SILVER_POWDER,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_ANTICIPATION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_WORMADAM_TRASH] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 69,
		.baseDefense 	= 95,
		.baseSpAttack 	= 69,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 36,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 148,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SILVER_POWDER,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_ANTICIPATION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OVERCOAT,
		.noFlip = TRUE,
	},

	[SPECIES_SHELLOS_EAST] =
	{
		.baseHP 		= 76,
		.baseAttack 	= 48,
		.baseDefense 	= 48,
		.baseSpAttack 	= 57,
		.baseSpDefense 	= 62,
		.baseSpeed 		= 34,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 65,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 255,
		.friendship = 0,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_STICKYHOLD,
		.ability2 = ABILITY_STORMDRAIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_GASTRODON_EAST] =
	{
		.baseHP 		= 111,
		.baseAttack 	= 83,
		.baseDefense 	= 68,
		.baseSpAttack 	= 92,
		.baseSpDefense 	= 82,
		.baseSpeed 		= 39,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 75,
		.expYield = 166,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_STICKYHOLD,
		.ability2 = ABILITY_STORMDRAIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_ROTOM_HEAT] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 107,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 107,
		.baseSpeed 		= 86,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ROTOM_WASH] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 107,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 107,
		.baseSpeed 		= 86,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ROTOM_FROST] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 107,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 107,
		.baseSpeed 		= 86,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ROTOM_FAN] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 107,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 107,
		.baseSpeed 		= 86,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ROTOM_MOW] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 107,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 107,
		.baseSpeed 		= 86,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GIRATINA_ORIGIN] =
	{
		.baseHP 		= 150,
		.baseAttack 	= 120,
		.baseDefense 	= 100,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 90,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_DRAGON,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SHAYMIN_SKY] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 103,
		.baseDefense 	= 75,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 127,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SERENEGRACE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_FIGHT] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_FLYING] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_POISON] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_GROUND] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_ROCK] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_BUG] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_GHOST] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_STEEL] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_FIRE] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_WATER] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_GRASS] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_ELECTRIC] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_PSYCHIC] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_ICE] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_DRAGON] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_DARK] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_BASCULIN_BLUE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 92,
		.baseDefense 	= 65,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 98,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 25,
		.expYield = 136,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_DEEP_SEA_SCALE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_ADAPTABILITY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOLDBREAKER,
		.noFlip = TRUE,
	},

	[SPECIES_DARMANITANZEN] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 30,
		.baseDefense 	= 105,
		.baseSpAttack 	= 140,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 55,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 60,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_ZENMODE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ZENMODE,
		.noFlip = TRUE,
	},

	[SPECIES_DEERLING_SUMMER] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 75,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SERENEGRACE,
		.noFlip = TRUE,
	},

	[SPECIES_DEERLING_AUTUMN] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 75,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SERENEGRACE,
		.noFlip = TRUE,
	},

	[SPECIES_DEERLING_WINTER] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 75,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SERENEGRACE,
		.noFlip = TRUE,
	},

	[SPECIES_SAWSBUCK_SUMMER] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 95,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SERENEGRACE,
		.noFlip = TRUE,
	},

	[SPECIES_SAWSBUCK_AUTUMN] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 95,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SERENEGRACE,
		.noFlip = TRUE,
	},

	[SPECIES_SAWSBUCK_WINTER] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 95,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SERENEGRACE,
		.noFlip = TRUE,
	},

	[SPECIES_HIPPOPOTAS_F] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 72,
		.baseDefense 	= 78,
		.baseSpAttack 	= 38,
		.baseSpDefense 	= 42,
		.baseSpeed 		= 32,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 140,
		.expYield = 95,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDSTREAM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_HIPPOWDON_F] =
	{
		.baseHP 		= 108,
		.baseAttack 	= 112,
		.baseDefense 	= 118,
		.baseSpAttack 	= 68,
		.baseSpDefense 	= 72,
		.baseSpeed 		= 47,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 60,
		.expYield = 198,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDSTREAM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_MELOETTA_PIROUETTE] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 128,
		.baseDefense 	= 90,
		.baseSpAttack 	= 77,
		.baseSpDefense 	= 77,
		.baseSpeed 		= 128,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SERENEGRACE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GENESECT_SHOCK] =
	{
		.baseHP 		= 71,
		.baseAttack 	= 120,
		.baseDefense 	= 95,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 99,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DOWNLOAD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GENESECT_BURN] =
	{
		.baseHP 		= 71,
		.baseAttack 	= 120,
		.baseDefense 	= 95,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 99,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DOWNLOAD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GENESECT_CHILL] =
	{
		.baseHP 		= 71,
		.baseAttack 	= 120,
		.baseDefense 	= 95,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 99,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DOWNLOAD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GENESECT_DOUSE] =
	{
		.baseHP 		= 71,
		.baseAttack 	= 120,
		.baseDefense 	= 95,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 99,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DOWNLOAD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CHERRIM_SUN] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 60,
		.baseDefense 	= 70,
		.baseSpAttack 	= 87,
		.baseSpDefense 	= 78,
		.baseSpeed 		= 85,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 158,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_FLOWERGIFT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_KYUREM_BLACK] =
	{
		.baseHP 		= 125,
		.baseAttack 	= 170,
		.baseDefense 	= 100,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 95,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_ICE,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_TERAVOLT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_KYUREM_WHITE] =
	{
		.baseHP 		= 125,
		.baseAttack 	= 120,
		.baseDefense 	= 90,
		.baseSpAttack 	= 170,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 95,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_ICE,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_TURBOBLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TORNADUS_THERIAN] =
	{
		.baseHP 		= 79,
		.baseAttack 	= 100,
		.baseDefense 	= 80,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 121,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_REGENERATOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_THUNDURUS_THERIAN] =
	{
		.baseHP 		= 79,
		.baseAttack 	= 105,
		.baseDefense 	= 70,
		.baseSpAttack 	= 145,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 101,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_VOLTABSORB,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LANDORUS_THERIAN] =
	{
		.baseHP 		= 89,
		.baseAttack 	= 145,
		.baseDefense 	= 90,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 91,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_KELDEO_RESOLUTE] =
	{
		.baseHP 		= 91,
		.baseAttack 	= 72,
		.baseDefense 	= 90,
		.baseSpAttack 	= 129,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 108,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_JUSTIFIED,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CHESPIN] =
	{
		.baseHP 		= 56,
		.baseAttack 	= 61,
		.baseDefense 	= 65,
		.baseSpAttack 	= 48,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 38,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BULLETPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_QUILLADIN] =
	{
		.baseHP 		= 61,
		.baseAttack 	= 78,
		.baseDefense 	= 95,
		.baseSpAttack 	= 56,
		.baseSpDefense 	= 58,
		.baseSpeed 		= 57,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 142,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BULLETPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_CHESNAUGHT] =
	{
		.baseHP 		= 88,
		.baseAttack 	= 107,
		.baseDefense 	= 122,
		.baseSpAttack 	= 74,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 64,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 239,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BULLETPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_FENNEKIN] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 40,
		.baseSpAttack 	= 62,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 60,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MAGICIAN,
		.noFlip = TRUE,
	},

	[SPECIES_BRAIXEN] =
	{
		.baseHP 		= 59,
		.baseAttack 	= 59,
		.baseDefense 	= 58,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 73,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 143,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MAGICIAN,
		.noFlip = TRUE,
	},

	[SPECIES_DELPHOX] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 69,
		.baseDefense 	= 72,
		.baseSpAttack 	= 114,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 104,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 240,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MAGICIAN,
		.noFlip = TRUE,
	},

	[SPECIES_FROAKIE] =
	{
		.baseHP 		= 41,
		.baseAttack 	= 56,
		.baseDefense 	= 40,
		.baseSpAttack 	= 62,
		.baseSpDefense 	= 44,
		.baseSpeed 		= 71,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PROTEAN,
		.noFlip = TRUE,
	},

	[SPECIES_FROGADIER] =
	{
		.baseHP 		= 54,
		.baseAttack 	= 63,
		.baseDefense 	= 52,
		.baseSpAttack 	= 83,
		.baseSpDefense 	= 56,
		.baseSpeed 		= 97,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 142,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PROTEAN,
		.noFlip = TRUE,
	},

	[SPECIES_GRENINJA] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 95,
		.baseDefense 	= 67,
		.baseSpAttack 	= 103,
		.baseSpDefense 	= 71,
		.baseSpeed 		= 122,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 239,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_BATTLEBOND,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PROTEAN,
		.noFlip = TRUE,
	},

	[SPECIES_BUNNELBY] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 36,
		.baseDefense 	= 38,
		.baseSpAttack 	= 32,
		.baseSpDefense 	= 36,
		.baseSpeed 		= 57,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 47,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_HUGEPOWER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CHEEKPOUCH,
		.noFlip = TRUE,
	},

	[SPECIES_DIGGERSBY] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 56,
		.baseDefense 	= 77,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 77,
		.baseSpeed 		= 78,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_GROUND,
		.catchRate = 127,
		.expYield = 148,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_HUGEPOWER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CHEEKPOUCH,
		.noFlip = TRUE,
	},

	[SPECIES_FLETCHLING] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 50,
		.baseDefense 	= 43,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 38,
		.baseSpeed 		= 62,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 56,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_BIGPECKS,
		.ability2 = ABILITY_GALEWINGS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GALEWINGS,
		.noFlip = TRUE,
	},

	[SPECIES_FLETCHINDER] =
	{
		.baseHP 		= 62,
		.baseAttack 	= 73,
		.baseDefense 	= 55,
		.baseSpAttack 	= 56,
		.baseSpDefense 	= 52,
		.baseSpeed 		= 84,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FLYING,
		.catchRate = 120,
		.expYield = 134,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_FLAMEBODY,
		.ability2 = ABILITY_GALEWINGS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GALEWINGS,
		.noFlip = TRUE,
	},

	[SPECIES_TALONFLAME] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 81,
		.baseDefense 	= 71,
		.baseSpAttack 	= 74,
		.baseSpDefense 	= 69,
		.baseSpeed 		= 126,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_FLAMEBODY,
		.ability2 = ABILITY_GALEWINGS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GALEWINGS,
		.noFlip = TRUE,
	},

	[SPECIES_SCATTERBUG] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 35,
		.baseDefense 	= 40,
		.baseSpAttack 	= 27,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 35,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 255,
		.expYield = 40,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_SPEWPA] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 22,
		.baseDefense 	= 60,
		.baseSpAttack 	= 27,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 29,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 120,
		.expYield = 75,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHEDSKIN,
		.ability2 = ABILITY_SHEDSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_LITLEO] =
	{
		.baseHP 		= 62,
		.baseAttack 	= 50,
		.baseDefense 	= 58,
		.baseSpAttack 	= 73,
		.baseSpDefense 	= 54,
		.baseSpeed 		= 72,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_NORMAL,
		.catchRate = 220,
		.expYield = 74,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(87.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RIVALRY,
		.ability2 = ABILITY_UNNERVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOXIE,
		.noFlip = TRUE,
	},

	[SPECIES_PYROAR] =
	{
		.baseHP 		= 86,
		.baseAttack 	= 68,
		.baseDefense 	= 72,
		.baseSpAttack 	= 109,
		.baseSpDefense 	= 66,
		.baseSpeed 		= 106,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_NORMAL,
		.catchRate = 65,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(87.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RIVALRY,
		.ability2 = ABILITY_UNNERVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOXIE,
		.noFlip = TRUE,
	},

	[SPECIES_FLABEBE] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 38,
		.baseDefense 	= 39,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 79,
		.baseSpeed 		= 42,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLOETTE] =
	{
		.baseHP 		= 54,
		.baseAttack 	= 45,
		.baseDefense 	= 47,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 98,
		.baseSpeed 		= 52,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 120,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLORGES] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 65,
		.baseDefense 	= 68,
		.baseSpAttack 	= 112,
		.baseSpDefense 	= 154,
		.baseSpeed 		= 75,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 248,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_SKIDDO] =
	{
		.baseHP 		= 66,
		.baseAttack 	= 65,
		.baseDefense 	= 48,
		.baseSpAttack 	= 62,
		.baseSpDefense 	= 57,
		.baseSpeed 		= 52,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 200,
		.expYield = 70,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SAPSIPPER,
		.ability2 = ABILITY_GRASSPELT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GRASSPELT,
		.noFlip = TRUE,
	},

	[SPECIES_GOGOAT] =
	{
		.baseHP 		= 123,
		.baseAttack 	= 100,
		.baseDefense 	= 62,
		.baseSpAttack 	= 97,
		.baseSpDefense 	= 81,
		.baseSpeed 		= 68,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 186,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SAPSIPPER,
		.ability2 = ABILITY_GRASSPELT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GRASSPELT,
		.noFlip = TRUE,
	},

	[SPECIES_PANCHAM] =
	{
		.baseHP 		= 67,
		.baseAttack 	= 82,
		.baseDefense 	= 62,
		.baseSpAttack 	= 46,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 43,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 220,
		.expYield = 70,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MENTAL_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 24,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_IRONFIST,
		.ability2 = ABILITY_MOLDBREAKER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SCRAPPY,
		.noFlip = TRUE,
	},

	[SPECIES_PANGORO] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 124,
		.baseDefense 	= 78,
		.baseSpAttack 	= 69,
		.baseSpDefense 	= 71,
		.baseSpeed 		= 58,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_DARK,
		.catchRate = 65,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MENTAL_HERB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_IRONFIST,
		.ability2 = ABILITY_MOLDBREAKER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SCRAPPY,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ESPURR] =
	{
		.baseHP 		= 62,
		.baseAttack 	= 48,
		.baseDefense 	= 54,
		.baseSpAttack 	= 63,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 68,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 190,
		.expYield = 71,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OWNTEMPO,
		.noFlip = TRUE,
	},

	[SPECIES_MEOWSTIC] =
	{
		.baseHP 		= 74,
		.baseAttack 	= 48,
		.baseDefense 	= 76,
		.baseSpAttack 	= 83,
		.baseSpDefense 	= 81,
		.baseSpeed 		= 104,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 75,
		.expYield = 163,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PRANKSTER,
		.noFlip = TRUE,
	},

	[SPECIES_HONEDGE] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 80,
		.baseDefense 	= 100,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 37,
		.baseSpeed 		= 28,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_GHOST,
		.catchRate = 180,
		.expYield = 65,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_NOGUARD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_DOUBLADE] =
	{
		.baseHP 		= 59,
		.baseAttack 	= 110,
		.baseDefense 	= 150,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 49,
		.baseSpeed 		= 35,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_GHOST,
		.catchRate = 90,
		.expYield = 157,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_NOGUARD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_AEGISLASH] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 50,
		.baseDefense 	= 150,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 150,
		.baseSpeed 		= 60,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 234,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STANCECHANGE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SPRITZEE] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 52,
		.baseDefense 	= 60,
		.baseSpAttack 	= 63,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 23,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 200,
		.expYield = 68,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HEALER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_AROMATISSE] =
	{
		.baseHP 		= 101,
		.baseAttack 	= 72,
		.baseDefense 	= 72,
		.baseSpAttack 	= 99,
		.baseSpDefense 	= 89,
		.baseSpeed 		= 29,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 140,
		.expYield = 162,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HEALER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_SWIRLIX] =
	{
		.baseHP 		= 62,
		.baseAttack 	= 48,
		.baseDefense 	= 66,
		.baseSpAttack 	= 59,
		.baseSpDefense 	= 57,
		.baseSpeed 		= 49,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 200,
		.expYield = 68,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNBURDEN,
		.noFlip = TRUE,
	},

	[SPECIES_SLURPUFF] =
	{
		.baseHP 		= 82,
		.baseAttack 	= 80,
		.baseDefense 	= 86,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 72,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 140,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNBURDEN,
		.noFlip = TRUE,
	},

	[SPECIES_INKAY] =
	{
		.baseHP 		= 53,
		.baseAttack 	= 54,
		.baseDefense 	= 53,
		.baseSpAttack 	= 37,
		.baseSpDefense 	= 46,
		.baseSpeed 		= 45,
		.type1 = TYPE_DARK,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 190,
		.expYield = 58,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_CONTRARY,
		.ability2 = ABILITY_SUCTIONCUPS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_MALAMAR] =
	{
		.baseHP 		= 86,
		.baseAttack 	= 92,
		.baseDefense 	= 88,
		.baseSpAttack 	= 68,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 73,
		.type1 = TYPE_DARK,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 80,
		.expYield = 169,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_CONTRARY,
		.ability2 = ABILITY_SUCTIONCUPS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INFILTRATOR,
		.noFlip = TRUE,
	},

	[SPECIES_BINACLE] =
	{
		.baseHP 		= 42,
		.baseAttack 	= 52,
		.baseDefense 	= 67,
		.baseSpAttack 	= 39,
		.baseSpDefense 	= 56,
		.baseSpeed 		= 50,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_WATER,
		.catchRate = 120,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_TOUGHCLAWS,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKPOCKET,
		.noFlip = TRUE,
	},

	[SPECIES_BARBARACLE] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 105,
		.baseDefense 	= 115,
		.baseSpAttack 	= 54,
		.baseSpDefense 	= 86,
		.baseSpeed 		= 68,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_TOUGHCLAWS,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKPOCKET,
		.noFlip = TRUE,
	},

	[SPECIES_SKRELP] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 60,
		.baseDefense 	= 60,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 30,
		.type1 = TYPE_POISON,
		.type2 = TYPE_WATER,
		.catchRate = 225,
		.expYield = 64,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_POISONTOUCH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ADAPTABILITY,
		.noFlip = TRUE,
	},

	[SPECIES_DRAGALGE] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 75,
		.baseDefense 	= 90,
		.baseSpAttack 	= 97,
		.baseSpDefense 	= 123,
		.baseSpeed 		= 44,
		.type1 = TYPE_POISON,
		.type2 = TYPE_DRAGON,
		.catchRate = 55,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_POISONPOINT,
		.ability2 = ABILITY_POISONTOUCH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ADAPTABILITY,
		.noFlip = TRUE,
	},

	[SPECIES_CLAUNCHER] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 53,
		.baseDefense 	= 62,
		.baseSpAttack 	= 58,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 44,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 225,
		.expYield = 66,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_MEGALAUNCHER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CLAWITZER] =
	{
		.baseHP 		= 71,
		.baseAttack 	= 73,
		.baseDefense 	= 88,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 89,
		.baseSpeed 		= 59,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 55,
		.expYield = 100,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_MEGALAUNCHER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_HELIOPTILE] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 38,
		.baseDefense 	= 33,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 43,
		.baseSpeed 		= 70,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_NORMAL,
		.catchRate = 190,
		.expYield = 58,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_DRYSKIN,
		.ability2 = ABILITY_SANDVEIL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOLARPOWER,
		.noFlip = TRUE,
	},

	[SPECIES_HELIOLISK] =
	{
		.baseHP 		= 62,
		.baseAttack 	= 55,
		.baseDefense 	= 52,
		.baseSpAttack 	= 109,
		.baseSpDefense 	= 94,
		.baseSpeed 		= 109,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_NORMAL,
		.catchRate = 75,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_DRYSKIN,
		.ability2 = ABILITY_SANDVEIL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOLARPOWER,
		.noFlip = TRUE,
	},

	[SPECIES_TYRUNT] =
	{
		.baseHP 		= 58,
		.baseAttack 	= 89,
		.baseDefense 	= 77,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 48,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 72,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_STRONGJAW,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STURDY,
		.noFlip = TRUE,
	},

	[SPECIES_TYRANTRUM] =
	{
		.baseHP 		= 82,
		.baseAttack 	= 121,
		.baseDefense 	= 119,
		.baseSpAttack 	= 69,
		.baseSpDefense 	= 59,
		.baseSpeed 		= 71,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 182,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_STRONGJAW,
		.ability2 = ABILITY_ROCKHEAD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ROCKHEAD,
		.noFlip = TRUE,
	},

	[SPECIES_AMAURA] =
	{
		.baseHP 		= 77,
		.baseAttack 	= 59,
		.baseDefense 	= 50,
		.baseSpAttack 	= 67,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 46,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 72,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_REFRIGERATE,
		.ability2 = ABILITY_SNOWWARNING,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNOWWARNING,
		.noFlip = TRUE,
	},

	[SPECIES_AURORUS] =
	{
		.baseHP 		= 123,
		.baseAttack 	= 77,
		.baseDefense 	= 72,
		.baseSpAttack 	= 99,
		.baseSpDefense 	= 92,
		.baseSpeed 		= 58,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 104,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_REFRIGERATE,
		.ability2 = ABILITY_SNOWWARNING,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNOWWARNING,
		.noFlip = TRUE,
	},

	[SPECIES_SYLVEON] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 60,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 184,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 37,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_CUTECHARM,
		.ability2 = ABILITY_PIXILATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PIXILATE,
		.noFlip = TRUE,
	},

	[SPECIES_HAWLUCHA] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 92,
		.baseDefense 	= 75,
		.baseSpAttack 	= 74,
		.baseSpDefense 	= 63,
		.baseSpeed 		= 118,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FLYING,
		.catchRate = 100,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_KINGS_ROCK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_LIMBER,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOLDBREAKER,
		.noFlip = TRUE,
	},

	[SPECIES_DEDENNE] =
	{
		.baseHP 		= 67,
		.baseAttack 	= 58,
		.baseDefense 	= 57,
		.baseSpAttack 	= 81,
		.baseSpDefense 	= 67,
		.baseSpeed 		= 101,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 180,
		.expYield = 151,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_CHEEKPOUCH,
		.ability2 = ABILITY_PICKUP,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PLUS,
		.noFlip = TRUE,
	},

	[SPECIES_CARBINK] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 50,
		.baseDefense 	= 150,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 150,
		.baseSpeed 		= 50,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FAIRY,
		.catchRate = 60,
		.expYield = 100,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STURDY,
		.noFlip = TRUE,
	},

	[SPECIES_GOOMY] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 50,
		.baseDefense 	= 35,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 40,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHED_SHELL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SAPSIPPER,
		.ability2 = ABILITY_HYDRATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GOOEY,
		.noFlip = TRUE,
	},

	[SPECIES_SLIGGOO] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 75,
		.baseDefense 	= 53,
		.baseSpAttack 	= 83,
		.baseSpDefense 	= 113,
		.baseSpeed 		= 60,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 158,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SHED_SHELL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SAPSIPPER,
		.ability2 = ABILITY_HYDRATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GOOEY,
		.noFlip = TRUE,
	},

	[SPECIES_GOODRA] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 150,
		.baseSpeed 		= 80,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SAPSIPPER,
		.ability2 = ABILITY_HYDRATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GOOEY,
		.noFlip = TRUE,
	},

	[SPECIES_KLEFKI] =
	{
		.baseHP 		= 57,
		.baseAttack 	= 80,
		.baseDefense 	= 91,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 87,
		.baseSpeed 		= 75,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_FAIRY,
		.catchRate = 75,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MAGICIAN,
		.noFlip = TRUE,
	},

	[SPECIES_PHANTUMP] =
	{
		.baseHP 		= 43,
		.baseAttack 	= 70,
		.baseDefense 	= 48,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 38,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 120,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HARVEST,
		.noFlip = TRUE,
	},

	[SPECIES_TREVENANT] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 110,
		.baseDefense 	= 76,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 82,
		.baseSpeed 		= 56,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 60,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HARVEST,
		.noFlip = TRUE,
	},

	[SPECIES_PUMPKABOO] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 66,
		.baseDefense 	= 70,
		.baseSpAttack 	= 44,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 56,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 120,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_GOURGEIST] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 85,
		.baseDefense 	= 122,
		.baseSpAttack 	= 58,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 99,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 60,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_BERGMITE] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 69,
		.baseDefense 	= 85,
		.baseSpAttack 	= 32,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 28,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 190,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_OWNTEMPO,
		.ability2 = ABILITY_ICEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STURDY,
		.noFlip = TRUE,
	},

	[SPECIES_AVALUGG] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 117,
		.baseDefense 	= 184,
		.baseSpAttack 	= 44,
		.baseSpDefense 	= 46,
		.baseSpeed 		= 28,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 55,
		.expYield = 180,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_OWNTEMPO,
		.ability2 = ABILITY_ICEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STURDY,
		.noFlip = TRUE,
	},

	[SPECIES_NOIBAT] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 30,
		.baseDefense 	= 35,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 55,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_DRAGON,
		.catchRate = 190,
		.expYield = 49,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_FRISK,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_NOIVERN] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 70,
		.baseDefense 	= 80,
		.baseSpAttack 	= 97,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 123,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 187,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_FRISK,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_XERNEAS] =
	{
		.baseHP 		= 126,
		.baseAttack 	= 131,
		.baseDefense 	= 95,
		.baseSpAttack 	= 131,
		.baseSpDefense 	= 98,
		.baseSpeed 		= 99,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_FAIRYAURA,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_YVELTAL] =
	{
		.baseHP 		= 126,
		.baseAttack 	= 131,
		.baseDefense 	= 95,
		.baseSpAttack 	= 131,
		.baseSpDefense 	= 98,
		.baseSpeed 		= 99,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DARKAURA,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ZYGARDE] =
	{
		.baseHP 		= 108,
		.baseAttack 	= 100,
		.baseDefense 	= 121,
		.baseSpAttack 	= 81,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GROUND,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_AURABREAK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POWERCONSTRUCT,
		.noFlip = TRUE,
	},

	[SPECIES_DIANCIE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 100,
		.baseDefense 	= 150,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 150,
		.baseSpeed 		= 50,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_HOOPA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 110,
		.baseDefense 	= 60,
		.baseSpAttack 	= 150,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 70,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_GHOST,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MAGICIAN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_HOOPA_UNBOUND] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 160,
		.baseDefense 	= 60,
		.baseSpAttack 	= 170,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 80,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_DARK,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MAGICIAN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_VOLCANION] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 110,
		.baseDefense 	= 120,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 70,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_WATER,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 100,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_PYROAR_FEMALE] =
	{
		.baseHP 		= 86,
		.baseAttack 	= 68,
		.baseDefense 	= 72,
		.baseSpAttack 	= 109,
		.baseSpDefense 	= 66,
		.baseSpeed 		= 106,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_NORMAL,
		.catchRate = 65,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RIVALRY,
		.ability2 = ABILITY_UNNERVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MOXIE,
		.noFlip = TRUE,
	},

	[SPECIES_MEOWSTIC_FEMALE] =
	{
		.baseHP 		= 74,
		.baseAttack 	= 48,
		.baseDefense 	= 76,
		.baseSpAttack 	= 83,
		.baseSpDefense 	= 81,
		.baseSpeed 		= 104,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 75,
		.expYield = 163,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_COMPETITIVE,
		.noFlip = TRUE,
	},

	[SPECIES_AEGISLASH_BLADE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 150,
		.baseDefense 	= 50,
		.baseSpAttack 	= 150,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 60,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 234,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STANCECHANGE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ARCEUS_FAIRY] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 120,
		.baseDefense 	= 120,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 120,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MULTITYPE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ZYGARDE_CELL] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 50,
		.baseDefense 	= 50,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 50,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GROUND,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_AURABREAK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ZYGARDE_CORE] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 75,
		.baseDefense 	= 75,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 75,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GROUND,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_AURABREAK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ZYGARDE_10] =
	{
		.baseHP 		= 54,
		.baseAttack 	= 100,
		.baseDefense 	= 71,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 115,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GROUND,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_AURABREAK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POWERCONSTRUCT,
		.noFlip = TRUE,
	},

	[SPECIES_ZYGARDE_COMPLETE] =
	{
		.baseHP 		= 216,
		.baseAttack 	= 100,
		.baseDefense 	= 121,
		.baseSpAttack 	= 91,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 85,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GROUND,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_POWERCONSTRUCT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POWERCONSTRUCT,
		.noFlip = TRUE,
	},

	[SPECIES_ASHGRENINJA] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 145,
		.baseDefense 	= 67,
		.baseSpAttack 	= 153,
		.baseSpDefense 	= 71,
		.baseSpeed 		= 132,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 239,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_BATTLEBOND,
		.ability2 = ABILITY_BATTLEBOND,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FLABEBE_BLUE] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 38,
		.baseDefense 	= 39,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 79,
		.baseSpeed 		= 42,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLABEBE_ORANGE] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 38,
		.baseDefense 	= 39,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 79,
		.baseSpeed 		= 42,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLABEBE_YELLOW] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 38,
		.baseDefense 	= 39,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 79,
		.baseSpeed 		= 42,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLABEBE_WHITE] =
	{
		.baseHP 		= 44,
		.baseAttack 	= 38,
		.baseDefense 	= 39,
		.baseSpAttack 	= 61,
		.baseSpDefense 	= 79,
		.baseSpeed 		= 42,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 225,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLOETTE_BLUE] =
	{
		.baseHP 		= 54,
		.baseAttack 	= 45,
		.baseDefense 	= 47,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 98,
		.baseSpeed 		= 52,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 120,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLOETTE_ORANGE] =
	{
		.baseHP 		= 54,
		.baseAttack 	= 45,
		.baseDefense 	= 47,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 98,
		.baseSpeed 		= 52,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 120,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLOETTE_YELLOW] =
	{
		.baseHP 		= 54,
		.baseAttack 	= 45,
		.baseDefense 	= 47,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 98,
		.baseSpeed 		= 52,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 120,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLOETTE_WHITE] =
	{
		.baseHP 		= 54,
		.baseAttack 	= 45,
		.baseDefense 	= 47,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 98,
		.baseSpeed 		= 52,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 120,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLOETTE_ETERNAL] =
	{
		.baseHP 		= 74,
		.baseAttack 	= 65,
		.baseDefense 	= 67,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 128,
		.baseSpeed 		= 92,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 120,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLORGES_BLUE] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 65,
		.baseDefense 	= 68,
		.baseSpAttack 	= 112,
		.baseSpDefense 	= 154,
		.baseSpeed 		= 75,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 248,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLORGES_ORANGE] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 65,
		.baseDefense 	= 68,
		.baseSpAttack 	= 112,
		.baseSpDefense 	= 154,
		.baseSpeed 		= 75,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 248,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLORGES_YELLOW] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 65,
		.baseDefense 	= 68,
		.baseSpAttack 	= 112,
		.baseSpDefense 	= 154,
		.baseSpeed 		= 75,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 248,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_FLORGES_WHITE] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 65,
		.baseDefense 	= 68,
		.baseSpAttack 	= 112,
		.baseSpDefense 	= 154,
		.baseSpeed 		= 75,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 248,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_FLOWERVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_PUMPKABOO_XL] =
	{
		.baseHP 		= 59,
		.baseAttack 	= 66,
		.baseDefense 	= 70,
		.baseSpAttack 	= 44,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 41,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 120,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_MIRACLE_SEED,
		.item2 = ITEM_MIRACLE_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_PUMPKABOO_L] =
	{
		.baseHP 		= 54,
		.baseAttack 	= 66,
		.baseDefense 	= 70,
		.baseSpAttack 	= 44,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 46,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 120,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_PUMPKABOO_M] =
	{
		.baseHP 		= 49,
		.baseAttack 	= 66,
		.baseDefense 	= 70,
		.baseSpAttack 	= 44,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 51,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 120,
		.expYield = 67,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_GOURGEIST_XL] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 100,
		.baseDefense 	= 122,
		.baseSpAttack 	= 58,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 54,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 60,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_MIRACLE_SEED,
		.item2 = ITEM_MIRACLE_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_GOURGEIST_L] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 95,
		.baseDefense 	= 122,
		.baseSpAttack 	= 58,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 69,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 60,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_GOURGEIST_M] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 90,
		.baseDefense 	= 122,
		.baseSpAttack 	= 58,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 84,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 60,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INSOMNIA,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU_HEART] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU_DIAMOND] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU_STAR] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU_PHAROAH] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU_KABUKI] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU_LA_REINE] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU_MATRON] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU_DANDY] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_FURFROU_DEBUTANTE] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 60,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 102,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 160,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_FANCY] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VENUSAUR_MEGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 100,
		.baseDefense 	= 123,
		.baseSpAttack 	= 122,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 80,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_THICKFAT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CHARIZARD_MEGA_X] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 130,
		.baseDefense 	= 111,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_TOUGHCLAWS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CHARIZARD_MEGA_Y] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 104,
		.baseDefense 	= 78,
		.baseSpAttack 	= 159,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_DROUGHT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_BLASTOISE_MEGA] =
	{
		.baseHP 		= 79,
		.baseAttack 	= 103,
		.baseDefense 	= 120,
		.baseSpAttack 	= 135,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 78,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_MEGALAUNCHER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_BEEDRILL_MEGA] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 150,
		.baseDefense 	= 40,
		.baseSpAttack 	= 15,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 145,
		.type1 = TYPE_BUG,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 159,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_ADAPTABILITY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_PIDGEOT_MEGA] =
	{
		.baseHP 		= 83,
		.baseAttack 	= 80,
		.baseDefense 	= 80,
		.baseSpAttack 	= 135,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 121,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_NOGUARD,
		.ability2 = ABILITY_NOGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ALAKAZAM_MEGA] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 50,
		.baseDefense 	= 65,
		.baseSpAttack 	= 175,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 150,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 50,
		.expYield = 186,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_TWISTED_SPOON,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_TRACE,
		.ability2 = ABILITY_TRACE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SLOWBRO_MEGA] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 75,
		.baseDefense 	= 180,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 30,
		.type1 = TYPE_WATER,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 75,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_SHELLARMOR,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GENGAR_MEGA] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 65,
		.baseDefense 	= 80,
		.baseSpAttack 	= 170,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 130,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 190,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SHADOWTAG,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_KANGASKHAN_MEGA] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 125,
		.baseDefense 	= 100,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 175,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_PARENTALBOND,
		.ability2 = ABILITY_PARENTALBOND,
		.safariZoneFleeRate = 125,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_PINSIR_MEGA] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 155,
		.baseDefense 	= 120,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 105,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 200,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_AERILATE,
		.ability2 = ABILITY_AERILATE,
		.safariZoneFleeRate = 125,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GYARADOS_MEGA] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 155,
		.baseDefense 	= 109,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 81,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 214,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 5,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_MOLDBREAKER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_AERODACTYL_MEGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 135,
		.baseDefense 	= 85,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 150,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 202,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_TOUGHCLAWS,
		.ability2 = ABILITY_TOUGHCLAWS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MEWTWO_MEGA_X] =
	{
		.baseHP 		= 106,
		.baseAttack 	= 190,
		.baseDefense 	= 100,
		.baseSpAttack 	= 154,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 130,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_STEADFAST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MEWTWO_MEGA_Y] =
	{
		.baseHP 		= 106,
		.baseAttack 	= 150,
		.baseDefense 	= 70,
		.baseSpAttack 	= 194,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 140,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_INSOMNIA,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_AMPHAROS_MEGA] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 95,
		.baseDefense 	= 105,
		.baseSpAttack 	= 165,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 45,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 194,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_MOLDBREAKER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_STEELIX_MEGA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 125,
		.baseDefense 	= 230,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 30,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_GROUND,
		.catchRate = 25,
		.expYield = 196,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SANDFORCE,
		.ability2 = ABILITY_SANDFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SCIZOR_MEGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 150,
		.baseDefense 	= 140,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 75,
		.type1 = TYPE_BUG,
		.type2 = TYPE_STEEL,
		.catchRate = 25,
		.expYield = 200,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_TECHNICIAN,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_HERACROSS_MEGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 185,
		.baseDefense 	= 115,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 75,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 200,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SKILLLINK,
		.ability2 = ABILITY_SKILLLINK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_HOUNDOOM_MEGA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 90,
		.baseDefense 	= 90,
		.baseSpAttack 	= 140,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 115,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 204,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SOLARPOWER,
		.ability2 = ABILITY_SOLARPOWER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TYRANITAR_MEGA] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 164,
		.baseDefense 	= 150,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 71,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_SANDSTREAM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SCEPTILE_MEGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 110,
		.baseDefense 	= 75,
		.baseSpAttack 	= 145,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 145,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_BLAZIKEN_MEGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 160,
		.baseDefense 	= 80,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SPEEDBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SWAMPERT_MEGA] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 150,
		.baseDefense 	= 110,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GARDEVOIR_MEGA] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 85,
		.baseDefense 	= 65,
		.baseSpAttack 	= 165,
		.baseSpDefense 	= 135,
		.baseSpeed 		= 100,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PIXILATE,
		.ability2 = ABILITY_PIXILATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SABLEYE_MEGA] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 85,
		.baseDefense 	= 125,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 20,
		.type1 = TYPE_DARK,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 98,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_MAGICBOUNCE,
		.ability2 = ABILITY_MAGICBOUNCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MAWILE_MEGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 105,
		.baseDefense 	= 125,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 50,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 98,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HUGEPOWER,
		.ability2 = ABILITY_HUGEPOWER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_AGGRON_MEGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 140,
		.baseDefense 	= 230,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 50,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 205,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HARD_STONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 35,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_FILTER,
		.ability2 = ABILITY_FILTER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MEDICHAM_MEGA] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 85,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 90,
		.expYield = 153,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_HUGEPOWER, //ABILITY_PUREPOWER
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MANECTRIC_MEGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 75,
		.baseDefense 	= 80,
		.baseSpAttack 	= 135,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 135,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INTIMIDATE,
		.ability2 = ABILITY_INTIMIDATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SHARPEDO_MEGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 140,
		.baseDefense 	= 70,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 105,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DARK,
		.catchRate = 60,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_STRONGJAW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CAMERUPT_MEGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 120,
		.baseDefense 	= 100,
		.baseSpAttack 	= 145,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 20,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_GROUND,
		.catchRate = 150,
		.expYield = 175,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_RAWST_BERRY,
		.item2 = ITEM_RAWST_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SHEERFORCE,
		.ability2 = ABILITY_SHEERFORCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ALTARIA_MEGA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 110,
		.baseDefense 	= 110,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 80,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 188,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_PIXILATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_BANETTE_MEGA] =
	{
		.baseHP 		= 64,
		.baseAttack 	= 165,
		.baseDefense 	= 75,
		.baseSpAttack 	= 93,
		.baseSpDefense 	= 83,
		.baseSpeed 		= 75,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_PRANKSTER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ABSOL_MEGA] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 150,
		.baseDefense 	= 60,
		.baseSpAttack 	= 115,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 115,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 30,
		.expYield = 174,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 35,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_MAGICBOUNCE,
		.ability2 = ABILITY_MAGICBOUNCE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GLALIE_MEGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 120,
		.baseDefense 	= 80,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 100,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 75,
		.expYield = 187,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NEVER_MELT_ICE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_REFRIGERATE,
		.ability2 = ABILITY_REFRIGERATE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SALAMENCE_MEGA] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 145,
		.baseDefense 	= 130,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 120,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_AERILATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_METAGROSS_MEGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 145,
		.baseDefense 	= 150,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 110,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_METAL_COAT,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 40,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_TOUGHCLAWS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LATIAS_MEGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 100,
		.baseDefense 	= 120,
		.baseSpAttack 	= 140,
		.baseSpDefense 	= 150,
		.baseSpeed 		= 110,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 211,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LATIOS_MEGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 130,
		.baseDefense 	= 100,
		.baseSpAttack 	= 160,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 110,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 211,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 120,
		.friendship = 90,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GROUDON_PRIMAL] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 180,
		.baseDefense 	= 160,
		.baseSpAttack 	= 150,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 90,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_FIRE,
		.catchRate = 5,
		.expYield = 230,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DESOLATELAND,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_KYOGRE_PRIMAL] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 150,
		.baseDefense 	= 90,
		.baseSpAttack 	= 180,
		.baseSpDefense 	= 160,
		.baseSpeed 		= 90,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 5,
		.expYield = 230,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRIMORDIALSEA,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_RAYQUAZA_MEGA] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 180,
		.baseDefense 	= 100,
		.baseSpAttack 	= 180,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 115,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 230,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DELTASTREAM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LOPUNNY_MEGA] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 136,
		.baseDefense 	= 94,
		.baseSpAttack 	= 54,
		.baseSpDefense 	= 96,
		.baseSpeed 		= 135,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FIGHTING,
		.catchRate = 60,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SCRAPPY,
		.ability2 = ABILITY_SCRAPPY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GARCHOMP_MEGA] =
	{
		.baseHP 		= 108,
		.baseAttack 	= 170,
		.baseDefense 	= 115,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 92,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GROUND,
		.catchRate = 45,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_SANDFORCE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LUCARIO_MEGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 145,
		.baseDefense 	= 88,
		.baseSpAttack 	= 140,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 112,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 204,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_ADAPTABILITY,
		.ability2 = ABILITY_ADAPTABILITY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ABOMASNOW_MEGA] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 132,
		.baseDefense 	= 105,
		.baseSpAttack 	= 132,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_ICE,
		.catchRate = 60,
		.expYield = 214,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_SNOWWARNING,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GALLADE_MEGA] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 165,
		.baseDefense 	= 95,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 110,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 233,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_AUDINO_MEGA] =
	{
		.baseHP 		= 103,
		.baseAttack 	= 60,
		.baseDefense 	= 126,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 126,
		.baseSpeed 		= 50,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FAIRY,
		.catchRate = 255,
		.expYield = 245,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HEALER,
		.ability2 = ABILITY_HEALER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_DIANCIE_MEGA] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 160,
		.baseDefense 	= 110,
		.baseSpAttack 	= 160,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 110,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MAGICBOUNCE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_ARCHIPELAGO] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_CONTINENTAL] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_ELEGANT] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_GARDEN] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_HIGH_PLAINS] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_ICY_SNOW] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_JUNGLE] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_MARINE] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_MODERN] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_MONSOON] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_OCEAN] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_POKEBALL] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_POLAR] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_RIVER] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_SANDSTORM] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_SAVANNA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_SUN] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_VIVILLON_TUNDRA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 52,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 89,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 185,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRIENDGUARD,
		.noFlip = TRUE,
	},

	[SPECIES_ROWLET] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 55,
		.baseDefense 	= 55,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 42,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 64,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LONGREACH,
		.noFlip = TRUE,
	},

	[SPECIES_DARTRIX] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 75,
		.baseDefense 	= 75,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 52,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 144,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LONGREACH,
		.noFlip = TRUE,
	},

	[SPECIES_DECIDUEYE] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 107,
		.baseDefense 	= 75,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 70,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LONGREACH,
		.noFlip = TRUE,
	},

	[SPECIES_LITTEN] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 65,
		.baseDefense 	= 40,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 70,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 64,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INTIMIDATE,
		.noFlip = TRUE,
	},

	[SPECIES_TORRACAT] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 85,
		.baseDefense 	= 50,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INTIMIDATE,
		.noFlip = TRUE,
	},

	[SPECIES_INCINEROAR] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 115,
		.baseDefense 	= 90,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 60,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_DARK,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INTIMIDATE,
		.noFlip = TRUE,
	},

	[SPECIES_POPPLIO] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 54,
		.baseDefense 	= 54,
		.baseSpAttack 	= 66,
		.baseSpDefense 	= 56,
		.baseSpeed 		= 40,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 64,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIQUIDVOICE,
		.noFlip = TRUE,
	},

	[SPECIES_BRIONNE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 69,
		.baseDefense 	= 69,
		.baseSpAttack 	= 91,
		.baseSpDefense 	= 81,
		.baseSpeed 		= 50,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIQUIDVOICE,
		.noFlip = TRUE,
	},

	[SPECIES_PRIMARINA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 74,
		.baseDefense 	= 74,
		.baseSpAttack 	= 126,
		.baseSpDefense 	= 116,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIQUIDVOICE,
		.noFlip = TRUE,
	},

	[SPECIES_PIKIPEK] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 75,
		.baseDefense 	= 30,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 65,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 54,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ORAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_SKILLLINK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKUP,
		.noFlip = TRUE,
	},

	[SPECIES_TRUMBEAK] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 85,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 75,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 120,
		.expYield = 126,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SITRUS_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_SKILLLINK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKUP,
		.noFlip = TRUE,
	},

	[SPECIES_TOUCANNON] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 120,
		.baseDefense 	= 75,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FLYING,
		.catchRate = 90,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_RAWST_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_SKILLLINK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_YUNGOOS] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 70,
		.baseDefense 	= 30,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 45,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 57,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PECHA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STAKEOUT,
		.ability2 = ABILITY_STRONGJAW,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ADAPTABILITY,
		.noFlip = TRUE,
	},

	[SPECIES_GUMSHOOS] =
	{
		.baseHP 		= 88,
		.baseAttack 	= 110,
		.baseDefense 	= 60,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 45,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 127,
		.expYield = 116,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PECHA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STAKEOUT,
		.ability2 = ABILITY_STRONGJAW,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ADAPTABILITY,
		.noFlip = TRUE,
	},

	[SPECIES_GRUBBIN] =
	{
		.baseHP 		= 47,
		.baseAttack 	= 62,
		.baseDefense 	= 45,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 46,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 255,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CHARJABUG] =
	{
		.baseHP 		= 57,
		.baseAttack 	= 82,
		.baseDefense 	= 95,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 36,
		.type1 = TYPE_BUG,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 120,
		.expYield = 145,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CELL_BATTERY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_BATTERY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_VIKAVOLT] =
	{
		.baseHP 		= 77,
		.baseAttack 	= 70,
		.baseDefense 	= 90,
		.baseSpAttack 	= 145,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 43,
		.type1 = TYPE_BUG,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 186,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CRABRAWLER] =
	{
		.baseHP 		= 47,
		.baseAttack 	= 82,
		.baseDefense 	= 57,
		.baseSpAttack 	= 42,
		.baseSpDefense 	= 47,
		.baseSpeed 		= 63,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 225,
		.expYield = 114,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ASPEAR_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_IRONFIST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANGERPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_CRABOMINABLE] =
	{
		.baseHP 		= 97,
		.baseAttack 	= 132,
		.baseDefense 	= 77,
		.baseSpAttack 	= 62,
		.baseSpDefense 	= 67,
		.baseSpeed 		= 43,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_ICE,
		.catchRate = 60,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHERI_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_IRONFIST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANGERPOINT,
		.noFlip = TRUE,
	},

	[SPECIES_ORICORIO] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 70,
		.baseDefense 	= 70,
		.baseSpAttack 	= 98,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 93,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HONEY,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_DANCER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CUTIEFLY] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 40,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 84,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FAIRY,
		.catchRate = 190,
		.expYield = 75,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HONEY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HONEYGATHER,
		.ability2 = ABILITY_SHIELDDUST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWEETVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_RIBOMBEE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 55,
		.baseDefense 	= 60,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 124,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FAIRY,
		.catchRate = 75,
		.expYield = 138,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HONEY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HONEYGATHER,
		.ability2 = ABILITY_SHIELDDUST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWEETVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_ROCKRUFF] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 65,
		.baseDefense 	= 40,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 60,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 190,
		.expYield = 55,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STEADFAST,
		.ability2 = ABILITY_VITALSPIRIT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_LYCANROC] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 115,
		.baseDefense 	= 65,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 112,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 90,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STEADFAST,
		.ability2 = ABILITY_SANDRUSH,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_WISHIWASHI] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 20,
		.baseDefense 	= 20,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 25,
		.baseSpeed 		= 40,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 88,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SCHOOLING,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MAREANIE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 53,
		.baseDefense 	= 62,
		.baseSpAttack 	= 43,
		.baseSpDefense 	= 52,
		.baseSpeed 		= 45,
		.type1 = TYPE_POISON,
		.type2 = TYPE_WATER,
		.catchRate = 190,
		.expYield = 97,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_MERCILESS,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIMBER,
		.noFlip = TRUE,
	},

	[SPECIES_TOXAPEX] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 63,
		.baseDefense 	= 152,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 142,
		.baseSpeed 		= 35,
		.type1 = TYPE_POISON,
		.type2 = TYPE_WATER,
		.catchRate = 75,
		.expYield = 203,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_POISON_BARB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_MERCILESS,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIMBER,
		.noFlip = TRUE,
	},

	[SPECIES_MUDBRAY] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 45,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 190,
		.expYield = 108,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LIGHT_CLAY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_OWNTEMPO,
		.ability2 = ABILITY_STAMINA,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_MUDSDALE] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 125,
		.baseDefense 	= 100,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 35,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 60,
		.expYield = 196,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LIGHT_CLAY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_OWNTEMPO,
		.ability2 = ABILITY_STAMINA,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},

	[SPECIES_DEWPIDER] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 40,
		.baseDefense 	= 52,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 72,
		.baseSpeed 		= 27,
		.type1 = TYPE_WATER,
		.type2 = TYPE_BUG,
		.catchRate = 200,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MYSTIC_WATER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_WATERBUBBLE,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERABSORB,
		.noFlip = TRUE,
	},

	[SPECIES_ARAQUANID] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 70,
		.baseDefense 	= 92,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 132,
		.baseSpeed 		= 42,
		.type1 = TYPE_WATER,
		.type2 = TYPE_BUG,
		.catchRate = 100,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MYSTIC_WATER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_WATERBUBBLE,
		.ability2 = ABILITY_WATERABSORB,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WATERABSORB,
		.noFlip = TRUE,
	},

	[SPECIES_FOMANTIS] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 55,
		.baseDefense 	= 35,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 35,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 78,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MIRACLE_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_LEAFGUARD,
		.ability2 = ABILITY_CONTRARY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CONTRARY,
		.noFlip = TRUE,
	},

	[SPECIES_LURANTIS] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 105,
		.baseDefense 	= 90,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 45,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 160,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MIRACLE_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_LEAFGUARD,
		.ability2 = ABILITY_CONTRARY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CONTRARY,
		.noFlip = TRUE,
	},

	[SPECIES_MORELULL] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 35,
		.baseDefense 	= 55,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 15,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FAIRY,
		.catchRate = 190,
		.expYield = 70,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_TINY_MUSHROOM,
		.item2 = ITEM_BIG_MUSHROOM,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_ILLUMINATE,
		.ability2 = ABILITY_EFFECTSPORE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RAINDISH,
		.noFlip = TRUE,
	},

	[SPECIES_SHIINOTIC] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 45,
		.baseDefense 	= 80,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FAIRY,
		.catchRate = 75,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_BIG_MUSHROOM,
		.item2 = ITEM_TINY_MUSHROOM,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_ILLUMINATE,
		.ability2 = ABILITY_EFFECTSPORE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RAINDISH,
		.noFlip = TRUE,
	},

	[SPECIES_SALANDIT] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 44,
		.baseDefense 	= 40,
		.baseSpAttack 	= 71,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 77,
		.type1 = TYPE_POISON,
		.type2 = TYPE_FIRE,
		.catchRate = 120,
		.expYield = 73,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SMOKE_BALL,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_CORROSION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_SALAZZLE] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 64,
		.baseDefense 	= 60,
		.baseSpAttack 	= 111,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 117,
		.type1 = TYPE_POISON,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 171,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SMOKE_BALL,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_CORROSION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_OBLIVIOUS,
		.noFlip = TRUE,
	},

	[SPECIES_STUFFUL] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 75,
		.baseDefense 	= 50,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 50,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FIGHTING,
		.catchRate = 140,
		.expYield = 114,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FLUFFY,
		.ability2 = ABILITY_KLUTZ,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CUTECHARM,
		.noFlip = TRUE,
	},

	[SPECIES_BEWEAR] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 125,
		.baseDefense 	= 80,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_FIGHTING,
		.catchRate = 70,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FLUFFY,
		.ability2 = ABILITY_KLUTZ,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},

	[SPECIES_BOUNSWEET] =
	{
		.baseHP 		= 42,
		.baseAttack 	= 30,
		.baseDefense 	= 38,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 38,
		.baseSpeed 		= 32,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 235,
		.expYield = 52,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_GRASSY_SEED,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_LEAFGUARD,
		.ability2 = ABILITY_OBLIVIOUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWEETVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_STEENEE] =
	{
		.baseHP 		= 52,
		.baseAttack 	= 40,
		.baseDefense 	= 48,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 48,
		.baseSpeed 		= 62,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 120,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_GRASSY_SEED,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_LEAFGUARD,
		.ability2 = ABILITY_OBLIVIOUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWEETVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_TSAREENA] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 120,
		.baseDefense 	= 98,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 98,
		.baseSpeed 		= 72,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 194,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_GRASSY_SEED,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_LEAFGUARD,
		.ability2 = ABILITY_QUEENLYMAJESTY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWEETVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_COMFEY] =
	{
		.baseHP 		= 51,
		.baseAttack 	= 52,
		.baseDefense 	= 90,
		.baseSpAttack 	= 82,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 100,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 60,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_MISTY_SEED,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_NATURALCURE,
		.ability2 = ABILITY_TRIAGE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLOWERVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_ORANGURU] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 60,
		.baseDefense 	= 80,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 60,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 200,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_TELEPATHY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SYMBIOSIS,
		.noFlip = TRUE,
	},

	[SPECIES_PASSIMIAN] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 120,
		.baseDefense 	= 90,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 80,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 200,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RECEIVER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},

	[SPECIES_WIMPOD] =
	{
		.baseHP 		= 25,
		.baseAttack 	= 35,
		.baseDefense 	= 40,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 80,
		.type1 = TYPE_BUG,
		.type2 = TYPE_WATER,
		.catchRate = 90,
		.expYield = 53,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_EMERGENCYEXIT, //ABILITY_WIMP_OUT
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GOLISOPOD] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 125,
		.baseDefense 	= 140,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 40,
		.type1 = TYPE_BUG,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 212,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_EMERGENCYEXIT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SANDYGAST] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 55,
		.baseDefense 	= 80,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 15,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GROUND,
		.catchRate = 140,
		.expYield = 73,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WATERCOMPACTION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_PALOSSAND] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 75,
		.baseDefense 	= 110,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 35,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GROUND,
		.catchRate = 60,
		.expYield = 171,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WATERCOMPACTION,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},

	[SPECIES_PYUKUMUKU] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 60,
		.baseDefense 	= 130,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 5,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 107,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_INNARDSOUT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNAWARE,
		.noFlip = TRUE,
	},

	[SPECIES_TYPE_NULL] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 59,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 3,
		.expYield = 107,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BATTLEARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MINIOR_SHIELD] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 60,
		.baseDefense 	= 100,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 60,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHIELDSDOWN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_KOMALA] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 115,
		.baseDefense 	= 65,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 65,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_COMATOSE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TURTONATOR] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 78,
		.baseDefense 	= 135,
		.baseSpAttack 	= 91,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 36,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_DRAGON,
		.catchRate = 70,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHARCOAL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SHELLARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_TOGEDEMARU] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 98,
		.baseDefense 	= 63,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 73,
		.baseSpeed 		= 96,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_STEEL,
		.catchRate = 180,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ELECTRIC_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_IRONBARBS,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STURDY,
		.noFlip = TRUE,
	},

	[SPECIES_MIMIKYU] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 90,
		.baseDefense 	= 80,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 96,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHESTO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_DISGUISE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_BRUXISH] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 105,
		.baseDefense 	= 70,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 92,
		.type1 = TYPE_WATER,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 80,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_RAZOR_FANG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_DAZZLING,
		.ability2 = ABILITY_STRONGJAW,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_WONDERSKIN,
		.noFlip = TRUE,
	},

	[SPECIES_DRAMPA] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 60,
		.baseDefense 	= 85,
		.baseSpAttack 	= 135,
		.baseSpDefense 	= 91,
		.baseSpeed 		= 36,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_DRAGON,
		.catchRate = 70,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PERSIM_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_BERSERK,
		.ability2 = ABILITY_SAPSIPPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CLOUDNINE,
		.noFlip = TRUE,
	},

	[SPECIES_DHELMISE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 131,
		.baseDefense 	= 100,
		.baseSpAttack 	= 86,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 40,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 207,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STEELWORKER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_JANGMO_O] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 55,
		.baseDefense 	= 65,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 45,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 89,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_RAZOR_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_BULLETPROOF,
		.ability2 = ABILITY_OVERCOAT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOUNDPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_HAKAMO_O] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 75,
		.baseDefense 	= 90,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 65,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_RAZOR_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_BULLETPROOF,
		.ability2 = ABILITY_OVERCOAT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOUNDPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_KOMMO_O] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 110,
		.baseDefense 	= 125,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 85,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 218,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_RAZOR_CLAW,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_DRAGON,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_BULLETPROOF,
		.ability2 = ABILITY_OVERCOAT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOUNDPROOF,
		.noFlip = TRUE,
	},

	[SPECIES_TAPU_KOKO] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 115,
		.baseDefense 	= 85,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 130,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_ELECTRICSURGE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_TAPU_LELE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 85,
		.baseDefense 	= 75,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 95,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PSYCHICSURGE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_TAPU_BULU] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 130,
		.baseDefense 	= 115,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 75,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_GRASSYSURGE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_TAPU_FINI] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 75,
		.baseDefense 	= 115,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 85,
		.type1 = TYPE_WATER,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MISTYSURGE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},

	[SPECIES_COSMOG] =
	{
		.baseHP 		= 43,
		.baseAttack 	= 29,
		.baseDefense 	= 31,
		.baseSpAttack 	= 29,
		.baseSpDefense 	= 31,
		.baseSpeed 		= 37,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 20,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_UNAWARE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_COSMOEM] =
	{
		.baseHP 		= 43,
		.baseAttack 	= 29,
		.baseDefense 	= 131,
		.baseSpAttack 	= 29,
		.baseSpDefense 	= 131,
		.baseSpeed 		= 37,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 140,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_STURDY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SOLGALEO] =
	{
		.baseHP 		= 137,
		.baseAttack 	= 137,
		.baseDefense 	= 107,
		.baseSpAttack 	= 113,
		.baseSpDefense 	= 89,
		.baseSpeed 		= 97,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_CLEARBODY, //ABILITY_FULLMETALBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LUNALA] =
	{
		.baseHP 		= 137,
		.baseAttack 	= 113,
		.baseDefense 	= 89,
		.baseSpAttack 	= 137,
		.baseSpDefense 	= 107,
		.baseSpeed 		= 97,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SHADOWSHIELD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_NIHILEGO] =
	{
		.baseHP 		= 109,
		.baseAttack 	= 53,
		.baseDefense 	= 47,
		.baseSpAttack 	= 127,
		.baseSpDefense 	= 131,
		.baseSpeed 		= 103,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_BUZZWOLE] =
	{
		.baseHP 		= 107,
		.baseAttack 	= 139,
		.baseDefense 	= 139,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 53,
		.baseSpeed 		= 79,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FIGHTING,
		.catchRate = 25,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_PHEROMOSA] =
	{
		.baseHP 		= 71,
		.baseAttack 	= 137,
		.baseDefense 	= 37,
		.baseSpAttack 	= 137,
		.baseSpDefense 	= 37,
		.baseSpeed 		= 151,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FIGHTING,
		.catchRate = 255,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_XURKITREE] =
	{
		.baseHP 		= 83,
		.baseAttack 	= 89,
		.baseDefense 	= 71,
		.baseSpAttack 	= 173,
		.baseSpDefense 	= 71,
		.baseSpeed 		= 83,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 30,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_CELESTEELA] =
	{
		.baseHP 		= 97,
		.baseAttack 	= 101,
		.baseDefense 	= 103,
		.baseSpAttack 	= 107,
		.baseSpDefense 	= 101,
		.baseSpeed 		= 61,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_FLYING,
		.catchRate = 25,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_KARTANA] =
	{
		.baseHP 		= 59,
		.baseAttack 	= 181,
		.baseDefense 	= 131,
		.baseSpAttack 	= 59,
		.baseSpDefense 	= 31,
		.baseSpeed 		= 109,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_STEEL,
		.catchRate = 255,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_GUZZLORD] =
	{
		.baseHP 		= 223,
		.baseAttack 	= 101,
		.baseDefense 	= 53,
		.baseSpAttack 	= 97,
		.baseSpDefense 	= 53,
		.baseSpeed 		= 43,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DRAGON,
		.catchRate = 15,
		.expYield = 210,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_NECROZMA] =
	{
		.baseHP 		= 97,
		.baseAttack 	= 107,
		.baseDefense 	= 101,
		.baseSpAttack 	= 127,
		.baseSpDefense 	= 89,
		.baseSpeed 		= 79,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRISMARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MAGEARNA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 95,
		.baseDefense 	= 115,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 65,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SOULHEART,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MARSHADOW] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 125,
		.baseDefense 	= 80,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 125,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_GHOST,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_TECHNICIAN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_RATTATA_A] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 56,
		.baseDefense 	= 35,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 72,
		.type1 = TYPE_DARK,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 57,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PECHA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_HUSTLE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_THICKFAT,
		.noFlip = TRUE,
	},

	[SPECIES_RATICATE_A] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 71,
		.baseDefense 	= 70,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 77,
		.type1 = TYPE_DARK,
		.type2 = TYPE_NORMAL,
		.catchRate = 127,
		.expYield = 116,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PECHA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_HUSTLE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_THICKFAT,
		.noFlip = TRUE,
	},

	[SPECIES_RAICHU_A] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 85,
		.baseDefense 	= 50,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 110,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 75,
		.expYield = 122,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_SURGESURFER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SANDSHREW_A] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 75,
		.baseDefense 	= 90,
		.baseSpAttack 	= 10,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 40,
		.type1 = TYPE_ICE,
		.type2 = TYPE_STEEL,
		.catchRate = 255,
		.expYield = 93,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SNOWCLOAK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SLUSHRUSH,
		.noFlip = TRUE,
	},

	[SPECIES_SANDSLASH_A] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 100,
		.baseDefense 	= 120,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 65,
		.type1 = TYPE_ICE,
		.type2 = TYPE_STEEL,
		.catchRate = 90,
		.expYield = 163,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SNOWCLOAK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SLUSHRUSH,
		.noFlip = TRUE,
	},

	[SPECIES_VULPIX_A] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 41,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 65,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 190,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SNOWCLOAK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNOWWARNING,
		.noFlip = TRUE,
	},

	[SPECIES_NINETALES_A] =
	{
		.baseHP 		= 73,
		.baseAttack 	= 67,
		.baseDefense 	= 75,
		.baseSpAttack 	= 81,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 109,
		.type1 = TYPE_ICE,
		.type2 = TYPE_FAIRY,
		.catchRate = 75,
		.expYield = 178,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SNOWCLOAK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNOWWARNING,
		.noFlip = TRUE,
	},

	[SPECIES_DIGLETT_A] =
	{
		.baseHP 		= 10,
		.baseAttack 	= 55,
		.baseDefense 	= 30,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 90,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_STEEL,
		.catchRate = 255,
		.expYield = 81,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SOFT_SAND,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_TANGLINGHAIR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_DUGTRIO_A] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 110,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_STEEL,
		.catchRate = 50,
		.expYield = 153,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SOFT_SAND,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_SANDVEIL,
		.ability2 = ABILITY_TANGLINGHAIR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDFORCE,
		.noFlip = TRUE,
	},

	[SPECIES_MEOWTH_A] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 35,
		.baseDefense 	= 35,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 90,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 255,
		.expYield = 69,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_QUICK_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_PERSIAN_A] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 60,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 115,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 90,
		.expYield = 148,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_QUICK_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FURCOAT,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},

	[SPECIES_GEODUDE_A] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 80,
		.baseDefense 	= 100,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 20,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 255,
		.expYield = 86,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_MAGNETPULL,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GALVANIZE,
		.noFlip = TRUE,
	},

	[SPECIES_GRAVELER_A] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 95,
		.baseDefense 	= 115,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 35,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 120,
		.expYield = 134,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_MAGNETPULL,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GALVANIZE,
		.noFlip = TRUE,
	},

	[SPECIES_GOLEM_A] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 120,
		.baseDefense 	= 130,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 45,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_MAGNETPULL,
		.ability2 = ABILITY_STURDY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GALVANIZE,
		.noFlip = TRUE,
	},

	[SPECIES_GRIMER_A] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 80,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 25,
		.type1 = TYPE_POISON,
		.type2 = TYPE_DARK,
		.catchRate = 190,
		.expYield = 90,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_POISONTOUCH,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POWEROFALCHEMY,
		.noFlip = TRUE,
	},

	[SPECIES_MUK_A] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 105,
		.baseDefense 	= 75,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 50,
		.type1 = TYPE_POISON,
		.type2 = TYPE_DARK,
		.catchRate = 75,
		.expYield = 157,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_POISONTOUCH,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_POWEROFALCHEMY,
		.noFlip = TRUE,
	},

	[SPECIES_EXEGGCUTE_A] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 40,
		.baseDefense 	= 80,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 40,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 90,
		.expYield = 98,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_CHLOROPHYLL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 75,
		.hiddenAbility = ABILITY_HARVEST,
		.noFlip = TRUE,
	},

	[SPECIES_EXEGGUTOR_A] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 105,
		.baseDefense 	= 85,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 45,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 212,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_FRISK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HARVEST,
		.noFlip = TRUE,
	},

	[SPECIES_CUBONE_A] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 50,
		.baseDefense 	= 95,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 35,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 190,
		.expYield = 87,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_THICK_CLUB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_ROCKHEAD,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BATTLEARMOR,
		.noFlip = TRUE,
	},

	[SPECIES_MAROWAK_A] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 80,
		.baseDefense 	= 110,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 45,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_GHOST,
		.catchRate = 75,
		.expYield = 124,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_THICK_CLUB,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_CURSEDBODY,
		.ability2 = ABILITY_LIGHTNINGROD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ROCKHEAD,
		.noFlip = TRUE,
	},

	[SPECIES_DEOXYS_ATTACK] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 180,
		.baseDefense 	= 20,
		.baseSpAttack 	= 180,
		.baseSpDefense 	= 20,
		.baseSpeed 		= 150,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_DEOXYS_DEFENSE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 70,
		.baseDefense 	= 160,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 160,
		.baseSpeed 		= 90,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_DEOXYS_SPEED] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 95,
		.baseDefense 	= 90,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 180,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ORICORIO_Y] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 70,
		.baseDefense 	= 70,
		.baseSpAttack 	= 98,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 93,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HONEY,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_DANCER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ORICORIO_P] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 70,
		.baseDefense 	= 70,
		.baseSpAttack 	= 98,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 93,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HONEY,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_DANCER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ORICORIO_S] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 70,
		.baseDefense 	= 70,
		.baseSpAttack 	= 98,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 93,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_HONEY,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_DANCER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LYCANROC_N] =
	{
		.baseHP 		= 85,
		.baseAttack 	= 115,
		.baseDefense 	= 75,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 82,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 90,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_NOGUARD,
		.ability2 = ABILITY_VITALSPIRIT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_KEENEYE,
		.noFlip = TRUE,
	},

	[SPECIES_WISHIWASHI_S] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 140,
		.baseDefense 	= 130,
		.baseSpAttack 	= 140,
		.baseSpDefense 	= 135,
		.baseSpeed 		= 30,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 88,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SCHOOLING,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_FIGHT] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_FLYING] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_POISON] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_GROUND] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_ROCK] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_BUG] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_GHOST] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_STEEL] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_FIRE] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_WATER] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_GRASS] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_ELECTRIC] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_PSYCHIC] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_ICE] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_DRAGON] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_DARK] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_SILVALLY_FAIRY] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 114,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RKS_SYSTEM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MINIOR_RED] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 120,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHIELDSDOWN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MINIOR_BLUE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 120,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHIELDSDOWN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MINIOR_ORANGE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 120,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHIELDSDOWN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MINIOR_YELLOW] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 120,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHIELDSDOWN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MINIOR_INDIGO] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 120,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHIELDSDOWN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MINIOR_GREEN] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 120,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHIELDSDOWN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MINIOR_VIOLET] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 100,
		.baseDefense 	= 60,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 120,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FLYING,
		.catchRate = 30,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_STAR_PIECE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHIELDSDOWN,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MIMIKYU_BUSTED] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 90,
		.baseDefense 	= 80,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 96,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_CHESTO_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_DISGUISE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_MAGEARNA_P] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 95,
		.baseDefense 	= 115,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 65,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_FAIRY,
		.catchRate = 3,
		.expYield = 120,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SOULHEART,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_POIPOLE] =
	{
		.baseHP 		= 67,
		.baseAttack 	= 73,
		.baseDefense 	= 67,
		.baseSpAttack 	= 73,
		.baseSpDefense 	= 67,
		.baseSpeed 		= 73,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 154,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_NAGANADEL] =
	{
		.baseHP 		= 73,
		.baseAttack 	= 73,
		.baseDefense 	= 73,
		.baseSpAttack 	= 127,
		.baseSpDefense 	= 73,
		.baseSpeed 		= 121,
		.type1 = TYPE_POISON,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_STAKATAKA] =
	{
		.baseHP 		= 61,
		.baseAttack 	= 131,
		.baseDefense 	= 211,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 101,
		.baseSpeed 		= 13,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_STEEL,
		.catchRate = 30,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_BLACEPHALON] =
	{
		.baseHP 		= 53,
		.baseAttack 	= 127,
		.baseDefense 	= 53,
		.baseSpAttack 	= 151,
		.baseSpDefense 	= 79,
		.baseSpeed 		= 107,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_GHOST,
		.catchRate = 30,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BEASTBOOST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_ZERAORA] =
	{
		.baseHP 		= 88,
		.baseAttack 	= 112,
		.baseDefense 	= 75,
		.baseSpAttack 	= 102,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 143,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_VOLTABSORB,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_NECROZMA_DUSK_MANE] =
	{
		.baseHP 		= 97,
		.baseAttack 	= 157,
		.baseDefense 	= 127,
		.baseSpAttack 	= 113,
		.baseSpDefense 	= 109,
		.baseSpeed 		= 77,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRISMARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_NECROZMA_DAWN_WINGS] =
	{
		.baseHP 		= 97,
		.baseAttack 	= 113,
		.baseDefense 	= 109,
		.baseSpAttack 	= 157,
		.baseSpDefense 	= 127,
		.baseSpeed 		= 77,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_GHOST,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRISMARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_NECROZMA_ULTRA] =
	{
		.baseHP 		= 97,
		.baseAttack 	= 167,
		.baseDefense 	= 97,
		.baseSpAttack 	= 167,
		.baseSpDefense 	= 97,
		.baseSpeed 		= 129,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_DRAGON,
		.catchRate = 3,
		.expYield = 220,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_NEUROFORCE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},

	[SPECIES_LYCANROC_DUSK] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 117,
		.baseDefense 	= 65,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 110,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 90,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TOUGHCLAWS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_MELTAN] =
	{
		.baseHP 		= 46,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 34,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 154,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_MAGNETPULL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_MELMETAL] =
	{
		.baseHP 		= 135,
		.baseAttack 	= 143,
		.baseDefense 	= 143,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 34,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_IRONFIST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_SURFING] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_FLYING] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_COSPLAY] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_LIBRE] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_POP_STAR] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_ROCK_STAR] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_BELLE] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_PHD] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_CAP_ORIGINAL] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_CAP_HOENN] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_CAP_SINNOH] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_CAP_UNOVA] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_CAP_KALOS] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_CAP_ALOLA] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_CAP_PARTNER] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_PICHU_SPIKY] =
	{
		.baseHP 		= 20,
		.baseAttack 	= 40,
		.baseDefense 	= 15,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 60,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 42,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ORAN_BERRY,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},

	[SPECIES_XERNEAS_NATURAL] =
	{
		.baseHP 		= 126,
		.baseAttack 	= 131,
		.baseDefense 	= 95,
		.baseSpAttack 	= 131,
		.baseSpDefense 	= 98,
		.baseSpeed 		= 99,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_FAIRYAURA,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_GROOKEY] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 65,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_GRASSYSURGE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GRASSYSURGE,
		.noFlip = TRUE,
	},
	
	[SPECIES_THWACKEY] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 85,
		.baseDefense 	= 70,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 80,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 147,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_GRASSYSURGE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GRASSYSURGE,
		.noFlip = TRUE,
	},
	
	[SPECIES_RILLABOOM] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 125,
		.baseDefense 	= 90,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 85,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_GRASSYSURGE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GRASSYSURGE,
		.noFlip = TRUE,
	},
	
	[SPECIES_SCORBUNNY] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 71,
		.baseDefense 	= 40,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 69,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_PROTEAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PROTEAN,
		.noFlip = TRUE,
	},
	
	[SPECIES_RABOOT] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 86,
		.baseDefense 	= 60,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 94,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 147,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_PROTEAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PROTEAN,
		.noFlip = TRUE,
	},
	
	[SPECIES_CINDERACE] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 116,
		.baseDefense 	= 75,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 119,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_PROTEAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PROTEAN,
		.noFlip = TRUE,
	},
	
	[SPECIES_SOBBLE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 40,
		.baseDefense 	= 40,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 70,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNIPER,
		.noFlip = TRUE,
	},
	
	[SPECIES_DRIZZILE] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 55,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 90,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 147,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNIPER,
		.noFlip = TRUE,
	},
	
	[SPECIES_INTELEON] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 85,
		.baseDefense 	= 65,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 120,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_SNIPER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNIPER,
		.noFlip = TRUE,
	},
	
	[SPECIES_SKWOVET] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 55,
		.baseDefense 	= 55,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 25,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 55,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_ORAN_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHEEKPOUCH,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},
	
	[SPECIES_GREEDENT] =
	{
		.baseHP 		= 120,
		.baseAttack 	= 95,
		.baseDefense 	= 95,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 20,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 90,
		.expYield = 161,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SITRUS_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_CHEEKPOUCH,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},
	
	[SPECIES_ROOKIDEE] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 47,
		.baseDefense 	= 35,
		.baseSpAttack 	= 33,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 57,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_FLYING,
		.catchRate = 255,
		.expYield = 49,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_BIGPECKS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},
	
	[SPECIES_CORVISQUIRE] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 67,
		.baseDefense 	= 55,
		.baseSpAttack 	= 43,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 77,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_FLYING,
		.catchRate = 120,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_KEENEYE,
		.ability2 = ABILITY_BIGPECKS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},
	
	[SPECIES_CORVIKNIGHT] =
	{
		.baseHP 		= 98,
		.baseAttack 	= 87,
		.baseDefense 	= 105,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 67,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_MIRRORARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},
	
	[SPECIES_BLIPBUG] =
	{
		.baseHP 		= 25,
		.baseAttack 	= 20,
		.baseDefense 	= 20,
		.baseSpAttack 	= 25,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 45,
		.type1 = TYPE_BUG,
		.type2 = TYPE_BUG,
		.catchRate = 255,
		.expYield = 36,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},
	
	[SPECIES_DOTTLER] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 35,
		.baseDefense 	= 80,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 30,
		.type1 = TYPE_BUG,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 120,
		.expYield = 117,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PSYCHIC_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_COMPOUNDEYES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},
	
	[SPECIES_ORBEETLE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 45,
		.baseDefense 	= 110,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 90,
		.type1 = TYPE_BUG,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 186,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PSYCHIC_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},
	
	[SPECIES_NICKIT] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 28,
		.baseDefense 	= 28,
		.baseSpAttack 	= 47,
		.baseSpDefense 	= 52,
		.baseSpeed 		= 50,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 255,
		.expYield = 49,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STAKEOUT,
		.noFlip = TRUE,
	},
	
	[SPECIES_THIEVUL] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 58,
		.baseDefense 	= 58,
		.baseSpAttack 	= 87,
		.baseSpDefense 	= 92,
		.baseSpeed 		= 90,
		.type1 = TYPE_DARK,
		.type2 = TYPE_DARK,
		.catchRate = 127,
		.expYield = 159,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_UNBURDEN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STAKEOUT,
		.noFlip = TRUE,
	},
	
	[SPECIES_GOSSIFLEUR] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 40,
		.baseDefense 	= 60,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 10,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 190,
		.expYield = 50,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_COTTONDOWN,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_EFFECTSPORE,
		.noFlip = TRUE,
	},
	
	[SPECIES_ELDEGOSS] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 50,
		.baseDefense 	= 90,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 60,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 75,
		.expYield = 161,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_COTTONDOWN,
		.ability2 = ABILITY_REGENERATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_EFFECTSPORE,
		.noFlip = TRUE,
	},
	[SPECIES_WOOLOO] =
	{
		.baseHP 		= 42,
		.baseAttack 	= 40,
		.baseDefense 	= 55,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 48,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 122,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FLUFFY,
		.ability2 = ABILITY_RUNAWAY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BULLETPROOF,
		.noFlip = TRUE,
	},
	
	[SPECIES_DUBWOOL] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 80,
		.baseDefense 	= 100,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 88,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 127,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_FLUFFY,
		.ability2 = ABILITY_STEADFAST,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BULLETPROOF,
		.noFlip = TRUE,
	},
	
	[SPECIES_CHEWTLE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 64,
		.baseDefense 	= 50,
		.baseSpAttack 	= 38,
		.baseSpDefense 	= 38,
		.baseSpeed 		= 44,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 255,
		.expYield = 57,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_STRONGJAW,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},
	
	[SPECIES_DREDNAW] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 115,
		.baseDefense 	= 90,
		.baseSpAttack 	= 48,
		.baseSpDefense 	= 68,
		.baseSpeed 		= 74,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ROCK,
		.catchRate = 75,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_STRONGJAW,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},
	
	[SPECIES_YAMPER] =
	{
		.baseHP 		= 59,
		.baseAttack 	= 45,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 26,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 255,
		.expYield = 54,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BALLFETCH,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},
	
	[SPECIES_BOLTUND] =
	{
		.baseHP 		= 69,
		.baseAttack 	= 90,
		.baseDefense 	= 60,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 121,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 45,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STRONGJAW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_COMPETITIVE,
		.noFlip = TRUE,
	},
	
	[SPECIES_ROLYCOLY] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 40,
		.baseDefense 	= 50,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 30,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 255,
		.expYield = 48,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STEAMENGINE,
		.ability2 = ABILITY_HEATPROOF,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLASHFIRE,
		.noFlip = TRUE,
	},
	
	[SPECIES_CARKOL] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 60,
		.baseDefense 	= 90,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 50,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FIRE,
		.catchRate = 120,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STEAMENGINE,
		.ability2 = ABILITY_FLAMEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLASHFIRE,
		.noFlip = TRUE,
	},
	
	[SPECIES_COALOSSAL] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 80,
		.baseDefense 	= 120,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 30,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STEAMENGINE,
		.ability2 = ABILITY_FLAMEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLASHFIRE,
		.noFlip = TRUE,
	},
	
	[SPECIES_APPLIN] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 40,
		.baseDefense 	= 80,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 20,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DRAGON,
		.catchRate = 255,
		.expYield = 52,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_RIPEN,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_BULLETPROOF,
		.noFlip = TRUE,
	},
	
	[SPECIES_FLAPPLE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 110,
		.baseDefense 	= 80,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 70,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_RIPEN,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HUSTLE,
		.noFlip = TRUE,
	},
	
	[SPECIES_APPLETUN] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 85,
		.baseDefense 	= 80,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 170,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_RIPEN,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_THICKFAT,
		.noFlip = TRUE,
	},
	
	[SPECIES_SILICOBRA] =
	{
		.baseHP 		= 52,
		.baseAttack 	= 57,
		.baseDefense 	= 75,
		.baseSpAttack 	= 35,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 46,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 255,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SANDSPIT,
		.ability2 = ABILITY_SHEDSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},
	
	[SPECIES_SANDACONDA] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 107,
		.baseDefense 	= 125,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 71,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 120,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SANDSPIT,
		.ability2 = ABILITY_SHEDSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},
	
	[SPECIES_CRAMORANT] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 85,
		.baseDefense 	= 55,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 85,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_GULPMISSLE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_ARROKUDA] =
	{
		.baseHP 		= 41,
		.baseAttack 	= 63,
		.baseDefense 	= 40,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 66,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 255,
		.expYield = 56,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STALWART,
		.noFlip = TRUE,
	},
	
	[SPECIES_BARRASKEWDA] =
	{
		.baseHP 		= 61,
		.baseAttack 	= 123,
		.baseDefense 	= 60,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 136,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 172,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_2,
		.eggGroup2 = EGG_GROUP_WATER_2,
		.ability1 = ABILITY_SWIFTSWIM,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STALWART,
		.noFlip = TRUE,
	},
	
	[SPECIES_TOXEL] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 38,
		.baseDefense 	= 35,
		.baseSpAttack 	= 54,
		.baseSpDefense 	= 35,
		.baseSpeed 		= 40,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_POISON,
		.catchRate = 75,
		.expYield = 48,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_RATTLED,
		.ability2 = ABILITY_KLUTZ,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RATTLED,
		.noFlip = TRUE,
	},
	
	[SPECIES_TOXTRICITY] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 98,
		.baseDefense 	= 70,
		.baseSpAttack 	= 114,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 75,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 176,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_PUNKROCK,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PUNKROCK,
		.noFlip = TRUE,
	},
		
	[SPECIES_SIZZLIPEDE] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 45,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 45,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_BUG,
		.catchRate = 190,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_WHITESMOKE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLAMEBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_CENTISKORCH] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 115,
		.baseDefense 	= 65,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_BUG,
		.catchRate = 75,
		.expYield = 184,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_WHITESMOKE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLAMEBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_CLOBBOPUS] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 68,
		.baseDefense 	= 60,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 32,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 180,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_LIMBER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TECHNICIAN,
		.noFlip = TRUE,
	},
	
	[SPECIES_GRAPPLOCT] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 118,
		.baseDefense 	= 90,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 42,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_LIMBER,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TECHNICIAN,
		.noFlip = TRUE,
	},
	
	[SPECIES_SINISTEA] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 45,
		.baseSpAttack 	= 74,
		.baseSpDefense 	= 54,
		.baseSpeed 		= 50,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 120,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WEAKARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CURSEDBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_POLTEAGEIST] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 134,
		.baseSpDefense 	= 114,
		.baseSpeed 		= 70,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 60,
		.expYield = 178,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WEAKARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CURSEDBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_HATENNA] =
	{
		.baseHP 		= 42,
		.baseAttack 	= 30,
		.baseDefense 	= 45,
		.baseSpAttack 	= 56,
		.baseSpDefense 	= 53,
		.baseSpeed 		= 39,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 235,
		.expYield = 53,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HEALER,
		.ability2 = ABILITY_ANTICIPATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MAGICBOUNCE,
		.noFlip = TRUE,
	},
	
	[SPECIES_HATTREM] =
	{
		.baseHP 		= 57,
		.baseAttack 	= 40,
		.baseDefense 	= 65,
		.baseSpAttack 	= 86,
		.baseSpDefense 	= 73,
		.baseSpeed 		= 49,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 120,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HEALER,
		.ability2 = ABILITY_ANTICIPATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MAGICBOUNCE,
		.noFlip = TRUE,
	},
	
	[SPECIES_HATTERENE] =
	{
		.baseHP 		= 57,
		.baseAttack 	= 90,
		.baseDefense 	= 95,
		.baseSpAttack 	= 136,
		.baseSpDefense 	= 103,
		.baseSpeed 		= 29,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HEALER,
		.ability2 = ABILITY_ANTICIPATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MAGICBOUNCE,
		.noFlip = TRUE,
	},
	
	[SPECIES_IMPIDIMP] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 45,
		.baseDefense 	= 30,
		.baseSpAttack 	= 55,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 50,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FAIRY,
		.catchRate = 255,
		.expYield = 53,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_PICKPOCKET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},
	
	[SPECIES_MORGREM] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 45,
		.baseSpAttack 	= 75,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 70,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FAIRY,
		.catchRate = 120,
		.expYield = 130,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_PICKPOCKET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},
	
	[SPECIES_GRIMMSNARL] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 120,
		.baseDefense 	= 65,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 60,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_PICKPOCKET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FRISK,
		.noFlip = TRUE,
	},
	
	[SPECIES_OBSTAGOON] =
	{
		.baseHP 		= 93,
		.baseAttack 	= 90,
		.baseDefense 	= 101,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 81,
		.baseSpeed 		= 95,
		.type1 = TYPE_DARK,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 196,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RECKLESS,
		.ability2 = ABILITY_GUTS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},
	
	[SPECIES_PERRSERKER] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 110,
		.baseDefense 	= 100,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 50,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 90,
		.expYield = 154,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_BATTLEARMOR,
		.ability2 = ABILITY_TOUGHCLAWS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STEELY_SPIRIT,
		.noFlip = TRUE,
	},
	
	[SPECIES_CURSOLA] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 95,
		.baseDefense 	= 50,
		.baseSpAttack 	= 145,
		.baseSpDefense 	= 130,
		.baseSpeed 		= 30,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 30,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_WEAKARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PERISH_BODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_SIRFETCHD] =
	{
		.baseHP 		= 62,
		.baseAttack 	= 135,
		.baseDefense 	= 95,
		.baseSpAttack 	= 68,
		.baseSpDefense 	= 82,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LEEK,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STEADFAST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SCRAPPY,
		.noFlip = TRUE,
	},
	
	[SPECIES_MR_RIME] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 85,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 70,
		.type1 = TYPE_ICE,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 182,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SCREENCLEANER,
		.ability2 = ABILITY_TANGLEDFEET,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ICEBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_RUNERIGUS] =
	{
		.baseHP 		= 58,
		.baseAttack 	= 95,
		.baseDefense 	= 145,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 30,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GHOST,
		.catchRate = 90,
		.expYield = 169,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WANDERING_SPIRIT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_MILCERY] =
	{
		.baseHP 		= 45,
		.baseAttack 	= 40,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 61,
		.baseSpeed 		= 34,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 200,
		.expYield = 54,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},
	
	[SPECIES_ALCREMIE_STRAWBERRY] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 121,
		.baseSpeed 		= 64,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 100,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},
	
	[SPECIES_FALINKS] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 75,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_BATTLEARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_DEFIANT,
		.noFlip = TRUE,
	},
	
	[SPECIES_PINCURCHIN] =
	{
		.baseHP 		= 48,
		.baseAttack 	= 101,
		.baseDefense 	= 95,
		.baseSpAttack 	= 91,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 15,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 75,
		.expYield = 152,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LIGHTNINGROD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ELECTRICSURGE,
		.noFlip = TRUE,
	},
	
	[SPECIES_SNOM] =
	{
		.baseHP 		= 30,
		.baseAttack 	= 25,
		.baseDefense 	= 35,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 20,
		.type1 = TYPE_ICE,
		.type2 = TYPE_BUG,
		.catchRate = 190,
		.expYield = 37,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SNOWBALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_ICESCALES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ICESCALES,
		.noFlip = TRUE,
	},
	
	[SPECIES_FROSMOTH] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 65,
		.baseDefense 	= 60,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 65,
		.type1 = TYPE_ICE,
		.type2 = TYPE_BUG,
		.catchRate = 75,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SHIELDDUST,
		.ability2 = ABILITY_ICESCALES,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ICESCALES,
		.noFlip = TRUE,
	},
	
	[SPECIES_STONJOURNER] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 125,
		.baseDefense 	= 135,
		.baseSpAttack 	= 20,
		.baseSpDefense 	= 20,
		.baseSpeed 		= 70,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_ROCK,
		.catchRate = 60,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_POWERSPOT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_EISCUE] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 110,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 50,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 60,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_ICEFACE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
		
	[SPECIES_INDEEDEE] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 65,
		.baseDefense 	= 55,
		.baseSpAttack 	= 105,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 95,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_NORMAL,
		.catchRate = 30,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 40,
		.friendship = 140,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_SYNCHRONIZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PSYCHICSURGE,
		.noFlip = TRUE,
	},
		
	[SPECIES_MORPEKO] =
	{
		.baseHP 		= 58,
		.baseAttack 	= 95,
		.baseDefense 	= 58,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 58,
		.baseSpeed 		= 97,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_DARK,
		.catchRate = 180,
		.expYield = 153,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HUNGERSWITCH,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_CUFANT] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 80,
		.baseDefense 	= 49,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 49,
		.baseSpeed 		= 40,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 190,
		.expYield = 66,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LAGGING_TAIL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHEERFORCE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEAVYMETAL,
		.noFlip = TRUE,
	},
	
	[SPECIES_COPPERAJAH] = 
	{
		.baseHP 		= 122,
		.baseAttack 	= 130,
		.baseDefense 	= 69,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 69,
		.baseSpeed 		= 30,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 90,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LAGGING_TAIL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHEERFORCE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEAVYMETAL,
		.noFlip = TRUE,
	},
	
	[SPECIES_DRACOZOLT] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 100,
		.baseDefense 	= 90,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 75,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_VOLTABSORB,
		.ability2 = ABILITY_HUSTLE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDRUSH,
		.noFlip = TRUE,
	},
	
	[SPECIES_ARCTOZOLT] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 100,
		.baseDefense 	= 90,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 55,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_VOLTABSORB,
		.ability2 = ABILITY_STATIC,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SLUSHRUSH,
		.noFlip = TRUE,
	},
	
	[SPECIES_DRACOVISH] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 90,
		.baseDefense 	= 100,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 75,
		.type1 = TYPE_WATER,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_STRONGJAW,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDRUSH,
		.noFlip = TRUE,
	},
	
	[SPECIES_ARCTOVISH] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 90,
		.baseDefense 	= 100,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 55,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_ICEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SLUSHRUSH,
		.noFlip = TRUE,
	},
	
	[SPECIES_DURALUDON] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 95,
		.baseDefense 	= 115,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 85,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 187,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_LIGHTMETAL,
		.ability2 = ABILITY_HEAVYMETAL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STALWART,
		.noFlip = TRUE,
	},
	
	[SPECIES_DREEPY] =
	{
		.baseHP 		= 28,
		.baseAttack 	= 60,
		.baseDefense 	= 30,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 30,
		.baseSpeed 		= 82,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 54,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CURSEDBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_DRAKLOAK] =
	{
		.baseHP 		= 68,
		.baseAttack 	= 80,
		.baseDefense 	= 50,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 102,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 144,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CURSEDBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_DRAGAPULT] =
	{
		.baseHP 		= 88,
		.baseAttack 	= 120,
		.baseDefense 	= 75,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 142,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_GHOST,
		.catchRate = 45,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_CLEARBODY,
		.ability2 = ABILITY_INFILTRATOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CURSEDBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_ZACIAN] =
	{
		.baseHP 		= 92,
		.baseAttack 	= 130,
		.baseDefense 	= 115,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 138,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 10,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_INTREPIDSWORD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
		
	[SPECIES_ZAMAZENTA] =
	{
		.baseHP 		= 92,
		.baseAttack 	= 130,
		.baseDefense 	= 115,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 138,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 10,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DAUNTLESSSHIELD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
		
	[SPECIES_ETERNATUS] =
	{
		.baseHP 		= 140,
		.baseAttack 	= 85,
		.baseDefense 	= 95,
		.baseSpAttack 	= 145,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 130,
		.type1 = TYPE_POISON,
		.type2 = TYPE_DRAGON,
		.catchRate = 255,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_KUBFU] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 90,
		.baseDefense 	= 60,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 72,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 3,
		.expYield = 20,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_INNERFOCUS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					     
	[SPECIES_URSHIFU_SINGLE] = 
	{
		.baseHP 		= 100,
		.baseAttack 	= 130,
		.baseDefense 	= 100,
		.baseSpAttack 	= 63,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 97,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_DARK,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_INNERFOCUS, //UNSEEN FIST NOT DEFINED
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_ZARUDE] = 
	{
		.baseHP 		= 105,
		.baseAttack 	= 120,
		.baseDefense 	= 105,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 105,
		.type1 = TYPE_DARK,
		.type2 = TYPE_GRASS,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LEAFGUARD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
/*	
	[SPECIES_CALYREX] = //PLACEHOLDER DATA
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_GRASS,
		.catchRate = 255,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_UNNERVE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_REGIELEKI] = //PLACEHOLDER DATA
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 255,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_LIGHTNINGROD, //NEW ABILITY TRANSISTOR
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_REGIDRAGO] = //PLACEHOLDER DATA
	{
		.baseHP 		= 100,
		.baseAttack 	= 100,
		.baseDefense 	= 100,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 100,
		.type1 = TYPE_DRAGON,
		.type2 = TYPE_DRAGON,
		.catchRate = 255,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE, //NEW ABILITY DRAGONS MAW
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	*/
			
	[SPECIES_CRAMORANT_GULPING] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 85,
		.baseDefense 	= 55,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 85,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_GULPMISSLE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_CRAMORANT_GORGING] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 85,
		.baseDefense 	= 55,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 85,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_GULPMISSLE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_TOXTRICITY_LOW_KEY] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 98,
		.baseDefense 	= 70,
		.baseSpAttack 	= 114,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 75,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 176,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_PUNKROCK,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PUNKROCK,
		.noFlip = TRUE,
	},
					      
	[SPECIES_SINISTEA_CHIPPED] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 45,
		.baseSpAttack 	= 74,
		.baseSpDefense 	= 54,
		.baseSpeed 		= 50,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 120,
		.expYield = 62,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 1,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WEAKARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CURSEDBODY,
		.noFlip = TRUE,
	},
					      
	[SPECIES_POLTEAGEIST_CHIPPED] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 134,
		.baseSpDefense 	= 114,
		.baseSpeed 		= 70,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 60,
		.expYield = 178,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WEAKARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CURSEDBODY,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ALCREMIE_BERRY] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 121,
		.baseSpeed 		= 64,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 100,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ALCREMIE_LOVE] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 121,
		.baseSpeed 		= 64,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 100,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ALCREMIE_CLOVER] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 121,
		.baseSpeed 		= 64,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 100,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ALCREMIE_FLOWER] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 121,
		.baseSpeed 		= 64,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 100,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ALCREMIE_RIBBON] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 121,
		.baseSpeed 		= 64,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 100,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ALCREMIE_STAR] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 121,
		.baseSpeed 		= 64,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 100,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},
					      
	[SPECIES_EISCUE_NOICE] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 80,
		.baseDefense 	= 70,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 130,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 60,
		.expYield = 165,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_ICEFACE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_INDEEDEE_FEMALE] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 55,
		.baseDefense 	= 65,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 85,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_NORMAL,
		.catchRate = 30,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 40,
		.friendship = 140,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_OWNTEMPO,
		.ability2 = ABILITY_SYNCHRONIZE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PSYCHICSURGE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_MORPEKO_HANGRY] =
	{
		.baseHP 		= 58,
		.baseAttack 	= 95,
		.baseDefense 	= 58,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 58,
		.baseSpeed 		= 97,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_DARK,
		.catchRate = 180,
		.expYield = 153,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HUNGERSWITCH,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ZACIAN_CROWNED] =
	{
		.baseHP 		= 92,
		.baseAttack 	= 170,
		.baseDefense 	= 115,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 115,
		.baseSpeed 		= 148,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_STEEL,
		.catchRate = 10,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_INTREPIDSWORD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ZAMAZENTA_CROWNED] =
	{
		.baseHP 		= 92,
		.baseAttack 	= 130,
		.baseDefense 	= 145,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 145,
		.baseSpeed 		= 128,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_STEEL,
		.catchRate = 10,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DAUNTLESSSHIELD,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ETERNATUS_ETERNAMAX] =
	{
		.baseHP 		= 255,
		.baseAttack 	= 115,
		.baseDefense 	= 250,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 250,
		.baseSpeed 		= 130,
		.type1 = TYPE_POISON,
		.type2 = TYPE_DRAGON,
		.catchRate = 255,
		.expYield = 255,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_URSHIFU_RAPID] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 130,
		.baseDefense 	= 100,
		.baseSpAttack 	= 63,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 97,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_WATER,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_INNERFOCUS, //UNSEEN FIST NOT DEFINED
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_MEOWTH_G] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 55,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 40,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 255,
		.expYield = 69,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_TOUGHCLAWS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},
	
	[SPECIES_PONYTA_G] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 85,
		.baseDefense 	= 55,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 90,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 190,
		.expYield = 152,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_PASTELVEIL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANTICIPATION,
		.noFlip = TRUE,
	},
	
	[SPECIES_RAPIDASH_G] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 100,
		.baseDefense 	= 70,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 105,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 60,
		.expYield = 192,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_PASTELVEIL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANTICIPATION,
		.noFlip = TRUE,
	},
	
	[SPECIES_SLOWPOKE_G] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 15,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 190,
		.expYield = 99,
		.evYield_HP 		= 1,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_OWNTEMPO,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_REGENERATOR,
		.noFlip = TRUE,
	},
	
	[SPECIES_SLOWBRO_G] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 100,
		.baseDefense 	= 95,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 30,
		.type1 = TYPE_POISON,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 75,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_GLUTTONY, //QUICK DRAW NOT DEFINED
		.ability2 = ABILITY_OWNTEMPO,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_REGENERATOR,
		.noFlip = TRUE,
	}, 
	
	[SPECIES_FARFETCHD_G] =
	{
		.baseHP 		= 52,
		.baseAttack 	= 95,
		.baseDefense 	= 55,
		.baseSpAttack 	= 58,
		.baseSpDefense 	= 62,
		.baseSpeed 		= 55,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 132,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_STEADFAST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SCRAPPY,
		.noFlip = TRUE,
	},
	
	[SPECIES_KOFFING_G] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 65,
		.baseDefense 	= 95,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 35,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 190,
		.expYield = 114,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SMOKE_BALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NEUTRALIZINGGAS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STENCH,
		.noFlip = TRUE,
	},
	
	[SPECIES_WEEZING_G] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 90,
		.baseDefense 	= 120,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 60,
		.type1 = TYPE_POISON,
		.type2 = TYPE_FAIRY,
		.catchRate = 60,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_LEVITATE,
		.ability2 = ABILITY_NEUTRALIZINGGAS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MISTYSURGE,
		.noFlip = TRUE,
	},
	
	[SPECIES_MIME_JR_G] =
	{
		.baseHP 		= 20,
		.baseAttack 	= 25,
		.baseDefense 	= 45,
		.baseSpAttack 	= 70,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 60,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 145,
		.expYield = 78,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LEPPA_BERRY,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_SOUNDPROOF,
		.ability2 = ABILITY_FILTER,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TECHNICIAN,
		.noFlip = TRUE,
	},
	
	[SPECIES_MR_MIME_G] =
	{
		.baseHP 		= 50,
		.baseAttack 	= 65,
		.baseDefense 	= 65,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 100,
		.type1 = TYPE_ICE,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 136,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_SCREENCLEANER,
		.ability2 = ABILITY_VITALSPIRIT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ICEBODY,
		.noFlip = TRUE,
	},
	
/*	[SPECIES_ARTICUNO_G] = //PLACEHOLDER DATA
	{
		.baseHP 		= 90,
		.baseAttack 	= 85,
		.baseDefense 	= 100,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 125,
		.baseSpeed 		= 85,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 215,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_COMPETITIVE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
					      
	[SPECIES_ZAPDOS_G] = //PLACEHOLDER DATA
	{
		.baseHP 		= 90,
		.baseAttack 	= 90,
		.baseDefense 	= 85,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 216,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_DEFIANT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_MOLTRES_G] = //PLACEHOLDER DATA
	{
		.baseHP 		= 90,
		.baseAttack 	= 100,
		.baseDefense 	= 90,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 90,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FLYING,
		.catchRate = 3,
		.expYield = 217,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 80,
		.friendship = 35,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_BERSERK,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_SLOWKING_G] = //PLACEHOLDER DATA
	{
		.baseHP 		= 95,
		.baseAttack 	= 75,
		.baseDefense 	= 80,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 30,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_POISON,
		.catchRate = 70,
		.expYield = 164,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_GLUTTONY,
		.ability2 = ABILITY_OWNTEMPO,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_REGENERATOR,
		.noFlip = TRUE,
	}, */
	
	[SPECIES_CORSOLA_G] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 55,
		.baseDefense 	= 100,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 30,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_GHOST,
		.catchRate = 60,
		.expYield = 113,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(75),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_WEAKARMOR,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CURSEDBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_ZIGZAGOON_G] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 30,
		.baseDefense 	= 41,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 41,
		.baseSpeed 		= 60,
		.type1 = TYPE_DARK,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 60,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_QUICKFEET,
		.noFlip = TRUE,
	},
	
	[SPECIES_LINOONE_G] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 70,
		.baseDefense 	= 61,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 61,
		.baseSpeed 		= 100,
		.type1 = TYPE_DARK,
		.type2 = TYPE_NORMAL,
		.catchRate = 90,
		.expYield = 128,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_QUICKFEET,
		.noFlip = TRUE,
	},
	
	[SPECIES_DARUMAKA_G] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 90,
		.baseDefense 	= 45,
		.baseSpAttack 	= 15,
		.baseSpDefense 	= 45,
		.baseSpeed 		= 50,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 120,
		.expYield = 63,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 1,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_HUSTLE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_INNERFOCUS,
		.noFlip = TRUE,
	},
	
	[SPECIES_DARMANITAN_G] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 140,
		.baseDefense 	= 55,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 95,
		.type1 = TYPE_ICE,
		.type2 = TYPE_ICE,
		.catchRate = 60,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_GORILLATACTICS,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ZENMODE,
		.noFlip = TRUE,
	},
	
	[SPECIES_DARMANITAN_G_ZEN] =
	{
		.baseHP 		= 105,
		.baseAttack 	= 160,
		.baseDefense 	= 55,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 55,
		.baseSpeed 		= 135,
		.type1 = TYPE_ICE,
		.type2 = TYPE_FIRE,
		.catchRate = 60,
		.expYield = 168,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_ZENMODE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ZENMODE,
		.noFlip = TRUE,
	},
	
	[SPECIES_YAMASK_G] =
	{
		.baseHP 		= 38,
		.baseAttack 	= 55,
		.baseDefense 	= 85,
		.baseSpAttack 	= 30,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 30,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GHOST,
		.catchRate = 190,
		.expYield = 61,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 1,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_WANDERING_SPIRIT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_STUNFISK_G] =
	{
		.baseHP 		= 109,
		.baseAttack 	= 81,
		.baseDefense 	= 99,
		.baseSpAttack 	= 66,
		.baseSpDefense 	= 84,
		.baseSpeed 		= 32,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_STEEL,
		.catchRate = 75,
		.expYield = 165,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_MIMICRY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_VENUSAUR_GIGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 82,
		.baseDefense 	= 83,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 100,
		.baseSpeed 		= 80,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_CHLOROPHYLL,
		.noFlip = TRUE,
	},
	
	[SPECIES_CHARIZARD_GIGA] =
	{
		.baseHP 		= 78,
		.baseAttack 	= 84,
		.baseDefense 	= 78,
		.baseSpAttack 	= 109,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 100,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 209,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SOLARPOWER,
		.noFlip = TRUE,
	},
	
	[SPECIES_BLASTOISE_GIGA] =
	{
		.baseHP 		= 79,
		.baseAttack 	= 83,
		.baseDefense 	= 100,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 105,
		.baseSpeed 		= 78,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_RAINDISH,
		.noFlip = TRUE,
	},
	
	[SPECIES_BUTTERFREE_GIGA] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 45,
		.baseDefense 	= 50,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 70,
		.type1 = TYPE_BUG,
		.type2 = TYPE_FLYING,
		.catchRate = 45,
		.expYield = 160,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SILVER_POWDER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_COMPOUNDEYES,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TINTEDLENS,
		.noFlip = TRUE,
	},
	
	[SPECIES_PIKACHU_GIGA] =
	{
		.baseHP 		= 35,
		.baseAttack 	= 55,
		.baseDefense 	= 40,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 90,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_ELECTRIC,
		.catchRate = 190,
		.expYield = 82,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 2,
		.item1 = ITEM_ORAN_BERRY,
		.item2 = ITEM_LIGHT_BALL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 10,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_STATIC,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_LIGHTNINGROD,
		.noFlip = TRUE,
	},
	
	[SPECIES_MEOWTH_GIGA] =
	{
		.baseHP 		= 40,
		.baseAttack 	= 45,
		.baseDefense 	= 35,
		.baseSpAttack 	= 40,
		.baseSpDefense 	= 40,
		.baseSpeed 		= 90,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 255,
		.expYield = 69,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 1,
		.item1 = ITEM_NONE,
		.item2 = ITEM_QUICK_CLAW,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_PICKUP,
		.ability2 = ABILITY_TECHNICIAN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_UNNERVE,
		.noFlip = TRUE,
	},
	
	[SPECIES_MACHAMP_GIGA] =
	{
		.baseHP 		= 90,
		.baseAttack 	= 130,
		.baseDefense 	= 80,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 55,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_FIGHTING,
		.catchRate = 45,
		.expYield = 193,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_FOCUS_BAND,
		.genderRatio = PERCENT_FEMALE(25),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_GUTS,
		.ability2 = ABILITY_NOGUARD,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STEADFAST,
		.noFlip = TRUE,
	},
	
	[SPECIES_GENGAR_GIGA] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 65,
		.baseDefense 	= 60,
		.baseSpAttack 	= 130,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 110,
		.type1 = TYPE_GHOST,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 190,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_SPELL_TAG,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_AMORPHOUS,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_CURSEDBODY,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_KINGLER_GIGA] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 130,
		.baseDefense 	= 115,
		.baseSpAttack 	= 50,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 75,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 60,
		.expYield = 206,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_WATER_3,
		.eggGroup2 = EGG_GROUP_WATER_3,
		.ability1 = ABILITY_HYPERCUTTER,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SHEERFORCE,
		.noFlip = TRUE,
	},
	
	[SPECIES_LAPRAS_GIGA] =
	{
		.baseHP 		= 130,
		.baseAttack 	= 85,
		.baseDefense 	= 80,
		.baseSpAttack 	= 85,
		.baseSpDefense 	= 95,
		.baseSpeed 		= 60,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ICE,
		.catchRate = 45,
		.expYield = 219,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_MYSTIC_WATER,
		.item2 = ITEM_MYSTIC_WATER,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_WATERABSORB,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HYDRATION,
		.noFlip = TRUE,
	},
	
	[SPECIES_EEVEE_GIGA] =
	{
		.baseHP 		= 55,
		.baseAttack 	= 55,
		.baseDefense 	= 50,
		.baseSpAttack 	= 45,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 55,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 45,
		.expYield = 92,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 1,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 35,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_RUNAWAY,
		.ability2 = ABILITY_ADAPTABILITY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_ANTICIPATION,
		.noFlip = TRUE,
	},
	
	[SPECIES_SNORLAX_GIGA] =
	{
		.baseHP 		= 160,
		.baseAttack 	= 110,
		.baseDefense 	= 65,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 110,
		.baseSpeed 		= 30,
		.type1 = TYPE_NORMAL,
		.type2 = TYPE_NORMAL,
		.catchRate = 25,
		.expYield = 213,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_LEFTOVERS,
		.item2 = ITEM_LEFTOVERS,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 40,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_MONSTER,
		.ability1 = ABILITY_IMMUNITY,
		.ability2 = ABILITY_THICKFAT,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GLUTTONY,
		.noFlip = TRUE,
	},
	
	[SPECIES_GARBODOR_GIGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 95,
		.baseDefense 	= 82,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 82,
		.baseSpeed 		= 75,
		.type1 = TYPE_POISON,
		.type2 = TYPE_POISON,
		.catchRate = 60,
		.expYield = 166,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_BLACK_SLUDGE,
		.item2 = ITEM_NUGGET,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STENCH,
		.ability2 = ABILITY_WEAKARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AFTERMATH,
		.noFlip = TRUE,
	},
	
	[SPECIES_MELMETAL_GIGA] =
	{
		.baseHP 		= 135,
		.baseAttack 	= 143,
		.baseDefense 	= 143,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 34,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 3,
		.expYield = 199,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = MON_GENDERLESS,
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_IRONFIST,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_RILLABOOM_GIGA] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 125,
		.baseDefense 	= 90,
		.baseSpAttack 	= 60,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 85,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_GRASS,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 3,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_GRASS,
		.ability1 = ABILITY_OVERGROW,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_GRASSYSURGE,
		.noFlip = TRUE,
	},
	
	[SPECIES_CINDERACE_GIGA] =
	{
		.baseHP 		= 80,
		.baseAttack 	= 116,
		.baseDefense 	= 75,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 119,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_BLAZE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PROTEAN,
		.noFlip = TRUE,
	},
	
	[SPECIES_INTELEON_GIGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 85,
		.baseDefense 	= 65,
		.baseSpAttack 	= 125,
		.baseSpDefense 	= 65,
		.baseSpeed 		= 120,
		.type1 = TYPE_WATER,
		.type2 = TYPE_WATER,
		.catchRate = 45,
		.expYield = 210,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 3,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_WATER_1,
		.eggGroup2 = EGG_GROUP_FIELD,
		.ability1 = ABILITY_TORRENT,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SNIPER,
		.noFlip = TRUE,
	},
	
	[SPECIES_CORVIKNIGHT_GIGA] =
	{
		.baseHP 		= 98,
		.baseAttack 	= 87,
		.baseDefense 	= 105,
		.baseSpAttack 	= 53,
		.baseSpDefense 	= 85,
		.baseSpeed 		= 67,
		.type1 = TYPE_FLYING,
		.type2 = TYPE_STEEL,
		.catchRate = 45,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_FLYING,
		.eggGroup2 = EGG_GROUP_FLYING,
		.ability1 = ABILITY_PRESSURE,
		.ability2 = ABILITY_UNNERVE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MIRRORARMOR,
		.noFlip = TRUE,
	},
	
	[SPECIES_ORBEETLE_GIGA] =
	{
		.baseHP 		= 60,
		.baseAttack 	= 45,
		.baseDefense 	= 110,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 120,
		.baseSpeed 		= 90,
		.type1 = TYPE_BUG,
		.type2 = TYPE_PSYCHIC,
		.catchRate = 45,
		.expYield = 186,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 3,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_PSYCHIC_SEED,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_SWARM,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TELEPATHY,
		.noFlip = TRUE,
	},
	
	[SPECIES_DREDNAW_GIGA] =
{
		.baseHP 		= 90,
		.baseAttack 	= 115,
		.baseDefense 	= 90,
		.baseSpAttack 	= 48,
		.baseSpDefense 	= 68,
		.baseSpeed 		= 74,
		.type1 = TYPE_WATER,
		.type2 = TYPE_ROCK,
		.catchRate = 75,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MONSTER,
		.eggGroup2 = EGG_GROUP_WATER_1,
		.ability1 = ABILITY_STRONGJAW,
		.ability2 = ABILITY_SHELLARMOR,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SWIFTSWIM,
		.noFlip = TRUE,
	},
	
	[SPECIES_COALOSSAL_GIGA] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 80,
		.baseDefense 	= 120,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 30,
		.type1 = TYPE_ROCK,
		.type2 = TYPE_FIRE,
		.catchRate = 45,
		.expYield = 177,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 3,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 15,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_STEAMENGINE,
		.ability2 = ABILITY_FLAMEBODY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLASHFIRE,
		.noFlip = TRUE,
	},
	
	[SPECIES_FLAPPLE_GIGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 110,
		.baseDefense 	= 80,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 70,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 170,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_RIPEN,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HUSTLE,
		.noFlip = TRUE,
	},
	
	[SPECIES_APPLETUN_GIGA] =
	{
		.baseHP 		= 110,
		.baseAttack 	= 85,
		.baseDefense 	= 80,
		.baseSpAttack 	= 100,
		.baseSpDefense 	= 80,
		.baseSpeed 		= 30,
		.type1 = TYPE_GRASS,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 170,
		.evYield_HP 		= 2,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_ERRATIC,
		.eggGroup1 = EGG_GROUP_GRASS,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_RIPEN,
		.ability2 = ABILITY_GLUTTONY,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_THICKFAT,
		.noFlip = TRUE,
	},
	
	[SPECIES_SANDACONDA_GIGA] =
	{
		.baseHP 		= 72,
		.baseAttack 	= 107,
		.baseDefense 	= 125,
		.baseSpAttack 	= 65,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 71,
		.type1 = TYPE_GROUND,
		.type2 = TYPE_GROUND,
		.catchRate = 120,
		.expYield = 179,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 2,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_SANDSPIT,
		.ability2 = ABILITY_SHEDSKIN,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_SANDVEIL,
		.noFlip = TRUE,
	},
	
	[SPECIES_TOXTRICITY_GIGA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 98,
		.baseDefense 	= 70,
		.baseSpAttack 	= 114,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 75,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 176,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_PUNKROCK,
		.ability2 = ABILITY_PLUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TECHNICIAN,
		.noFlip = TRUE,
	},
					      
	[SPECIES_TOXTRICITY_LOW_KEY_GIGA] =
	{
		.baseHP 		= 75,
		.baseAttack 	= 98,
		.baseDefense 	= 70,
		.baseSpAttack 	= 114,
		.baseSpDefense 	= 70,
		.baseSpeed 		= 75,
		.type1 = TYPE_ELECTRIC,
		.type2 = TYPE_POISON,
		.catchRate = 45,
		.expYield = 176,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_SLOW,
		.eggGroup1 = EGG_GROUP_HUMAN_LIKE,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_PUNKROCK,
		.ability2 = ABILITY_MINUS,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_TECHNICIAN,
		.noFlip = TRUE,
	},
	
	[SPECIES_CENTISKORCH_GIGA] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 115,
		.baseDefense 	= 65,
		.baseSpAttack 	= 90,
		.baseSpDefense 	= 90,
		.baseSpeed 		= 65,
		.type1 = TYPE_FIRE,
		.type2 = TYPE_BUG,
		.catchRate = 75,
		.expYield = 184,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_BUG,
		.eggGroup2 = EGG_GROUP_BUG,
		.ability1 = ABILITY_FLASHFIRE,
		.ability2 = ABILITY_WHITESMOKE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_FLAMEBODY,
		.noFlip = TRUE,
	},
	
	[SPECIES_HATTERENE_GIGA] =
	{
		.baseHP 		= 57,
		.baseAttack 	= 90,
		.baseDefense 	= 95,
		.baseSpAttack 	= 136,
		.baseSpDefense 	= 103,
		.baseSpeed 		= 29,
		.type1 = TYPE_PSYCHIC,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 3,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_FAIRY,
		.ability1 = ABILITY_HEALER,
		.ability2 = ABILITY_ANTICIPATION,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_MAGICBOUNCE,
		.noFlip = TRUE,
	},
	
	[SPECIES_GRIMMSNARL_GIGA] =
	{
		.baseHP 		= 95,
		.baseAttack 	= 120,
		.baseDefense 	= 65,
		.baseSpAttack 	= 95,
		.baseSpDefense 	= 75,
		.baseSpeed 		= 60,
		.type1 = TYPE_DARK,
		.type2 = TYPE_FAIRY,
		.catchRate = 45,
		.expYield = 208,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(0),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_HUMAN_LIKE,
		.ability1 = ABILITY_PRANKSTER,
		.ability2 = ABILITY_FRISK,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_PICKPOCKET,
		.noFlip = TRUE,
	},
	
	[SPECIES_ALCREMIE_GIGA] =
	{
		.baseHP 		= 65,
		.baseAttack 	= 60,
		.baseDefense 	= 75,
		.baseSpAttack 	= 110,
		.baseSpDefense 	= 121,
		.baseSpeed 		= 64,
		.type1 = TYPE_FAIRY,
		.type2 = TYPE_FAIRY,
		.catchRate = 100,
		.expYield = 173,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 2,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(100),
		.eggCycles = 20,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FAIRY,
		.eggGroup2 = EGG_GROUP_AMORPHOUS,
		.ability1 = ABILITY_SWEETVEIL,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_AROMAVEIL,
		.noFlip = TRUE,
	},
	
	[SPECIES_COPPERAJAH_GIGA] = 
	{
		.baseHP 		= 122,
		.baseAttack 	= 130,
		.baseDefense 	= 69,
		.baseSpAttack 	= 80,
		.baseSpDefense 	= 69,
		.baseSpeed 		= 30,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_STEEL,
		.catchRate = 90,
		.expYield = 175,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 2,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_LAGGING_TAIL,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 25,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_FIELD,
		.eggGroup2 = EGG_GROUP_MINERAL,
		.ability1 = ABILITY_SHEERFORCE,
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_HEAVYMETAL,
		.noFlip = TRUE,
	},
	
	[SPECIES_DURALUDON_GIGA] =
	{
		.baseHP 		= 70,
		.baseAttack 	= 95,
		.baseDefense 	= 115,
		.baseSpAttack 	= 120,
		.baseSpDefense 	= 50,
		.baseSpeed 		= 85,
		.type1 = TYPE_STEEL,
		.type2 = TYPE_DRAGON,
		.catchRate = 45,
		.expYield = 187,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 0,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 2,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(50),
		.eggCycles = 30,
		.friendship = 50,
		.growthRate = GROWTH_MEDIUM_FAST,
		.eggGroup1 = EGG_GROUP_MINERAL,
		.eggGroup2 = EGG_GROUP_DRAGON,
		.ability1 = ABILITY_LIGHTMETAL,
		.ability2 = ABILITY_HEAVYMETAL,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_STALWART,
		.noFlip = TRUE,
	},
	
	[SPECIES_URSHIFU_SINGLE_GIGA] =
	{
		.baseHP 		= 100,
		.baseAttack 	= 130,
		.baseDefense 	= 100,
		.baseSpAttack 	= 63,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 97,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_DARK,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_INNERFOCUS, //UNSEEN FIST NOT DEFINED
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
	
	[SPECIES_URSHIFU_RAPID_GIGA] = 
	{
		.baseHP 		= 100,
		.baseAttack 	= 130,
		.baseDefense 	= 100,
		.baseSpAttack 	= 63,
		.baseSpDefense 	= 60,
		.baseSpeed 		= 97,
		.type1 = TYPE_FIGHTING,
		.type2 = TYPE_WATER,
		.catchRate = 3,
		.expYield = 255,
		.evYield_HP 		= 0,
		.evYield_Attack 	= 3,
		.evYield_Defense 	= 0,
		.evYield_SpAttack 	= 0,
		.evYield_SpDefense 	= 0,
		.evYield_Speed 		= 0,
		.item1 = ITEM_NONE,
		.item2 = ITEM_NONE,
		.genderRatio = PERCENT_FEMALE(12.5),
		.eggCycles = 120,
		.friendship = 0,
		.growthRate = GROWTH_SLOW,
		.eggGroup1 = EGG_GROUP_UNDISCOVERED,
		.eggGroup2 = EGG_GROUP_UNDISCOVERED,
		.ability1 = ABILITY_INNERFOCUS, //UNSEEN FIST NOT DEFINED
		.ability2 = ABILITY_NONE,
		.safariZoneFleeRate = 0,
		.hiddenAbility = ABILITY_NONE,
		.noFlip = TRUE,
	},
};
